/// <reference types="react" />
export interface ActionListItemProps extends React.HTMLProps<HTMLDivElement> {
    /** Children of the action list item */
    children?: React.ReactNode;
    /** Additional classes added to the action list item */
    className?: string;
}
export declare const ActionListItem: React.FunctionComponent<ActionListItemProps>;
//# sourceMappingURL=ActionListItem.d.ts.map