/// <reference types="react" />
export interface DescriptionListTermHelpTextProps extends React.HTMLProps<HTMLElement> {
    /** Anything that can be rendered inside of list term */
    children: React.ReactNode;
    /** Additional classes added to the DescriptionListTermHelpText */
    className?: string;
}
export declare const DescriptionListTermHelpText: React.FunctionComponent<DescriptionListTermHelpTextProps>;
//# sourceMappingURL=DescriptionListTermHelpText.d.ts.map