import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import progressStyle from '@patternfly/react-styles/css/components/Progress/progress.mjs';
export const ProgressHelperText = (_a) => {
    var { children } = _a, props = __rest(_a, ["children"]);
    return (_jsx("div", Object.assign({ className: progressStyle.progressHelperText }, props, { children: children })));
};
ProgressHelperText.displayName = 'ProgressHelperText';
//# sourceMappingURL=ProgressHelperText.js.map