/// <reference types="react" />
export interface ModalBoxHeaderProps {
    /** Content rendered inside the modal box header. */
    children?: React.ReactNode;
    /** Additional classes added to the modal box header. */
    className?: string;
    /** Optional help section for the modal box header. */
    help?: React.ReactNode;
}
export declare const ModalBoxHeader: React.FunctionComponent<ModalBoxHeaderProps>;
//# sourceMappingURL=ModalBoxHeader.d.ts.map