/// <reference types="react" />
export interface HintFooterProps {
    /** Content rendered inside the hint footer. */
    children?: React.ReactNode;
    /** Additional classes applied to the hint footer. */
    className?: string;
}
export declare const HintFooter: React.FunctionComponent<HintFooterProps>;
//# sourceMappingURL=HintFooter.d.ts.map