import './dual-list-selector.css';
export default {
  "badge": "pf-v6-c-badge",
  "button": "pf-v6-c-button",
  "dirRtl": "pf-v6-m-dir-rtl",
  "dualListSelector": "pf-v6-c-dual-list-selector",
  "dualListSelectorControls": "pf-v6-c-dual-list-selector__controls",
  "dualListSelectorControlsItem": "pf-v6-c-dual-list-selector__controls-item",
  "dualListSelectorDraggable": "pf-v6-c-dual-list-selector__draggable",
  "dualListSelectorHeader": "pf-v6-c-dual-list-selector__header",
  "dualListSelectorItem": "pf-v6-c-dual-list-selector__item",
  "dualListSelectorItemCheck": "pf-v6-c-dual-list-selector__item-check",
  "dualListSelectorItemCount": "pf-v6-c-dual-list-selector__item-count",
  "dualListSelectorItemMain": "pf-v6-c-dual-list-selector__item-main",
  "dualListSelectorItemText": "pf-v6-c-dual-list-selector__item-text",
  "dualListSelectorItemToggle": "pf-v6-c-dual-list-selector__item-toggle",
  "dualListSelectorItemToggleIcon": "pf-v6-c-dual-list-selector__item-toggle-icon",
  "dualListSelectorList": "pf-v6-c-dual-list-selector__list",
  "dualListSelectorListItem": "pf-v6-c-dual-list-selector__list-item",
  "dualListSelectorListItemRow": "pf-v6-c-dual-list-selector__list-item-row",
  "dualListSelectorMain": "pf-v6-c-dual-list-selector__main",
  "dualListSelectorMenu": "pf-v6-c-dual-list-selector__menu",
  "dualListSelectorPane": "pf-v6-c-dual-list-selector__pane",
  "dualListSelectorStatus": "pf-v6-c-dual-list-selector__status",
  "dualListSelectorStatusText": "pf-v6-c-dual-list-selector__status-text",
  "dualListSelectorTitleText": "pf-v6-c-dual-list-selector__title-text",
  "dualListSelectorTools": "pf-v6-c-dual-list-selector__tools",
  "dualListSelectorToolsActions": "pf-v6-c-dual-list-selector__tools-actions",
  "dualListSelectorToolsFilter": "pf-v6-c-dual-list-selector__tools-filter",
  "modifiers": {
    "chosen": "pf-m-chosen",
    "dragOver": "pf-m-drag-over",
    "expandable": "pf-m-expandable",
    "animateExpand": "pf-m-animate-expand",
    "expanded": "pf-m-expanded",
    "disabled": "pf-m-disabled",
    "selected": "pf-m-selected",
    "check": "pf-m-check",
    "ghostRow": "pf-m-ghost-row",
    "read": "pf-m-read"
  }
};