"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PanelMain = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const panel_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Panel/panel"));
const react_styles_1 = require("@patternfly/react-styles");
const c_panel__main_MaxHeight_1 = tslib_1.__importDefault(require('@patternfly/react-tokens/dist/js/c_panel__main_MaxHeight'));
const PanelMain = (_a) => {
    var { className, children, maxHeight } = _a, props = tslib_1.__rest(_a, ["className", "children", "maxHeight"]);
    return ((0, jsx_runtime_1.jsx)("div", Object.assign({ className: (0, react_styles_1.css)(panel_1.default.panelMain, className), style: { [c_panel__main_MaxHeight_1.default.name]: maxHeight } }, props, { children: children })));
};
exports.PanelMain = PanelMain;
exports.PanelMain.displayName = 'PanelMain';
//# sourceMappingURL=PanelMain.js.map