"use strict"
exports.__esModule = true;
exports.OutlinedWindowMinimizeIconConfig = {
  name: 'OutlinedWindowMinimizeIcon',
  height: 512,
  width: 512,
  svgPath: "M480 480H32c-17.7 0-32-14.3-32-32s14.3-32 32-32h448c17.7 0 32 14.3 32 32s-14.3 32-32 32z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.OutlinedWindowMinimizeIcon = require('../createIcon').createIcon(exports.OutlinedWindowMinimizeIconConfig);
exports["default"] = exports.OutlinedWindowMinimizeIcon;