"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DualListSelectorPaneContext = exports.DualListSelectorListContext = exports.DualListSelectorContext = void 0;
const react_1 = require("react");
exports.DualListSelectorContext = (0, react_1.createContext)({ isTree: false });
exports.DualListSelectorListContext = (0, react_1.createContext)({});
exports.DualListSelectorPaneContext = (0, react_1.createContext)({ isChosen: false });
//# sourceMappingURL=DualListSelectorContext.js.map