/// <reference types="react" />
export interface AboutModalBoxHeaderProps extends React.HTMLProps<HTMLDivElement> {
    /** Name of the product  */
    productName?: string;
    /** Id to use for about modal box header  */
    id: string;
}
export declare const AboutModalBoxHeader: React.FunctionComponent<AboutModalBoxHeaderProps>;
//# sourceMappingURL=AboutModalBoxHeader.d.ts.map