import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const EthernetIconConfig: {
  name: 'EthernetIcon',
  height: 512,
  width: 512,
  svgPath: "M496 192h-48v-48c0-8.8-7.2-16-16-16h-48V80c0-8.8-7.2-16-16-16H144c-8.8 0-16 7.2-16 16v48H80c-8.8 0-16 7.2-16 16v48H16c-8.8 0-16 7.2-16 16v224c0 8.8 7.2 16 16 16h80V320h32v128h64V320h32v128h64V320h32v128h64V320h32v128h80c8.8 0 16-7.2 16-16V208c0-8.8-7.2-16-16-16z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const EthernetIcon: ComponentClass<SVGIconProps>;
export default EthernetIcon;