/// <reference types="react" />
export interface ModalBoxBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the modal box body. */
    children?: React.ReactNode;
    /** Additional classes added to the modal box body. */
    className?: string;
}
export declare const ModalBoxBody: React.FunctionComponent<ModalBoxBodyProps>;
//# sourceMappingURL=ModalBoxBody.d.ts.map