/// <reference types="react" />
export interface DataListControlProps extends React.HTMLProps<HTMLDivElement> {
    /** Children of the data list control */
    children?: React.ReactNode;
    /** Additional classes added to the DataList item control */
    className?: string;
}
export declare const DataListControl: React.FunctionComponent<DataListControlProps>;
//# sourceMappingURL=DataListControl.d.ts.map