import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import { css } from '@patternfly/react-styles';
import styles from '@patternfly/react-styles/css/components/AboutModalBox/about-modal-box.mjs';
export const AboutModalBoxBrand = (_a) => {
    var { src, alt } = _a, props = __rest(_a, ["src", "alt"]);
    return (_jsx("div", Object.assign({ className: css(styles.aboutModalBoxBrand) }, props, { children: _jsx("img", { className: css(styles.aboutModalBoxBrandImage), src: src, alt: alt }) })));
};
AboutModalBoxBrand.displayName = 'AboutModalBoxBrand';
//# sourceMappingURL=AboutModalBoxBrand.js.map