.pf-v6-chart svg g[clip-path] {
  mix-blend-mode: multiply;
}

:where(:root) {
  --pf-t--chart--global--BorderWidth--lg: 8;
  --pf-t--chart--global--BorderWidth--sm: 2;
  --pf-t--chart--global--BorderWidth--xs: 1;
  --pf-t--chart--global--FontSize--2xl: 22;
  --pf-t--chart--global--FontSize--lg: 18;
  --pf-t--chart--global--FontSize--sm: 14;
  --pf-t--chart--global--FontSize--xs: 12;
  --pf-t--chart--global--label--margin: 8;
  --pf-t--chart--global--label--padding: 10;
  --pf-t--chart--global--label--stroke: transparent;
  --pf-t--chart--global--label--text-anchor: middle;
  --pf-t--chart--global--layout--height: 300;
  --pf-t--chart--global--layout--padding: 50;
  --pf-t--chart--global--layout--width: 450;
  --pf-t--chart--global--letter-spacing: normal;
  --pf-t--chart--global--stroke--width--sm: 2;
  --pf-t--chart--global--stroke--width--xs: 1;
  --pf-t--chart--global--stroke-line-cap: round;
  --pf-t--chart--global--stroke-line-join: round;
  --pf-t--chart--color--black--100: var(--pf-t--color--gray--10);
  --pf-t--chart--color--black--200: var(--pf-t--color--gray--20);
  --pf-t--chart--color--black--300: var(--pf-t--color--gray--30);
  --pf-t--chart--color--black--400: var(--pf-t--color--gray--40);
  --pf-t--chart--color--black--500: var(--pf-t--color--gray--50);
  --pf-t--chart--color--blue--100: var(--pf-t--color--blue--30);
  --pf-t--chart--color--blue--200: var(--pf-t--color--blue--40);
  --pf-t--chart--color--blue--300: var(--pf-t--color--blue--50);
  --pf-t--chart--color--blue--400: var(--pf-t--color--blue--60);
  --pf-t--chart--color--blue--500: var(--pf-t--color--blue--70);
  --pf-t--chart--color--green--100: var(--pf-t--color--green--30);
  --pf-t--chart--color--green--200: var(--pf-t--color--green--40);
  --pf-t--chart--color--green--300: var(--pf-t--color--green--50);
  --pf-t--chart--color--green--400: var(--pf-t--color--green--60);
  --pf-t--chart--color--green--500: var(--pf-t--color--green--70);
  --pf-t--chart--color--orange--100: var(--pf-t--color--orange--30);
  --pf-t--chart--color--orange--200: var(--pf-t--color--orange--40);
  --pf-t--chart--color--orange--300: var(--pf-t--color--orange--50);
  --pf-t--chart--color--orange--400: var(--pf-t--color--orange--60);
  --pf-t--chart--color--orange--500: var(--pf-t--color--orange--70);
  --pf-t--chart--color--purple--100: var(--pf-t--color--purple--30);
  --pf-t--chart--color--purple--200: var(--pf-t--color--purple--40);
  --pf-t--chart--color--purple--300: var(--pf-t--color--purple--50);
  --pf-t--chart--color--purple--400: var(--pf-t--color--purple--60);
  --pf-t--chart--color--purple--500: var(--pf-t--color--purple--70);
  --pf-t--chart--color--red-orange--100: var(--pf-t--color--red-orange--30);
  --pf-t--chart--color--red-orange--200: var(--pf-t--color--red-orange--40);
  --pf-t--chart--color--red-orange--300: var(--pf-t--color--red-orange--50);
  --pf-t--chart--color--red-orange--400: var(--pf-t--color--red-orange--60);
  --pf-t--chart--color--red-orange--500: var(--pf-t--color--red-orange--70);
  --pf-t--chart--color--teal--100: var(--pf-t--color--teal--30);
  --pf-t--chart--color--teal--200: var(--pf-t--color--teal--40);
  --pf-t--chart--color--teal--300: var(--pf-t--color--teal--50);
  --pf-t--chart--color--teal--400: var(--pf-t--color--teal--60);
  --pf-t--chart--color--teal--500: var(--pf-t--color--teal--70);
  --pf-t--chart--color--yellow--100: var(--pf-t--color--yellow--20);
  --pf-t--chart--color--yellow--200: var(--pf-t--color--yellow--30);
  --pf-t--chart--color--yellow--300: var(--pf-t--color--yellow--40);
  --pf-t--chart--color--yellow--400: var(--pf-t--color--yellow--50);
  --pf-t--chart--color--yellow--500: var(--pf-t--color--yellow--60);
  --pf-t--chart--global--danger--color--100: var(--pf-t--color--red-orange--60);
  --pf-t--chart--global--fill--color--100: var(--pf-t--color--gray--10);
  --pf-t--chart--global--fill--color--200: var(--pf-t--color--gray--20);
  --pf-t--chart--global--fill--color--300: var(--pf-t--color--gray--30);
  --pf-t--chart--global--fill--color--400: var(--pf-t--color--gray--40);
  --pf-t--chart--global--fill--color--500: var(--pf-t--color--gray--50);
  --pf-t--chart--global--fill--color--700: var(--pf-t--color--gray--70);
  --pf-t--chart--global--fill--color--900: var(--pf-t--color--gray--90);
  --pf-t--chart--global--fill--color--white: var(--pf-t--color--white);
  --pf-t--chart--global--label--fill: var(--pf-t--color--gray--90);
  --pf-t--chart--global--success--color--100: var(--pf-t--color--blue--50);
  --pf-t--chart--global--warning--color--100: var(--pf-t--color--orange--40);
  --pf-t--chart--global--warning--color--200: var(--pf-t--color--yellow--40);
  --pf-t--chart--theme--colorscales--blue--colorscale--100: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--blue--colorscale--200: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--blue--colorscale--300: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--blue--colorscale--400: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--blue--colorscale--500: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--gray--colorscale--100: var(--pf-t--chart--color--black--300);
  --pf-t--chart--theme--colorscales--gray--colorscale--200: var(--pf-t--chart--color--black--100);
  --pf-t--chart--theme--colorscales--gray--colorscale--300: var(--pf-t--chart--color--black--500);
  --pf-t--chart--theme--colorscales--gray--colorscale--400: var(--pf-t--chart--color--black--200);
  --pf-t--chart--theme--colorscales--gray--colorscale--500: var(--pf-t--chart--color--black--400);
  --pf-t--chart--theme--colorscales--green--colorscale--100: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--green--colorscale--200: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--green--colorscale--300: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--green--colorscale--400: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--green--colorscale--500: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--100: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1000: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1100: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1200: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1300: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1400: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1500: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1600: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1700: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1800: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1900: var(--pf-t--chart--color--yellow--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--200: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2000: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2100: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2200: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2300: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2400: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2500: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--300: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--400: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--500: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--600: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--700: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--800: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--900: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--100: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1000: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1100: var(--pf-t--chart--color--purple--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1200: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1300: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1400: var(--pf-t--chart--color--black--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1500: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1600: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1700: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1800: var(--pf-t--chart--color--purple--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1900: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--200: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2000: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2100: var(--pf-t--chart--color--black--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2200: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2300: var(--pf-t--chart--color--yellow--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2400: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2500: var(--pf-t--chart--color--purple--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2600: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2700: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2800: var(--pf-t--chart--color--black--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2900: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--300: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3000: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3100: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3200: var(--pf-t--chart--color--purple--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3300: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3400: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3500: var(--pf-t--chart--color--black--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--400: var(--pf-t--chart--color--purple--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--500: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--600: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--700: var(--pf-t--chart--color--black--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--800: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--900: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--orange--colorscale--100: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--orange--colorscale--200: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--orange--colorscale--300: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--orange--colorscale--400: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--orange--colorscale--500: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--purple--colorscale--100: var(--pf-t--chart--color--purple--300);
  --pf-t--chart--theme--colorscales--purple--colorscale--200: var(--pf-t--chart--color--purple--100);
  --pf-t--chart--theme--colorscales--purple--colorscale--300: var(--pf-t--chart--color--purple--500);
  --pf-t--chart--theme--colorscales--purple--colorscale--400: var(--pf-t--chart--color--purple--200);
  --pf-t--chart--theme--colorscales--purple--colorscale--500: var(--pf-t--chart--color--purple--400);
  --pf-t--chart--theme--colorscales--teal--colorscale--100: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--teal--colorscale--200: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--teal--colorscale--300: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--teal--colorscale--400: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--teal--colorscale--500: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--yellow--colorscale--100: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--yellow--colorscale--200: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--yellow--colorscale--300: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--yellow--colorscale--400: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--yellow--colorscale--500: var(--pf-t--chart--color--yellow--400);
}

:where(.pf-v6-theme-dark) {
  --pf-t--chart--global--BorderWidth--lg: 8;
  --pf-t--chart--global--BorderWidth--sm: 2;
  --pf-t--chart--global--BorderWidth--xs: 1;
  --pf-t--chart--global--FontSize--2xl: 22;
  --pf-t--chart--global--FontSize--lg: 18;
  --pf-t--chart--global--FontSize--sm: 14;
  --pf-t--chart--global--FontSize--xs: 12;
  --pf-t--chart--global--label--margin: 8;
  --pf-t--chart--global--label--padding: 10;
  --pf-t--chart--global--label--stroke: transparent;
  --pf-t--chart--global--label--text-anchor: middle;
  --pf-t--chart--global--layout--height: 300;
  --pf-t--chart--global--layout--padding: 50;
  --pf-t--chart--global--layout--width: 450;
  --pf-t--chart--global--letter-spacing: normal;
  --pf-t--chart--global--stroke--width--sm: 2;
  --pf-t--chart--global--stroke--width--xs: 1;
  --pf-t--chart--global--stroke-line-cap: round;
  --pf-t--chart--global--stroke-line-join: round;
  --pf-t--chart--color--black--100: var(--pf-t--color--gray--50);
  --pf-t--chart--color--black--200: var(--pf-t--color--gray--40);
  --pf-t--chart--color--black--300: var(--pf-t--color--gray--30);
  --pf-t--chart--color--black--400: var(--pf-t--color--gray--20);
  --pf-t--chart--color--black--500: var(--pf-t--color--gray--10);
  --pf-t--chart--color--blue--100: var(--pf-t--color--blue--50);
  --pf-t--chart--color--blue--200: var(--pf-t--color--blue--40);
  --pf-t--chart--color--blue--300: var(--pf-t--color--blue--30);
  --pf-t--chart--color--blue--400: var(--pf-t--color--blue--20);
  --pf-t--chart--color--blue--500: var(--pf-t--color--blue--10);
  --pf-t--chart--color--green--100: var(--pf-t--color--green--50);
  --pf-t--chart--color--green--200: var(--pf-t--color--green--40);
  --pf-t--chart--color--green--300: var(--pf-t--color--green--30);
  --pf-t--chart--color--green--400: var(--pf-t--color--green--20);
  --pf-t--chart--color--green--500: var(--pf-t--color--green--10);
  --pf-t--chart--color--orange--100: var(--pf-t--color--orange--50);
  --pf-t--chart--color--orange--200: var(--pf-t--color--orange--40);
  --pf-t--chart--color--orange--300: var(--pf-t--color--orange--30);
  --pf-t--chart--color--orange--400: var(--pf-t--color--orange--20);
  --pf-t--chart--color--orange--500: var(--pf-t--color--orange--10);
  --pf-t--chart--color--purple--100: var(--pf-t--color--purple--60);
  --pf-t--chart--color--purple--200: var(--pf-t--color--purple--50);
  --pf-t--chart--color--purple--300: var(--pf-t--color--purple--40);
  --pf-t--chart--color--purple--400: var(--pf-t--color--purple--30);
  --pf-t--chart--color--purple--500: var(--pf-t--color--purple--20);
  --pf-t--chart--color--red-orange--100: var(--pf-t--color--red-orange--50);
  --pf-t--chart--color--red-orange--200: var(--pf-t--color--red-orange--40);
  --pf-t--chart--color--red-orange--300: var(--pf-t--color--red-orange--30);
  --pf-t--chart--color--red-orange--400: var(--pf-t--color--red-orange--20);
  --pf-t--chart--color--red-orange--500: var(--pf-t--color--red-orange--10);
  --pf-t--chart--color--teal--100: var(--pf-t--color--teal--50);
  --pf-t--chart--color--teal--200: var(--pf-t--color--teal--40);
  --pf-t--chart--color--teal--300: var(--pf-t--color--teal--30);
  --pf-t--chart--color--teal--400: var(--pf-t--color--teal--20);
  --pf-t--chart--color--teal--500: var(--pf-t--color--teal--10);
  --pf-t--chart--color--yellow--100: var(--pf-t--color--yellow--50);
  --pf-t--chart--color--yellow--200: var(--pf-t--color--yellow--40);
  --pf-t--chart--color--yellow--300: var(--pf-t--color--yellow--30);
  --pf-t--chart--color--yellow--400: var(--pf-t--color--yellow--20);
  --pf-t--chart--color--yellow--500: var(--pf-t--color--yellow--10);
  --pf-t--chart--global--danger--color--100: var(--pf-t--color--red-orange--50);
  --pf-t--chart--global--fill--color--100: var(--pf-t--color--gray--60);
  --pf-t--chart--global--fill--color--200: var(--pf-t--color--gray--50);
  --pf-t--chart--global--fill--color--300: var(--pf-t--color--gray--40);
  --pf-t--chart--global--fill--color--400: var(--pf-t--color--gray--30);
  --pf-t--chart--global--fill--color--500: var(--pf-t--color--gray--20);
  --pf-t--chart--global--fill--color--700: var(--pf-t--color--gray--10);
  --pf-t--chart--global--fill--color--900: var(--pf-t--color--white);
  --pf-t--chart--global--fill--color--white: var(--pf-t--color--white);
  --pf-t--chart--global--label--fill: var(--pf-t--color--white);
  --pf-t--chart--global--success--color--100: var(--pf-t--color--blue--30);
  --pf-t--chart--global--warning--color--100: var(--pf-t--color--orange--30);
  --pf-t--chart--global--warning--color--200: var(--pf-t--color--yellow--30);
  --pf-t--chart--theme--colorscales--blue--colorscale--100: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--blue--colorscale--200: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--blue--colorscale--300: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--blue--colorscale--400: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--blue--colorscale--500: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--gray--colorscale--100: var(--pf-t--chart--color--black--300);
  --pf-t--chart--theme--colorscales--gray--colorscale--200: var(--pf-t--chart--color--black--100);
  --pf-t--chart--theme--colorscales--gray--colorscale--300: var(--pf-t--chart--color--black--500);
  --pf-t--chart--theme--colorscales--gray--colorscale--400: var(--pf-t--chart--color--black--200);
  --pf-t--chart--theme--colorscales--gray--colorscale--500: var(--pf-t--chart--color--black--400);
  --pf-t--chart--theme--colorscales--green--colorscale--100: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--green--colorscale--200: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--green--colorscale--300: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--green--colorscale--400: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--green--colorscale--500: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--100: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1000: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1100: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1200: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1300: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1400: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1500: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1600: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1700: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1800: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1900: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--200: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2000: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2100: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2200: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2300: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2400: var(--pf-t--chart--color--yellow--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2500: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--300: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--400: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--500: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--600: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--700: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--800: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--900: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--100: var(--pf-t--chart--color--blue--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1000: var(--pf-t--chart--color--green--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1100: var(--pf-t--chart--color--purple--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1200: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1300: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1400: var(--pf-t--chart--color--black--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1500: var(--pf-t--chart--color--blue--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1600: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1700: var(--pf-t--chart--color--green--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1800: var(--pf-t--chart--color--purple--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1900: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--200: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2000: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2100: var(--pf-t--chart--color--black--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2200: var(--pf-t--chart--color--blue--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2300: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2400: var(--pf-t--chart--color--green--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2500: var(--pf-t--chart--color--purple--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2600: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2700: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2800: var(--pf-t--chart--color--black--500);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2900: var(--pf-t--chart--color--blue--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--300: var(--pf-t--chart--color--green--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3000: var(--pf-t--chart--color--yellow--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3100: var(--pf-t--chart--color--green--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3200: var(--pf-t--chart--color--purple--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3300: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3400: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3500: var(--pf-t--chart--color--black--400);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--400: var(--pf-t--chart--color--purple--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--500: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--600: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--700: var(--pf-t--chart--color--black--200);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--800: var(--pf-t--chart--color--blue--300);
  --pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--900: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--orange--colorscale--100: var(--pf-t--chart--color--orange--300);
  --pf-t--chart--theme--colorscales--orange--colorscale--200: var(--pf-t--chart--color--orange--100);
  --pf-t--chart--theme--colorscales--orange--colorscale--300: var(--pf-t--chart--color--orange--500);
  --pf-t--chart--theme--colorscales--orange--colorscale--400: var(--pf-t--chart--color--orange--200);
  --pf-t--chart--theme--colorscales--orange--colorscale--500: var(--pf-t--chart--color--orange--400);
  --pf-t--chart--theme--colorscales--purple--colorscale--100: var(--pf-t--chart--color--purple--300);
  --pf-t--chart--theme--colorscales--purple--colorscale--200: var(--pf-t--chart--color--purple--100);
  --pf-t--chart--theme--colorscales--purple--colorscale--300: var(--pf-t--chart--color--purple--500);
  --pf-t--chart--theme--colorscales--purple--colorscale--400: var(--pf-t--chart--color--purple--200);
  --pf-t--chart--theme--colorscales--purple--colorscale--500: var(--pf-t--chart--color--purple--400);
  --pf-t--chart--theme--colorscales--teal--colorscale--100: var(--pf-t--chart--color--teal--300);
  --pf-t--chart--theme--colorscales--teal--colorscale--200: var(--pf-t--chart--color--teal--100);
  --pf-t--chart--theme--colorscales--teal--colorscale--300: var(--pf-t--chart--color--teal--500);
  --pf-t--chart--theme--colorscales--teal--colorscale--400: var(--pf-t--chart--color--teal--200);
  --pf-t--chart--theme--colorscales--teal--colorscale--500: var(--pf-t--chart--color--teal--400);
  --pf-t--chart--theme--colorscales--yellow--colorscale--100: var(--pf-t--chart--color--yellow--300);
  --pf-t--chart--theme--colorscales--yellow--colorscale--200: var(--pf-t--chart--color--yellow--100);
  --pf-t--chart--theme--colorscales--yellow--colorscale--300: var(--pf-t--chart--color--yellow--500);
  --pf-t--chart--theme--colorscales--yellow--colorscale--400: var(--pf-t--chart--color--yellow--200);
  --pf-t--chart--theme--colorscales--yellow--colorscale--500: var(--pf-t--chart--color--yellow--400);
}

:where(:root) {
  --pf-v6-chart-color-blue-100: var(--pf-t--chart--color--blue--100);
  --pf-v6-chart-color-blue-200: var(--pf-t--chart--color--blue--200);
  --pf-v6-chart-color-blue-300: var(--pf-t--chart--color--blue--300);
  --pf-v6-chart-color-blue-400: var(--pf-t--chart--color--blue--400);
  --pf-v6-chart-color-blue-500: var(--pf-t--chart--color--blue--500);
  --pf-v6-chart-color-green-100: var(--pf-t--chart--color--green--100);
  --pf-v6-chart-color-green-200: var(--pf-t--chart--color--green--200);
  --pf-v6-chart-color-green-300: var(--pf-t--chart--color--green--300);
  --pf-v6-chart-color-green-400: var(--pf-t--chart--color--green--400);
  --pf-v6-chart-color-green-500: var(--pf-t--chart--color--green--500);
  --pf-v6-chart-color-teal-100: var(--pf-t--chart--color--teal--100);
  --pf-v6-chart-color-teal-200: var(--pf-t--chart--color--teal--200);
  --pf-v6-chart-color-teal-300: var(--pf-t--chart--color--teal--300);
  --pf-v6-chart-color-teal-400: var(--pf-t--chart--color--teal--400);
  --pf-v6-chart-color-teal-500: var(--pf-t--chart--color--teal--500);
  --pf-v6-chart-color-purple-100: var(--pf-t--chart--color--purple--100);
  --pf-v6-chart-color-purple-200: var(--pf-t--chart--color--purple--200);
  --pf-v6-chart-color-purple-300: var(--pf-t--chart--color--purple--300);
  --pf-v6-chart-color-purple-400: var(--pf-t--chart--color--purple--400);
  --pf-v6-chart-color-purple-500: var(--pf-t--chart--color--purple--500);
  --pf-v6-chart-color-yellow-100: var(--pf-t--chart--color--yellow--100);
  --pf-v6-chart-color-yellow-200: var(--pf-t--chart--color--yellow--200);
  --pf-v6-chart-color-yellow-300: var(--pf-t--chart--color--yellow--300);
  --pf-v6-chart-color-yellow-400: var(--pf-t--chart--color--yellow--400);
  --pf-v6-chart-color-yellow-500: var(--pf-t--chart--color--yellow--500);
  --pf-v6-chart-color-orange-100: var(--pf-t--chart--color--orange--100);
  --pf-v6-chart-color-orange-200: var(--pf-t--chart--color--orange--200);
  --pf-v6-chart-color-orange-300: var(--pf-t--chart--color--orange--300);
  --pf-v6-chart-color-orange-400: var(--pf-t--chart--color--orange--400);
  --pf-v6-chart-color-orange-500: var(--pf-t--chart--color--orange--500);
  --pf-v6-chart-color-black-100: var(--pf-t--chart--color--black--100);
  --pf-v6-chart-color-black-200: var(--pf-t--chart--color--black--200);
  --pf-v6-chart-color-black-300: var(--pf-t--chart--color--black--300);
  --pf-v6-chart-color-black-400: var(--pf-t--chart--color--black--400);
  --pf-v6-chart-color-black-500: var(--pf-t--chart--color--black--500);
  --pf-v6-chart-color-red-orange-100: var(--pf-t--chart--color--red-orange--100);
  --pf-v6-chart-color-red-orange-200: var(--pf-t--chart--color--red-orange--200);
  --pf-v6-chart-color-red-orange-300: var(--pf-t--chart--color--red-orange--300);
  --pf-v6-chart-color-red-orange-400: var(--pf-t--chart--color--red-orange--400);
  --pf-v6-chart-color-red-orange-500: var(--pf-t--chart--color--red-orange--500);
  --pf-v6-chart-global--FontSize--xs: var(--pf-t--chart--global--FontSize--xs);
  --pf-v6-chart-global--FontSize--sm: var(--pf-t--chart--global--FontSize--sm);
  --pf-v6-chart-global--FontSize--lg: var(--pf-t--chart--global--FontSize--lg);
  --pf-v6-chart-global--FontSize--2xl: var(--pf-t--chart--global--FontSize--2xl);
  --pf-v6-chart-global--FontFamily: var(--pf-t--global--font--family--body);
  --pf-v6-chart-global--letter-spacing: var(--pf-t--chart--global--letter-spacing);
  --pf-v6-chart-global--label--Padding: var(--pf-t--chart--global--label--padding);
  --pf-v6-chart-global--label--Margin: var(--pf-t--chart--global--label--margin);
  --pf-v6-chart-global--label--stroke: var(--pf-t--chart--global--label--stroke);
  --pf-v6-chart-global--label--text-anchor: var(--pf-t--chart--global--label--text-anchor);
  --pf-v6-chart-global--label--stroke--Width: 0;
  --pf-v6-chart-global--label--Fill: var(--pf-t--chart--global--label--fill);
  --pf-v6-chart-global--layout--Padding: var(--pf-t--chart--global--layout--padding);
  --pf-v6-chart-global--layout--Height: var(--pf-t--chart--global--layout--height);
  --pf-v6-chart-global--layout--Width: var(--pf-t--chart--global--layout--width);
  --pf-v6-chart-global--stroke--Width--xs: var(--pf-t--chart--global--stroke--width--xs);
  --pf-v6-chart-global--stroke--Width--sm: var(--pf-t--chart--global--stroke--width--sm);
  --pf-v6-chart-global--BorderWidth--xs: var(--pf-t--chart--global--BorderWidth--xs);
  --pf-v6-chart-global--BorderWidth--sm: var(--pf-t--chart--global--BorderWidth--sm);
  --pf-v6-chart-global--BorderWidth--lg: var(--pf-t--chart--global--BorderWidth--lg);
  --pf-v6-chart-global--stroke-line-cap: var(--pf-t--chart--global--stroke-line-cap);
  --pf-v6-chart-global--stroke-line-join: var(--pf-t--chart--global--stroke-line-join);
  --pf-v6-chart-global--danger--Color--100: var(--pf-t--chart--global--danger--color--100);
  --pf-v6-chart-global--warning--Color--100: var(--pf-t--chart--global--warning--color--100);
  --pf-v6-chart-global--warning--Color--200: var(--pf-t--chart--global--warning--color--200);
  --pf-v6-chart-global--success--Color--100: var(--pf-t--chart--global--success--color--100);
  --pf-v6-chart-global--Fill--Color--900: var(--pf-t--chart--global--fill--color--900);
  --pf-v6-chart-global--Fill--Color--700: var(--pf-t--chart--global--fill--color--700);
  --pf-v6-chart-global--Fill--Color--500: var(--pf-t--chart--global--fill--color--500);
  --pf-v6-chart-global--Fill--Color--400: var(--pf-t--chart--global--fill--color--400);
  --pf-v6-chart-global--Fill--Color--300: var(--pf-t--chart--global--fill--color--300);
  --pf-v6-chart-global--Fill--Color--200: var(--pf-t--chart--global--fill--color--200);
  --pf-v6-chart-global--Fill--Color--white: var(--pf-t--chart--global--fill--color--white);
  --pf-v6-chart-area--Opacity: .3;
  --pf-v6-chart-area--stroke--Width: var(--pf-v6-chart-global--stroke--Width--sm);
  --pf-v6-chart-area--data--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-axis--axis--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-axis--axis--stroke--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-axis--axis--Fill: transparent;
  --pf-v6-chart-axis--axis-label--Padding: 40;
  --pf-v6-chart-axis--axis-label--stroke--Color: transparent;
  --pf-v6-chart-axis--grid--Fill: none;
  --pf-v6-chart-axis--grid--stroke--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-axis--grid--PointerEvents: painted;
  --pf-v6-chart-axis--tick--Fill: transparent;
  --pf-v6-chart-axis--tick--Size: 5;
  --pf-v6-chart-axis--tick--Width: 1;
  --pf-v6-chart-axis--tick--stroke--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-axis--tick-label--Fill: var(--pf-v6-chart-global--Fill--Color--700);
  --pf-v6-chart-bar--Width: 10;
  --pf-v6-chart-bar--data--stroke: none;
  --pf-v6-chart-bar--data--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-bar--data--Padding: 8;
  --pf-v6-chart-bar--data-stroke--Width: 0;
  --pf-v6-chart-boxplot--max--Padding: 8;
  --pf-v6-chart-boxplot--max--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-boxplot--max--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-boxplot--median--Padding: 8;
  --pf-v6-chart-boxplot--median--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-boxplot--median--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-boxplot--min--Padding: 8;
  --pf-v6-chart-boxplot--min--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-boxplot--min--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-boxplot--lower-quartile--Padding: 8;
  --pf-v6-chart-boxplot--lower-quartile--Fill: var(--pf-v6-chart-global--Fill--Color--500);
  --pf-v6-chart-boxplot--upper-quartile--Padding: 8;
  --pf-v6-chart-boxplot--upper-quartile--Fill: var(--pf-v6-chart-global--Fill--Color--500);
  --pf-v6-chart-boxplot--box--Width: 20;
  --pf-v6-chart-bullet--axis--tick--count: 5;
  --pf-v6-chart-bullet--comparative-measure--Fill--Color: var(--pf-v6-chart-global--Fill--Color--700);
  --pf-v6-chart-bullet--comparative-measure--stroke--Color: var(--pf-v6-chart-global--Fill--Color--700);
  --pf-v6-chart-bullet--comparative-measure--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-bullet--comparative-measure--Width: 30;
  --pf-v6-chart-bullet--comparative-measure--error--Fill--Color: var(--pf-v6-chart-global--danger--Color--100);
  --pf-v6-chart-bullet--comparative-measure--error--stroke--Color: var(--pf-v6-chart-global--danger--Color--100);
  --pf-v6-chart-bullet--comparative-measure--error--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-bullet--comparative-measure--error--Width: 30;
  --pf-v6-chart-bullet--comparative-measure--warning--Fill--Color: var(--pf-v6-chart-global--warning--Color--100);
  --pf-v6-chart-bullet--comparative-measure--warning--stroke--Color: var(--pf-v6-chart-global--warning--Color--100);
  --pf-v6-chart-bullet--comparative-measure--warning--stroke--Width: var(--pf-t--chart--global--stroke--width--sm);
  --pf-v6-chart-bullet--comparative-measure--warning--Width: 30;
  --pf-v6-chart-bullet--group-title--divider--Fill--Color: var(--pf-t--global--border--color--default);
  --pf-v6-chart-bullet--group-title--divider--stroke--Color: var(--pf-t--global--border--color--default);
  --pf-v6-chart-bullet--group-title--divider--stroke--Width: var(--pf-t--chart--global--stroke--width--sm);
  --pf-v6-chart-bullet--Height: 140;
  --pf-v6-chart-bullet--label--title--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-bullet--label--grouptitle--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-bullet--label--subtitle--Fill: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-bullet--primary-measure--dot--size: 6;
  --pf-v6-chart-bullet--primary-measure--segmented--Width: 9;
  --pf-v6-chart-bullet--negative-measure--ColorScale--100: var(--pf-v6-chart-color-red-orange-100);
  --pf-v6-chart-bullet--negative-measure--ColorScale--200: var(--pf-v6-chart-color-red-orange-200);
  --pf-v6-chart-bullet--negative-measure--ColorScale--300: var(--pf-v6-chart-color-red-orange-300);
  --pf-v6-chart-bullet--negative-measure--ColorScale--400: var(--pf-v6-chart-color-red-orange-400);
  --pf-v6-chart-bullet--negative-measure--ColorScale--500: var(--pf-v6-chart-color-red-orange-500);
  --pf-v6-chart-bullet--qualitative-range--Width: 30;
  --pf-v6-chart-bullet--qualitative-range--ColorScale--100: var(--pf-v6-chart-color-black-100);
  --pf-v6-chart-bullet--qualitative-range--ColorScale--200: var(--pf-v6-chart-color-black-200);
  --pf-v6-chart-bullet--qualitative-range--ColorScale--300: var(--pf-v6-chart-color-black-300);
  --pf-v6-chart-bullet--qualitative-range--ColorScale--400: var(--pf-v6-chart-color-black-400);
  --pf-v6-chart-bullet--qualitative-range--ColorScale--500: var(--pf-v6-chart-color-black-500);
  --pf-v6-chart-candelstick--data--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-candelstick--data--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-candelstick--candle--positive--Color: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-candelstick--candle--negative--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-container--cursor--line--Fill: var(--pf-t--global--border--color--default);
  --pf-v6-chart-donut--label--title--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-donut--label--subtitle--Fill: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-donut--label--subtitle--position: center;
  --pf-v6-chart-donut--pie--Height: 230;
  --pf-v6-chart-donut--pie--angle--Padding: 1;
  --pf-v6-chart-donut--pie--Padding: 20;
  --pf-v6-chart-donut--pie--Width: 230;
  --pf-v6-chart-donut--threshold--first--Color: var(--pf-v6-chart-global--Fill--Color--200);
  --pf-v6-chart-donut--threshold--second--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-donut--threshold--third--Color: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-donut--threshold--warning--Color: var(--pf-v6-chart-global--warning--Color--200);
  --pf-v6-chart-donut--threshold--danger--Color: var(--pf-v6-chart-global--danger--Color--100);
  --pf-v6-chart-donut--threshold--dynamic--pie--Height: 202;
  --pf-v6-chart-donut--threshold--dynamic--pie--Padding: 202;
  --pf-v6-chart-donut--threshold--dynamic--pie--Width: 20;
  --pf-v6-chart-donut--threshold--static--pie--Height: 230;
  --pf-v6-chart-donut--threshold--static--pie--angle--Padding: 1;
  --pf-v6-chart-donut--threshold--static--pie--Padding: 20;
  --pf-v6-chart-donut--threshold--static--pie--Width: 230;
  --pf-v6-chart-donut--utilization--dynamic--pie--Height: 230;
  --pf-v6-chart-donut--utilization--dynamic--pie--angle--Padding: 1;
  --pf-v6-chart-donut--utilization--dynamic--pie--Padding: 20;
  --pf-v6-chart-donut--utilization--dynamic--pie--Width: 230;
  --pf-v6-chart-donut--utilization--static--pie--Padding: 20;
  --pf-v6-chart-errorbar--BorderWidth: var(--pf-v6-chart-global--BorderWidth--lg);
  --pf-v6-chart-errorbar--data--Fill: transparent;
  --pf-v6-chart-errorbar--data--Opacity: 1;
  --pf-v6-chart-errorbar--data-stroke--Width: var(--pf-v6-chart-global--stroke--Width--sm);
  --pf-v6-chart-errorbar--data-stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-legend--gutter--Width: 20;
  --pf-v6-chart-legend--orientation: horizontal;
  --pf-v6-chart-legend--position: right;
  --pf-v6-chart-legend--title--orientation: top;
  --pf-v6-chart-legend--data--type: square;
  --pf-v6-chart-legend--title--Padding: 2;
  --pf-v6-chart-legend--Margin: 16;
  --pf-v6-chart-line--data--Fill: transparent;
  --pf-v6-chart-line--data--Opacity: 1;
  --pf-v6-chart-line--data--stroke--Width: var(--pf-v6-chart-global--stroke--Width--sm);
  --pf-v6-chart-line--data--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-pie--Padding: 20;
  --pf-v6-chart-pie--data--Padding: 8;
  --pf-v6-chart-pie--data--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-pie--data--stroke--Color: transparent;
  --pf-v6-chart-pie--labels--Padding: 8;
  --pf-v6-chart-pie--Height: 230;
  --pf-v6-chart-pie--Width: 230;
  --pf-v6-chart-scatter--data--stroke--Color: transparent;
  --pf-v6-chart-scatter--data--stroke--Width: 0;
  --pf-v6-chart-scatter--data--Opacity: 1;
  --pf-v6-chart-scatter--data--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-scatter--active--size: 5;
  --pf-v6-chart-scatter--size: 3;
  --pf-v6-chart-stack--data--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-threshold--stroke-dash-array: 4,2;
  --pf-v6-chart-threshold--stroke--Width: 1.5;
  --pf-v6-chart-tooltip--corner-radius: 6;
  --pf-v6-chart-tooltip--pointer-length: 10;
  --pf-v6-chart-tooltip--Fill: var(--pf-v6-chart-global--Fill--Color--200);
  --pf-v6-chart-tooltip--flyoutStyle--corner-radius: 6;
  --pf-v6-chart-tooltip--flyoutStyle--stroke--Width: 0;
  --pf-v6-chart-tooltip--flyoutStyle--PointerEvents: none;
  --pf-v6-chart-tooltip--flyoutStyle--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-tooltip--flyoutStyle--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-tooltip--pointer--Width: 20;
  --pf-v6-chart-tooltip--Padding: 8;
  --pf-v6-chart-tooltip--PointerEvents: none;
  --pf-v6-chart-voronoi--data--Fill: transparent;
  --pf-v6-chart-voronoi--data--stroke--Color: transparent;
  --pf-v6-chart-voronoi--data--stroke--Width: 0;
  --pf-v6-chart-voronoi--labels--Padding: 8;
  --pf-v6-chart-voronoi--labels--Fill: var(--pf-v6-chart-global--Fill--Color--200);
  --pf-v6-chart-voronoi--labels--PointerEvents: none;
  --pf-v6-chart-voronoi--flyout--stroke--Width: var(--pf-v6-chart-global--stroke--Width--xs);
  --pf-v6-chart-voronoi--flyout--stroke--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-voronoi--flyout--stroke--Fill: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-voronoi--flyout--PointerEvents: none;
  --pf-v6-chart-theme--blue--ColorScale--100: var(--pf-t--chart--theme--colorscales--blue--colorscale--100);
  --pf-v6-chart-theme--blue--ColorScale--200: var(--pf-t--chart--theme--colorscales--blue--colorscale--200);
  --pf-v6-chart-theme--blue--ColorScale--300: var(--pf-t--chart--theme--colorscales--blue--colorscale--300);
  --pf-v6-chart-theme--blue--ColorScale--400: var(--pf-t--chart--theme--colorscales--blue--colorscale--400);
  --pf-v6-chart-theme--blue--ColorScale--500: var(--pf-t--chart--theme--colorscales--blue--colorscale--500);
  --pf-v6-chart-theme--teal--ColorScale--100: var(--pf-t--chart--theme--colorscales--teal--colorscale--100);
  --pf-v6-chart-theme--teal--ColorScale--200: var(--pf-t--chart--theme--colorscales--teal--colorscale--200);
  --pf-v6-chart-theme--teal--ColorScale--300: var(--pf-t--chart--theme--colorscales--teal--colorscale--300);
  --pf-v6-chart-theme--teal--ColorScale--400: var(--pf-t--chart--theme--colorscales--teal--colorscale--400);
  --pf-v6-chart-theme--teal--ColorScale--500: var(--pf-t--chart--theme--colorscales--teal--colorscale--500);
  --pf-v6-chart-theme--yellow--ColorScale--100: var(--pf-t--chart--theme--colorscales--yellow--colorscale--100);
  --pf-v6-chart-theme--yellow--ColorScale--200: var(--pf-t--chart--theme--colorscales--yellow--colorscale--200);
  --pf-v6-chart-theme--yellow--ColorScale--300: var(--pf-t--chart--theme--colorscales--yellow--colorscale--300);
  --pf-v6-chart-theme--yellow--ColorScale--400: var(--pf-t--chart--theme--colorscales--yellow--colorscale--400);
  --pf-v6-chart-theme--yellow--ColorScale--500: var(--pf-t--chart--theme--colorscales--yellow--colorscale--500);
  --pf-v6-chart-theme--gray--ColorScale--100: var(--pf-t--chart--theme--colorscales--gray--colorscale--100);
  --pf-v6-chart-theme--gray--ColorScale--200: var(--pf-t--chart--theme--colorscales--gray--colorscale--200);
  --pf-v6-chart-theme--gray--ColorScale--300: var(--pf-t--chart--theme--colorscales--gray--colorscale--300);
  --pf-v6-chart-theme--gray--ColorScale--400: var(--pf-t--chart--theme--colorscales--gray--colorscale--400);
  --pf-v6-chart-theme--gray--ColorScale--500: var(--pf-t--chart--theme--colorscales--gray--colorscale--500);
  --pf-v6-chart-theme--green--ColorScale--100: var(--pf-t--chart--theme--colorscales--green--colorscale--100);
  --pf-v6-chart-theme--green--ColorScale--200: var(--pf-t--chart--theme--colorscales--green--colorscale--200);
  --pf-v6-chart-theme--green--ColorScale--300: var(--pf-t--chart--theme--colorscales--green--colorscale--300);
  --pf-v6-chart-theme--green--ColorScale--400: var(--pf-t--chart--theme--colorscales--green--colorscale--400);
  --pf-v6-chart-theme--green--ColorScale--500: var(--pf-t--chart--theme--colorscales--green--colorscale--500);
  --pf-v6-chart-theme--orange--ColorScale--100: var(--pf-t--chart--theme--colorscales--orange--colorscale--100);
  --pf-v6-chart-theme--orange--ColorScale--200: var(--pf-t--chart--theme--colorscales--orange--colorscale--200);
  --pf-v6-chart-theme--orange--ColorScale--300: var(--pf-t--chart--theme--colorscales--orange--colorscale--300);
  --pf-v6-chart-theme--orange--ColorScale--400: var(--pf-t--chart--theme--colorscales--orange--colorscale--400);
  --pf-v6-chart-theme--orange--ColorScale--500: var(--pf-t--chart--theme--colorscales--orange--colorscale--500);
  --pf-v6-chart-theme--purple--ColorScale--100: var(--pf-t--chart--theme--colorscales--purple--colorscale--100);
  --pf-v6-chart-theme--purple--ColorScale--200: var(--pf-t--chart--theme--colorscales--purple--colorscale--200);
  --pf-v6-chart-theme--purple--ColorScale--300: var(--pf-t--chart--theme--colorscales--purple--colorscale--300);
  --pf-v6-chart-theme--purple--ColorScale--400: var(--pf-t--chart--theme--colorscales--purple--colorscale--400);
  --pf-v6-chart-theme--purple--ColorScale--500: var(--pf-t--chart--theme--colorscales--purple--colorscale--500);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--100: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--100);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--200: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--200);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--300: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--300);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--400: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--400);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--500: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--500);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--600: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--600);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--700: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--700);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--800: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--800);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--900: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--900);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1000: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1000);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1100: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1100);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1200: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1200);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1300: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1300);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1400: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1400);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1500: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1500);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1600: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1600);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1700: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1700);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1800: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1800);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--1900: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--1900);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2000: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2000);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2100: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2100);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2200: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2200);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2300: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2300);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2400: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2400);
  --pf-v6-chart-theme--multi-color-ordered--ColorScale--2500: var(--pf-t--chart--theme--colorscales--multi-colored-ordered--colorscale--2500);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--100: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--100);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--200: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--200);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--300: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--300);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--400: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--400);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--500: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--500);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--600: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--600);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--700: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--700);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--800: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--800);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--900: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--900);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1000: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1000);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1100: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1100);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1200: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1200);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1300: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1300);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1400: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1400);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1500: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1500);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1600: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1600);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1700: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1700);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1800: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1800);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--1900: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--1900);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2000: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2000);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2100: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2100);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2200: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2200);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2300: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2300);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2400: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2400);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2500: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2500);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2600: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2600);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2700: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2700);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2800: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2800);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--2900: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--2900);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3000: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3000);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3100: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3100);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3200: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3200);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3300: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3300);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3400: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3400);
  --pf-v6-chart-theme--multi-color-unordered--ColorScale--3500: var(--pf-t--chart--theme--colorscales--multi-colored-unordered--colorscale--3500);
}

:where(:root) {
  --pf-v6-chart-echarts-global--axis--BoundaryGap: false;
  --pf-v6-chart-echarts-global--axis--axis-label--Show: true;
  --pf-v6-chart-echarts-global--axis--axis-line--Show: true;
  --pf-v6-chart-echarts-global--axis--axis-line--item-style--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-echarts-global--axis--axis-tick--Show: true;
  --pf-v6-chart-echarts-global--axis--axis-tick--item-style--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-echarts-global--axis--split-area--Show: false;
  --pf-v6-chart-echarts-global--axis--split-area--area-style--Color: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-echarts-global--axis--split-line--Show: false;
  --pf-v6-chart-echarts-global--label--Color: var(--pf-v6-chart-global--label--Fill);
  --pf-v6-chart-echarts-BackgroundColor: transparent;
  --pf-v6-chart-echarts-bar--item-style--BarBorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-bar--item-style--BarBorderWidth: 0;
  --pf-v6-chart-echarts-boxplot--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-boxplot--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-candlestick--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-candlestick--item-style--negative--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-candlestick--item-style--positive--Color: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-echarts-candlestick--item-style--negative--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-candlestick--item-style--positive--BorderColor: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-echarts-datazoom--HandleSize: 100%;
  --pf-v6-chart-echarts-funnel--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-funnel--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-gauge--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-gauge--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-geo--emphasis--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-echarts-geo--emphasis--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-geo--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-geo--item-style--BorderWidth: 0.5;
  --pf-v6-chart-echarts-graph--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-graph--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-graph--line-style--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-graph--line-style--BorderWidth: 1;
  --pf-v6-chart-echarts-graph--Smooth: false;
  --pf-v6-chart-echarts-graph--SymbolSize: 4;
  --pf-v6-chart-echarts-graph--Symbol: "square";
  --pf-v6-chart-echarts-line--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-line--line-style--BorderWidth: 2;
  --pf-v6-chart-echarts-line--Smooth: false;
  --pf-v6-chart-echarts-line--SymbolSize: 4;
  --pf-v6-chart-echarts-line--Symbol: "square";
  --pf-v6-chart-echarts-map--emphasis--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-echarts-map--emphasis--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-map--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-map--item-style--BorderWidth: 0.5;
  --pf-v6-chart-echarts-parallel--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-parallel--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-pie--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-pie--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-sankey--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-sankey--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-scatter--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-scatter--item-style--BorderWidth: 0;
  --pf-v6-chart-echarts-skeleton--label--Color: transparent;
  --pf-v6-chart-echarts-toolbox--emphasis--item-style--BorderColor: var(--pf-v6-chart-theme--blue--ColorScale--400);
  --pf-v6-chart-echarts-toolbox--item-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--500);
  --pf-v6-chart-echarts-tooltip--axis--pointer--cross-style--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-echarts-tooltip--axis--pointer--cross-style--Width: 1;
  --pf-v6-chart-echarts-tooltip--axis--pointer--line-style--Color: var(--pf-v6-chart-global--Fill--Color--300);
  --pf-v6-chart-echarts-tooltip--axis--pointer--line-style--Width: 1;
  --pf-v6-chart-echarts-tooltip--backgroundColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-tooltip--text-Style--Color: var(--pf-v6-chart-global--Fill--Color--200);
  --pf-v6-chart-echarts-timeline--emphasis--control-style--Color: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-echarts-timeline--emphasis--control-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--400);
  --pf-v6-chart-echarts-timeline--emphasis--control-style--BorderWidth: 1;
  --pf-v6-chart-echarts-timeline--emphasis--item-style--Color: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-echarts-timeline--checkpoint-style--Color: var(--pf-v6-chart-theme--blue--ColorScale--400);
  --pf-v6-chart-echarts-timeline--checkpoint-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--white);
  --pf-v6-chart-echarts-timeline--control-style--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-timeline--control-style--BorderColor: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-timeline--control-style--BorderWidth: 1;
  --pf-v6-chart-echarts-timeline--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-timeline--item-style--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-timeline--line-style--Color: var(--pf-v6-chart-global--Fill--Color--900);
  --pf-v6-chart-echarts-timeline--line-style--Width: 2;
  --pf-v6-chart-echarts-radar--item-style--BorderWidth: 1;
  --pf-v6-chart-echarts-radar--line-style--BorderWidth: 2;
  --pf-v6-chart-echarts-radar--Smooth: false;
  --pf-v6-chart-echarts-radar--SymbolSize: 4;
  --pf-v6-chart-echarts-radar--Symbol: "square";
}