/// <reference types="react" />
export interface EmptyStateIconProps {
    /** Additional classes added to the empty state icon */
    className?: string;
    /** Icon component to be rendered. Can also be a spinner component */
    icon: React.ComponentType<any>;
}
export declare const EmptyStateIcon: React.FunctionComponent<EmptyStateIconProps>;
//# sourceMappingURL=EmptyStateIcon.d.ts.map