"use strict"
exports.__esModule = true;
exports.OutlinedStopCircleIconConfig = {
  name: 'OutlinedStopCircleIcon',
  height: 512,
  width: 512,
  svgPath: "M504 256C504 119 393 8 256 8S8 119 8 256s111 248 248 248 248-111 248-248zm-448 0c0-110.5 89.5-200 200-200s200 89.5 200 200-89.5 200-200 200S56 366.5 56 256zm296-80v160c0 8.8-7.2 16-16 16H176c-8.8 0-16-7.2-16-16V176c0-8.8 7.2-16 16-16h160c8.8 0 16 7.2 16 16z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.OutlinedStopCircleIcon = require('../createIcon').createIcon(exports.OutlinedStopCircleIconConfig);
exports["default"] = exports.OutlinedStopCircleIcon;