/// <reference types="react" />
export interface FormAlertProps extends React.HTMLProps<HTMLDivElement> {
    /** An inline PatternFly Alert. */
    children?: React.ReactNode;
    /** Additional classes added to the FormGroup. */
    className?: string;
}
export declare const FormAlert: React.FunctionComponent<FormAlertProps>;
//# sourceMappingURL=FormAlert.d.ts.map