import './jump-links.css';
declare const _default: {
  "dirRtl": "pf-v6-m-dir-rtl",
  "jumpLinks": "pf-v6-c-jump-links",
  "jumpLinksItem": "pf-v6-c-jump-links__item",
  "jumpLinksLabel": "pf-v6-c-jump-links__label",
  "jumpLinksLink": "pf-v6-c-jump-links__link",
  "jumpLinksLinkText": "pf-v6-c-jump-links__link-text",
  "jumpLinksList": "pf-v6-c-jump-links__list",
  "jumpLinksMain": "pf-v6-c-jump-links__main",
  "jumpLinksToggle": "pf-v6-c-jump-links__toggle",
  "jumpLinksToggleIcon": "pf-v6-c-jump-links__toggle-icon",
  "modifiers": {
    "center": "pf-m-center",
    "vertical": "pf-m-vertical",
    "expandable": "pf-m-expandable",
    "nonExpandable": "pf-m-non-expandable",
    "expandableOnSm": "pf-m-expandable-on-sm",
    "nonExpandableOnSm": "pf-m-non-expandable-on-sm",
    "expandableOnMd": "pf-m-expandable-on-md",
    "nonExpandableOnMd": "pf-m-non-expandable-on-md",
    "expandableOnLg": "pf-m-expandable-on-lg",
    "nonExpandableOnLg": "pf-m-non-expandable-on-lg",
    "expandableOnXl": "pf-m-expandable-on-xl",
    "nonExpandableOnXl": "pf-m-non-expandable-on-xl",
    "expandableOn_2xl": "pf-m-expandable-on-2xl",
    "nonExpandableOn_2xl": "pf-m-non-expandable-on-2xl",
    "expanded": "pf-m-expanded",
    "current": "pf-m-current"
  }
};
export default _default;