import { jsx as _jsx } from "react/jsx-runtime";
import { css } from '@patternfly/react-styles';
import styles from '@patternfly/react-styles/css/components/Wizard/wizard.mjs';
export const WizardFooter = ({ children }) => (_jsx("footer", { className: css(styles.wizardFooter), children: children }));
WizardFooter.displayName = 'WizardFooter';
//# sourceMappingURL=WizardFooter.js.map