/// <reference types="react" />
export interface TabTitleIconProps extends React.HTMLProps<HTMLSpanElement> {
    /** Icon to be rendered inside the tab button title. */
    children: React.ReactNode;
    /** additional classes added to the tab title icon */
    className?: string;
}
export declare const TabTitleIcon: React.FunctionComponent<TabTitleIconProps>;
//# sourceMappingURL=TabTitleIcon.d.ts.map