/// <reference types="react" />
export interface ModalBoxDescriptionProps {
    /** Content rendered inside the description. */
    children?: React.ReactNode;
    /** Additional classes added to the description. */
    className?: string;
    /** Id of the description. */
    id?: string;
}
export declare const ModalBoxDescription: React.FunctionComponent<ModalBoxDescriptionProps>;
//# sourceMappingURL=ModalBoxDescription.d.ts.map