import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const MehBlankIconConfig: {
  name: 'MehBlankIcon',
  height: 512,
  width: 496,
  svgPath: "M248 8C111 8 0 119 0 256s111 248 248 248 248-111 248-248S385 8 248 8zm-80 232c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32zm160 0c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const MehBlankIcon: ComponentClass<SVGIconProps>;
export default MehBlankIcon;