/// <reference types="react" />
export interface CardExpandableContentProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the Card Body */
    children?: React.ReactNode;
    /** Additional classes added to the Card Body */
    className?: string;
}
export declare const CardExpandableContent: React.FunctionComponent<CardExpandableContentProps>;
//# sourceMappingURL=CardExpandableContent.d.ts.map