"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccordionItemContext = exports.AccordionContext = void 0;
const react_1 = require("react");
exports.AccordionContext = (0, react_1.createContext)({});
exports.AccordionItemContext = (0, react_1.createContext)({});
//# sourceMappingURL=AccordionContext.js.map