import type { Duration } from "./gen/google/protobuf/duration_pb.js";
/**
 * Create a google.protobuf.Duration message from a Unix timestamp in milliseconds.
 */
export declare function durationFromMs(durationMs: number): Duration;
/**
 * Convert a google.protobuf.Duration to a Unix timestamp in milliseconds.
 */
export declare function durationMs(duration: Duration): number;
