"use strict";
exports.__esModule = true;
require('./file-upload.css');
exports.default = {
  "button": "pf-v6-c-button",
  "fileUpload": "pf-v6-c-file-upload",
  "fileUploadFileDetails": "pf-v6-c-file-upload__file-details",
  "fileUploadFileDetailsSpinner": "pf-v6-c-file-upload__file-details-spinner",
  "fileUploadFileSelect": "pf-v6-c-file-upload__file-select",
  "formControl": "pf-v6-c-form-control",
  "modifiers": {
    "dragHover": "pf-m-drag-hover",
    "loading": "pf-m-loading",
    "control": "pf-m-control"
  }
};