/// <reference types="react" />
interface PopoverContextProps {
    headerComponent?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6';
}
export declare const PopoverContext: import("react").Context<Partial<PopoverContextProps>>;
export {};
//# sourceMappingURL=PopoverContext.d.ts.map