/// <reference types="react" />
export interface DescriptionListGroupProps extends React.HTMLProps<HTMLDivElement> {
    /** Any elements that can be rendered in the list group */
    children?: any;
    /** Additional classes added to the DescriptionListGroup */
    className?: string;
}
export declare const DescriptionListGroup: React.FunctionComponent<DescriptionListGroupProps>;
//# sourceMappingURL=DescriptionListGroup.d.ts.map