.pf-v6-c-overflow-menu {
  --pf-v6-c-overflow-menu--ColumnGap: var(--pf-t--global--spacer--md);
  --pf-v6-c-overflow-menu__group--ColumnGap: var(--pf-t--global--spacer--md);
  --pf-v6-c-overflow-menu__group--m-button-group--ColumnGap: var(--pf-t--global--spacer--sm);
  --pf-v6-c-overflow-menu__group--m-icon-button-group--ColumnGap: var(--pf-t--global--spacer--xs);
}

.pf-v6-c-overflow-menu {
  display: inline-flex;
  column-gap: var(--pf-v6-c-overflow-menu--ColumnGap);
}

.pf-v6-c-overflow-menu__content,
.pf-v6-c-overflow-menu__group {
  display: flex;
  align-items: start;
}

.pf-v6-c-overflow-menu__group {
  column-gap: var(--pf-v6-c-overflow-menu__group--ColumnGap);
}
.pf-v6-c-overflow-menu__group.pf-m-button-group {
  column-gap: var(--pf-v6-c-overflow-menu__group--m-button-group--ColumnGap);
}
.pf-v6-c-overflow-menu__group.pf-m-icon-button-group {
  column-gap: var(--pf-v6-c-overflow-menu__group--m-icon-button-group--ColumnGap);
}

.pf-v6-c-overflow-menu__item {
  column-gap: var(--pf-v6-c-overflow-menu__item--ColumnGap, var(--pf-v6-c-overflow-menu--ColumnGap));
}

.pf-v6-c-overflow-menu__content,
.pf-v6-c-overflow-menu__control {
  column-gap: var(--pf-v6-c-overflow-menu--ColumnGap);
}