/// <reference types="react" />
export interface DrawerActionsProps extends React.HTMLProps<HTMLDivElement> {
    /** Additional classes added to the drawer actions button. */
    className?: string;
    /** Actions to be rendered in the panel head. */
    children?: React.ReactNode;
}
export declare const DrawerActions: React.FunctionComponent<DrawerActionsProps>;
//# sourceMappingURL=DrawerActions.d.ts.map