/// <reference types="react" />
export declare const PopoverContent: React.FunctionComponent<PopoverContentProps>;
export interface PopoverContentProps extends React.HTMLProps<HTMLDivElement> {
    /** PopoverContent additional class */
    className?: string;
    /** PopoverContent content */
    children: React.ReactNode;
}
//# sourceMappingURL=PopoverContent.d.ts.map