#ws-core-c-navigation-nav-with-flyout .ws-preview-html,
[id^="ws-core-c-navigation-nav-with-drilldown-menu"] .ws-preview-html {
  width: 280px;
}

#ws-core-c-navigation-nav-with-flyout .ws-preview-html {
  position: relative;
}

#ws-core-c-navigation-nav-with-flyout .pf-v6-c-menu.pf-m-flyout.pf-m-nav {
  position: absolute;
  inset-block-start: 151px;
  inset-inline-start: 265px;
}

#ws-core-c-navigation-horizontal .ws-preview-html,
#ws-core-c-navigation-horizontal-overflow .ws-preview-html {
  padding: var(--pf-t--global--spacer--md);
}

.ws-core-c-navigation .ws-preview-html {
  background: var(--pf-v6-c-page__sidebar--BackgroundColor); /* use sidebar background for vertical nav examples */
}

[id^="ws-core-c-navigation-horizontal"] .ws-preview-html {
  background: var(--pf-v6-c-masthead--BackgroundColor); /* use masthead background for horizontal nav examples */
}

[id^="ws-core-c-navigation-horizontal-subnav"] .ws-preview-html {
  background: transparent; /* reset background for horizontal subnav examples */
}
