import { createIcon } from '../createIcon';

export const WindowMinimizeIconConfig = {
  name: 'WindowMinimizeIcon',
  height: 512,
  width: 512,
  svgPath: "M464 352H48c-26.5 0-48 21.5-48 48v32c0 26.5 21.5 48 48 48h416c26.5 0 48-21.5 48-48v-32c0-26.5-21.5-48-48-48z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const WindowMinimizeIcon = createIcon(WindowMinimizeIconConfig);

export default WindowMinimizeIcon;