/// <reference types="react" />
export interface AboutModalBoxBrandProps extends React.HTMLProps<HTMLDivElement> {
    /** The URL of the image for the brand.  */
    src: string;
    /** The alternate text of the brand image.  */
    alt: string;
}
export declare const AboutModalBoxBrand: React.FunctionComponent<AboutModalBoxBrandProps>;
//# sourceMappingURL=AboutModalBoxBrand.d.ts.map