/// <reference types="react" />
export interface AccordionExpandableContentBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the accordion content body  */
    children?: React.ReactNode;
}
export declare const AccordionExpandableContentBody: React.FunctionComponent<AccordionExpandableContentBodyProps>;
//# sourceMappingURL=AccordionExpandableContentBody.d.ts.map