/// <reference types="react" />
export interface AboutModalBoxProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the about modal box */
    children: React.ReactNode;
    /** Additional classes added to the about modal box */
    className?: string;
}
export declare const AboutModalBox: React.FunctionComponent<AboutModalBoxProps>;
//# sourceMappingURL=AboutModalBox.d.ts.map