.pf-v6-c-toolbar {
  --pf-v6-c-toolbar--RowGap: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar--PaddingBlockStart: 0;
  --pf-v6-c-toolbar--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar--PaddingInlineStart: 0;
  --pf-v6-c-toolbar--PaddingInlineEnd: 0;
  --pf-v6-c-toolbar--LineHeight: var(--pf-t--global--font--line-height--body);
  --pf-v6-c-toolbar--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-toolbar--BackgroundColor: transparent;
  --pf-v6-c-toolbar--m-primary--BackgroundColor: var(--pf-t--global--background--color--primary--default);
  --pf-v6-c-toolbar--m-secondary--BackgroundColor: var(--pf-t--global--background--color--secondary--default);
  --pf-v6-c-toolbar--m-no-background--BackgroundColor: transparent;
  --pf-v6-c-toolbar__item--Width: auto;
  --pf-v6-c-toolbar__item--MinWidth: auto;
  --pf-v6-c-toolbar__item--RowGap: var(--pf-t--global--spacer--gap--group--vertical);
  --pf-v6-c-toolbar__item--ColumnGap: var(--pf-t--global--spacer--gap--group--horizontal);
  --pf-v6-c-toolbar__item--m-overflow-container--MinWidth: 0;
  --pf-v6-c-toolbar__group--RowGap: var(--pf-t--global--spacer--gap--group--vertical);
  --pf-v6-c-toolbar__group--ColumnGap: var(--pf-t--global--spacer--gap--group--horizontal);
  --pf-v6-c-toolbar__group--m-overflow-container--MinWidth: 0;
  --pf-v6-c-toolbar__content--RowGap: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar__content--PaddingInlineStart: 0;
  --pf-v6-c-toolbar__content--PaddingInlineEnd: 0;
  --pf-v6-c-toolbar__content-section--RowGap: var(--pf-t--global--spacer--gap--group--vertical);
  --pf-v6-c-toolbar__content-section--ColumnGap: var(--pf-t--global--spacer--gap--group--horizontal);
  --pf-v6-c-toolbar__expandable-content--ZIndex: var(--pf-t--global--z-index--sm);
  --pf-v6-c-toolbar__expandable-content--RowGap: var(--pf-t--global--spacer--gap--group--vertical);
  --pf-v6-c-toolbar__expandable-content--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar__expandable-content--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar__expandable-content--PaddingInlineStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar__expandable-content--PaddingInlineEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar__expandable-content--BoxShadow: var(--pf-t--global--box-shadow--md--bottom);
  --pf-v6-c-toolbar__expandable-content--BackgroundColor: var(--pf-t--global--background--color--floating--default);
  --pf-v6-c-toolbar__expandable-content--BorderBlockEndWidth: var(--pf-t--global--border--width--high-contrast--regular);
  --pf-v6-c-toolbar__expandable-content--BorderBlockEndColor: var(--pf-t--global--border--color--high-contrast);
  --pf-v6-c-toolbar--m-sticky--ZIndex: var(--pf-t--global--z-index--xs);
  --pf-v6-c-toolbar--m-sticky--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar--m-sticky--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-toolbar--m-sticky--BoxShadow: var(--pf-t--global--box-shadow--md--bottom);
  --pf-v6-c-toolbar--m-sticky--BackgroundColor: var(--pf-t--global--background--color--primary--default);
  --pf-v6-c-toolbar--m-sticky--BorderBlockEndWidth: var(--pf-t--global--border--width--high-contrast--regular);
  --pf-v6-c-toolbar--m-sticky--BorderBlockEndColor: var(--pf-t--global--border--color--high-contrast);
  --pf-v6-c-toolbar__expand-all-icon--Rotate: 0;
  --pf-v6-c-toolbar__expand-all-icon--TransitionDuration: var(--pf-t--global--motion--duration--icon--default);
  --pf-v6-c-toolbar__expand-all-icon--TransitionTimingFunction: var(--pf-t--global--motion--timing-function--default);
  --pf-v6-c-toolbar__item--m-expand-all--m-expanded__expand-all-icon--Rotate: 90deg;
  --pf-v6-c-toolbar__group--m-filter-group--ColumnGap: var(--pf-t--global--spacer--gap--control-to-control--default);
  --pf-v6-c-toolbar__item--m-label--FontWeight: var(--pf-t--global--font--weight--body--bold);
  --pf-v6-c-toolbar__group--m-label-group--ColumnGap: var(--pf-t--global--spacer--gap--text-to-element--default);
  --pf-v6-c-toolbar__group--m-action-group--ColumnGap: var(--pf-t--global--spacer--gap--action-to-action--default);
  --pf-v6-c-toolbar__group--m-action-group-plain--ColumnGap: var(--pf-t--global--spacer--gap--action-to-action--plain);
  --pf-v6-c-toolbar__group--m-action-group-inline--ColumnGap: var(--pf-t--global--spacer--gap--action-to-action--default);
}

.pf-v6-c-toolbar__content-section,
.pf-v6-c-toolbar__group,
.pf-v6-c-toolbar__item {
  --pf-v6-hidden-visible--visible--Display: flex;
  --pf-v6-hidden-visible--hidden--Display: none;
  --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  display: var(--pf-v6-hidden-visible--Display);
}
.pf-v6-c-toolbar__content-section.pf-m-hidden,
.pf-v6-c-toolbar__group.pf-m-hidden,
.pf-v6-c-toolbar__item.pf-m-hidden {
  --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
}
@media screen and (min-width: 36rem) {
  .pf-v6-c-toolbar__content-section.pf-m-hidden-on-sm,
  .pf-v6-c-toolbar__group.pf-m-hidden-on-sm,
  .pf-v6-c-toolbar__item.pf-m-hidden-on-sm {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content-section.pf-m-visible-on-sm,
  .pf-v6-c-toolbar__group.pf-m-visible-on-sm,
  .pf-v6-c-toolbar__item.pf-m-visible-on-sm {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-c-toolbar__content-section.pf-m-hidden-on-md,
  .pf-v6-c-toolbar__group.pf-m-hidden-on-md,
  .pf-v6-c-toolbar__item.pf-m-hidden-on-md {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content-section.pf-m-visible-on-md,
  .pf-v6-c-toolbar__group.pf-m-visible-on-md,
  .pf-v6-c-toolbar__item.pf-m-visible-on-md {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-c-toolbar__content-section.pf-m-hidden-on-lg,
  .pf-v6-c-toolbar__group.pf-m-hidden-on-lg,
  .pf-v6-c-toolbar__item.pf-m-hidden-on-lg {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content-section.pf-m-visible-on-lg,
  .pf-v6-c-toolbar__group.pf-m-visible-on-lg,
  .pf-v6-c-toolbar__item.pf-m-visible-on-lg {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-c-toolbar__content-section.pf-m-hidden-on-xl,
  .pf-v6-c-toolbar__group.pf-m-hidden-on-xl,
  .pf-v6-c-toolbar__item.pf-m-hidden-on-xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content-section.pf-m-visible-on-xl,
  .pf-v6-c-toolbar__group.pf-m-visible-on-xl,
  .pf-v6-c-toolbar__item.pf-m-visible-on-xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-c-toolbar__content-section.pf-m-hidden-on-2xl,
  .pf-v6-c-toolbar__group.pf-m-hidden-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-hidden-on-2xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content-section.pf-m-visible-on-2xl,
  .pf-v6-c-toolbar__group.pf-m-visible-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-visible-on-2xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}

.pf-v6-c-toolbar,
.pf-v6-c-toolbar__content {
  position: relative;
}

.pf-v6-c-toolbar__content {
  --pf-v6-hidden-visible--visible--Display: grid;
  --pf-v6-hidden-visible--hidden--Display: none;
  --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  display: var(--pf-v6-hidden-visible--Display);
  row-gap: var(--pf-v6-c-toolbar__content--RowGap);
  padding-inline-start: var(--pf-v6-c-toolbar__content--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-toolbar__content--PaddingInlineEnd);
}
.pf-v6-c-toolbar__content.pf-m-hidden {
  --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
}
@media screen and (min-width: 36rem) {
  .pf-v6-c-toolbar__content.pf-m-hidden-on-sm {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content.pf-m-visible-on-sm {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-c-toolbar__content.pf-m-hidden-on-md {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content.pf-m-visible-on-md {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-c-toolbar__content.pf-m-hidden-on-lg {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content.pf-m-visible-on-lg {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-c-toolbar__content.pf-m-hidden-on-xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content.pf-m-visible-on-xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-c-toolbar__content.pf-m-hidden-on-2xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--hidden--Display);
  }
  .pf-v6-c-toolbar__content.pf-m-visible-on-2xl {
    --pf-v6-hidden-visible--Display: var(--pf-v6-hidden-visible--visible--Display);
  }
}

.pf-v6-c-toolbar__content-section {
  flex-wrap: wrap;
  row-gap: var(--pf-v6-c-toolbar__content-section--RowGap);
  column-gap: var(--pf-v6-c-toolbar__content-section--ColumnGap);
  align-items: start;
}

.pf-v6-c-toolbar {
  display: grid;
  row-gap: var(--pf-v6-c-toolbar--RowGap);
  width: var(--pf-v6-c-toolbar--Width, auto);
  padding-block-start: var(--pf-v6-c-toolbar--PaddingBlockStart);
  padding-block-end: var(--pf-v6-c-toolbar--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-toolbar--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-toolbar--PaddingInlineEnd);
  font-size: var(--pf-v6-c-toolbar--FontSize);
  line-height: var(--pf-v6-c-toolbar--LineHeight);
  background-color: var(--pf-v6-c-toolbar--BackgroundColor);
}
.pf-v6-c-toolbar.pf-m-sticky {
  --pf-v6-c-toolbar--BackgroundColor: var(--pf-v6-c-toolbar--m-sticky--BackgroundColor);
  position: sticky;
  inset-block-start: 0;
  z-index: var(--pf-v6-c-toolbar--m-sticky--ZIndex);
  padding-block-start: var(--pf-v6-c-toolbar--m-sticky--PaddingBlockStart);
  padding-block-end: var(--pf-v6-c-toolbar--m-sticky--PaddingBlockEnd);
  border-block-end: var(--pf-v6-c-toolbar--m-sticky--BorderBlockEndWidth) solid var(--pf-v6-c-toolbar--m-sticky--BorderBlockEndColor);
  box-shadow: var(--pf-v6-c-toolbar--m-sticky--BoxShadow);
}
.pf-v6-c-toolbar.pf-m-static,
.pf-v6-c-toolbar.pf-m-static .pf-v6-c-toolbar__content {
  position: static;
}
.pf-v6-c-toolbar.pf-m-static .pf-v6-c-toolbar__expandable-content {
  position: absolute;
}
.pf-v6-c-toolbar.pf-m-full-height {
  --pf-v6-c-toolbar--PaddingBlockStart: 0;
  --pf-v6-c-toolbar--PaddingBlockEnd: 0;
}
.pf-v6-c-toolbar.pf-m-full-height .pf-v6-c-toolbar__group,
.pf-v6-c-toolbar.pf-m-full-height .pf-v6-c-toolbar__item {
  align-items: stretch;
  align-self: stretch;
}
.pf-v6-c-toolbar.pf-m-no-padding {
  --pf-v6-c-toolbar--PaddingBlockEnd: 0;
  --pf-v6-c-toolbar--m-sticky--PaddingBlockStart: 0;
  --pf-v6-c-toolbar--m-sticky--PaddingBlockEnd: 0;
}
.pf-v6-c-toolbar.pf-m-primary {
  --pf-v6-c-toolbar--BackgroundColor: var(--pf-v6-c-toolbar--m-primary--BackgroundColor);
}
.pf-v6-c-toolbar.pf-m-secondary {
  --pf-v6-c-toolbar--BackgroundColor: var(--pf-v6-c-toolbar--m-secondary--BackgroundColor);
}
.pf-v6-c-toolbar.pf-m-no-background {
  --pf-v6-c-toolbar--BackgroundColor: var(--pf-v6-c-toolbar--m-no-background--BackgroundColor);
}

.pf-v6-c-toolbar__item {
  --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width);
  --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth);
  row-gap: var(--pf-v6-c-toolbar__item--RowGap);
  column-gap: var(--pf-v6-c-toolbar__item--ColumnGap);
  width: var(--pf-v6-c-toolbar__item--Width--base);
  min-width: var(--pf-v6-c-toolbar__item--MinWidth--base);
}
@media (min-width: 36rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width-on-sm, var(--pf-v6-c-toolbar__item--Width));
  }
}
@media (min-width: 48rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width-on-md, var(--pf-v6-c-toolbar__item--Width-on-sm, var(--pf-v6-c-toolbar__item--Width)));
  }
}
@media (min-width: 62rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width-on-lg, var(--pf-v6-c-toolbar__item--Width-on-md, var(--pf-v6-c-toolbar__item--Width-on-sm, var(--pf-v6-c-toolbar__item--Width))));
  }
}
@media (min-width: 75rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width-on-xl, var(--pf-v6-c-toolbar__item--Width-on-lg, var(--pf-v6-c-toolbar__item--Width-on-md, var(--pf-v6-c-toolbar__item--Width-on-sm, var(--pf-v6-c-toolbar__item--Width)))));
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--Width--base: var(--pf-v6-c-toolbar__item--Width-on-2xl, var(--pf-v6-c-toolbar__item--Width-on-xl, var(--pf-v6-c-toolbar__item--Width-on-lg, var(--pf-v6-c-toolbar__item--Width-on-md, var(--pf-v6-c-toolbar__item--Width-on-sm, var(--pf-v6-c-toolbar__item--Width))))));
  }
}
@media (min-width: 36rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth-on-sm, var(--pf-v6-c-toolbar__item--MinWidth));
  }
}
@media (min-width: 48rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth-on-md, var(--pf-v6-c-toolbar__item--MinWidth-on-sm, var(--pf-v6-c-toolbar__item--MinWidth)));
  }
}
@media (min-width: 62rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth-on-lg, var(--pf-v6-c-toolbar__item--MinWidth-on-md, var(--pf-v6-c-toolbar__item--MinWidth-on-sm, var(--pf-v6-c-toolbar__item--MinWidth))));
  }
}
@media (min-width: 75rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth-on-xl, var(--pf-v6-c-toolbar__item--MinWidth-on-lg, var(--pf-v6-c-toolbar__item--MinWidth-on-md, var(--pf-v6-c-toolbar__item--MinWidth-on-sm, var(--pf-v6-c-toolbar__item--MinWidth)))));
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-c-toolbar__item {
    --pf-v6-c-toolbar__item--MinWidth--base: var(--pf-v6-c-toolbar__item--MinWidth-on-2xl, var(--pf-v6-c-toolbar__item--MinWidth-on-xl, var(--pf-v6-c-toolbar__item--MinWidth-on-lg, var(--pf-v6-c-toolbar__item--MinWidth-on-md, var(--pf-v6-c-toolbar__item--MinWidth-on-sm, var(--pf-v6-c-toolbar__item--MinWidth))))));
  }
}
.pf-v6-c-toolbar__item.pf-m-expand-all.pf-m-expanded {
  --pf-v6-c-toolbar__expand-all-icon--Rotate: var(--pf-v6-c-toolbar__item--m-expand-all--m-expanded__expand-all-icon--Rotate);
}
.pf-v6-c-toolbar__item.pf-m-label {
  font-weight: var(--pf-v6-c-toolbar__item--m-label--FontWeight);
}
.pf-v6-c-toolbar__item.pf-m-pagination {
  margin-inline-start: auto;
}
.pf-v6-c-toolbar__item.pf-m-pagination.pf-v6-c-pagination {
  flex-wrap: nowrap;
}
.pf-v6-c-toolbar__item.pf-m-overflow-container {
  min-width: var(--pf-v6-c-toolbar__item--m-overflow-container--MinWidth);
}

.pf-v6-c-toolbar__group {
  row-gap: var(--pf-v6-c-toolbar__group--RowGap);
  column-gap: var(--pf-v6-c-toolbar__group--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-filter-group {
  column-gap: var(--pf-v6-c-toolbar__group--m-filter-group--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-label-group {
  flex: 1;
  flex-wrap: wrap;
  column-gap: var(--pf-v6-c-toolbar__group--m-label-group--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-action-group {
  column-gap: var(--pf-v6-c-toolbar__group--m-action-group--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-action-group-plain {
  column-gap: var(--pf-v6-c-toolbar__group--m-action-group-plain--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-action-group-inline {
  flex-wrap: wrap;
  column-gap: var(--pf-v6-c-toolbar__group--m-action-group-inline--ColumnGap);
}
.pf-v6-c-toolbar__group.pf-m-overflow-container {
  min-width: var(--pf-v6-c-toolbar__group--m-overflow-container--MinWidth);
}

.pf-v6-c-toolbar__expandable-content {
  position: absolute;
  inset-block-start: 100%;
  inset-inline-start: 0;
  z-index: var(--pf-v6-c-toolbar__expandable-content--ZIndex);
  display: none;
  row-gap: var(--pf-v6-c-toolbar__expandable-content--RowGap);
  width: 100%;
  padding-block-start: var(--pf-v6-c-toolbar__expandable-content--PaddingBlockStart);
  padding-block-end: var(--pf-v6-c-toolbar__expandable-content--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-toolbar__expandable-content--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-toolbar__expandable-content--PaddingInlineEnd);
  background-color: var(--pf-v6-c-toolbar__expandable-content--BackgroundColor);
  border-block-end: var(--pf-v6-c-toolbar__expandable-content--BorderBlockEndWidth) solid var(--pf-v6-c-toolbar__expandable-content--BorderBlockEndColor);
  box-shadow: var(--pf-v6-c-toolbar__expandable-content--BoxShadow);
}
@media screen and (min-width: 62rem) {
  .pf-v6-c-toolbar__expandable-content {
    position: static;
    padding: 0;
    border-block-end: 0;
    box-shadow: none;
  }
}
.pf-v6-c-toolbar__expandable-content.pf-m-expanded,
.pf-v6-c-toolbar__expandable-content .pf-v6-c-toolbar__group {
  display: grid;
}
.pf-v6-c-toolbar__expandable-content .pf-v6-c-toolbar__item > * {
  flex-basis: 100%;
}
.pf-v6-c-toolbar__expandable-content .pf-v6-c-toolbar__group.pf-m-action-group-inline {
  display: flex;
  justify-content: center;
}

.pf-v6-c-toolbar__expand-all-icon {
  display: inline-flex;
  transition-timing-function: var(--pf-v6-c-toolbar__expand-all-icon--TransitionTimingFunction);
  transition-duration: var(--pf-v6-c-toolbar__expand-all-icon--TransitionDuration);
  transition-property: transform;
  transform: rotate(var(--pf-v6-c-toolbar__expand-all-icon--Rotate));
}
:where(.pf-v6-m-dir-rtl, [dir=rtl]) .pf-v6-c-toolbar__expand-all-icon {
  scale: -1 1;
}

.pf-v6-c-toolbar__group,
.pf-v6-c-toolbar__item {
  align-items: baseline;
}
.pf-v6-c-toolbar__group.pf-m-overflow-container,
.pf-v6-c-toolbar__item.pf-m-overflow-container {
  flex: 1;
  overflow: auto;
}

.pf-v6-c-toolbar__group.pf-m-align-start,
.pf-v6-c-toolbar__item.pf-m-align-start {
  margin-inline-start: 0;
}
.pf-v6-c-toolbar__group.pf-m-align-center,
.pf-v6-c-toolbar__item.pf-m-align-center {
  margin-inline-start: auto;
  margin-inline-end: auto;
}
.pf-v6-c-toolbar__group.pf-m-align-end,
.pf-v6-c-toolbar__item.pf-m-align-end {
  margin-inline-start: auto;
}
.pf-v6-c-toolbar__group.pf-m-flex-grow,
.pf-v6-c-toolbar__item.pf-m-flex-grow {
  flex-grow: 1;
}
.pf-v6-c-toolbar__group.pf-m-align-self-stretch,
.pf-v6-c-toolbar__item.pf-m-align-self-stretch {
  align-self: stretch;
}
.pf-v6-c-toolbar__group.pf-m-align-self-baseline,
.pf-v6-c-toolbar__item.pf-m-align-self-baseline {
  align-self: baseline;
}
.pf-v6-c-toolbar__group.pf-m-align-self-start,
.pf-v6-c-toolbar__item.pf-m-align-self-start {
  align-self: start;
}
.pf-v6-c-toolbar__group.pf-m-align-self-center,
.pf-v6-c-toolbar__item.pf-m-align-self-center {
  align-self: center;
}
.pf-v6-c-toolbar__group.pf-m-align-self-end,
.pf-v6-c-toolbar__item.pf-m-align-self-end {
  align-self: end;
}

.pf-v6-c-toolbar.pf-m-inset-none {
  padding-inline: 0;
}
.pf-v6-c-toolbar.pf-m-inset-xs {
  padding-inline: var(--pf-t--global--spacer--xs);
}
.pf-v6-c-toolbar.pf-m-inset-sm {
  padding-inline: var(--pf-t--global--spacer--sm);
}
.pf-v6-c-toolbar.pf-m-inset-md {
  padding-inline: var(--pf-t--global--spacer--md);
}
.pf-v6-c-toolbar.pf-m-inset-lg {
  padding-inline: var(--pf-t--global--spacer--lg);
}
.pf-v6-c-toolbar.pf-m-inset-xl {
  padding-inline: var(--pf-t--global--spacer--xl);
}
.pf-v6-c-toolbar.pf-m-inset-2xl {
  padding-inline: var(--pf-t--global--spacer--2xl);
}
.pf-v6-c-toolbar.pf-m-inset-3xl {
  padding-inline: var(--pf-t--global--spacer--3xl);
}
.pf-v6-c-toolbar.pf-m-inset-4xl {
  padding-inline: var(--pf-t--global--spacer--4xl);
}

.pf-v6-c-toolbar__group.pf-m-wrap,
.pf-v6-c-toolbar__item.pf-m-wrap,
.pf-v6-c-toolbar__content-section.pf-m-wrap {
  flex-wrap: wrap;
}
.pf-v6-c-toolbar__group.pf-m-nowrap,
.pf-v6-c-toolbar__item.pf-m-nowrap,
.pf-v6-c-toolbar__content-section.pf-m-nowrap {
  flex-wrap: nowrap;
}
.pf-v6-c-toolbar__group.pf-m-align-items-stretch,
.pf-v6-c-toolbar__item.pf-m-align-items-stretch,
.pf-v6-c-toolbar__content-section.pf-m-align-items-stretch {
  align-items: stretch;
}
.pf-v6-c-toolbar__group.pf-m-align-items-baseline,
.pf-v6-c-toolbar__item.pf-m-align-items-baseline,
.pf-v6-c-toolbar__content-section.pf-m-align-items-baseline {
  align-items: baseline;
}
.pf-v6-c-toolbar__group.pf-m-align-items-start,
.pf-v6-c-toolbar__item.pf-m-align-items-start,
.pf-v6-c-toolbar__content-section.pf-m-align-items-start {
  align-items: start;
}
.pf-v6-c-toolbar__group.pf-m-align-items-center,
.pf-v6-c-toolbar__item.pf-m-align-items-center,
.pf-v6-c-toolbar__content-section.pf-m-align-items-center {
  align-items: center;
}
.pf-v6-c-toolbar__group.pf-m-align-items-end,
.pf-v6-c-toolbar__item.pf-m-align-items-end,
.pf-v6-c-toolbar__content-section.pf-m-align-items-end {
  align-items: end;
}
.pf-v6-c-toolbar__group.pf-m-gap-none,
.pf-v6-c-toolbar__item.pf-m-gap-none,
.pf-v6-c-toolbar__content-section.pf-m-gap-none {
  gap: 0;
}
.pf-v6-c-toolbar__group.pf-m-gap-xs,
.pf-v6-c-toolbar__item.pf-m-gap-xs,
.pf-v6-c-toolbar__content-section.pf-m-gap-xs {
  gap: var(--pf-t--global--spacer--xs);
}
.pf-v6-c-toolbar__group.pf-m-gap-sm,
.pf-v6-c-toolbar__item.pf-m-gap-sm,
.pf-v6-c-toolbar__content-section.pf-m-gap-sm {
  gap: var(--pf-t--global--spacer--sm);
}
.pf-v6-c-toolbar__group.pf-m-gap-md,
.pf-v6-c-toolbar__item.pf-m-gap-md,
.pf-v6-c-toolbar__content-section.pf-m-gap-md {
  gap: var(--pf-t--global--spacer--md);
}
.pf-v6-c-toolbar__group.pf-m-gap-lg,
.pf-v6-c-toolbar__item.pf-m-gap-lg,
.pf-v6-c-toolbar__content-section.pf-m-gap-lg {
  gap: var(--pf-t--global--spacer--lg);
}
.pf-v6-c-toolbar__group.pf-m-gap-xl,
.pf-v6-c-toolbar__item.pf-m-gap-xl,
.pf-v6-c-toolbar__content-section.pf-m-gap-xl {
  gap: var(--pf-t--global--spacer--xl);
}
.pf-v6-c-toolbar__group.pf-m-gap-2xl,
.pf-v6-c-toolbar__item.pf-m-gap-2xl,
.pf-v6-c-toolbar__content-section.pf-m-gap-2xl {
  gap: var(--pf-t--global--spacer--2xl);
}
.pf-v6-c-toolbar__group.pf-m-gap-3xl,
.pf-v6-c-toolbar__item.pf-m-gap-3xl,
.pf-v6-c-toolbar__content-section.pf-m-gap-3xl {
  gap: var(--pf-t--global--spacer--3xl);
}
.pf-v6-c-toolbar__group.pf-m-gap-4xl,
.pf-v6-c-toolbar__item.pf-m-gap-4xl,
.pf-v6-c-toolbar__content-section.pf-m-gap-4xl {
  gap: var(--pf-t--global--spacer--4xl);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-none,
.pf-v6-c-toolbar__item.pf-m-column-gap-none,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-none {
  column-gap: 0;
}
.pf-v6-c-toolbar__group.pf-m-row-gap-none,
.pf-v6-c-toolbar__item.pf-m-row-gap-none,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-none {
  row-gap: 0;
}
.pf-v6-c-toolbar__group.pf-m-column-gap-xs,
.pf-v6-c-toolbar__item.pf-m-column-gap-xs,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-xs {
  column-gap: var(--pf-t--global--spacer--xs);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-xs,
.pf-v6-c-toolbar__item.pf-m-row-gap-xs,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-xs {
  row-gap: var(--pf-t--global--spacer--xs);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-sm,
.pf-v6-c-toolbar__item.pf-m-column-gap-sm,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-sm {
  column-gap: var(--pf-t--global--spacer--sm);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-sm,
.pf-v6-c-toolbar__item.pf-m-row-gap-sm,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-sm {
  row-gap: var(--pf-t--global--spacer--sm);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-md,
.pf-v6-c-toolbar__item.pf-m-column-gap-md,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-md {
  column-gap: var(--pf-t--global--spacer--md);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-md,
.pf-v6-c-toolbar__item.pf-m-row-gap-md,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-md {
  row-gap: var(--pf-t--global--spacer--md);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-lg,
.pf-v6-c-toolbar__item.pf-m-column-gap-lg,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-lg {
  column-gap: var(--pf-t--global--spacer--lg);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-lg,
.pf-v6-c-toolbar__item.pf-m-row-gap-lg,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-lg {
  row-gap: var(--pf-t--global--spacer--lg);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-xl,
.pf-v6-c-toolbar__item.pf-m-column-gap-xl,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-xl {
  column-gap: var(--pf-t--global--spacer--xl);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-xl,
.pf-v6-c-toolbar__item.pf-m-row-gap-xl,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-xl {
  row-gap: var(--pf-t--global--spacer--xl);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-2xl,
.pf-v6-c-toolbar__item.pf-m-column-gap-2xl,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl {
  column-gap: var(--pf-t--global--spacer--2xl);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-2xl,
.pf-v6-c-toolbar__item.pf-m-row-gap-2xl,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl {
  row-gap: var(--pf-t--global--spacer--2xl);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-3xl,
.pf-v6-c-toolbar__item.pf-m-column-gap-3xl,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl {
  column-gap: var(--pf-t--global--spacer--3xl);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-3xl,
.pf-v6-c-toolbar__item.pf-m-row-gap-3xl,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl {
  row-gap: var(--pf-t--global--spacer--3xl);
}
.pf-v6-c-toolbar__group.pf-m-column-gap-4xl,
.pf-v6-c-toolbar__item.pf-m-column-gap-4xl,
.pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl {
  column-gap: var(--pf-t--global--spacer--4xl);
}
.pf-v6-c-toolbar__group.pf-m-row-gap-4xl,
.pf-v6-c-toolbar__item.pf-m-row-gap-4xl,
.pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl {
  row-gap: var(--pf-t--global--spacer--4xl);
}

.pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show .pf-v6-c-toolbar__group,
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show .pf-v6-c-toolbar__item {
  display: flex;
  flex: 0 1 auto;
}
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show .pf-v6-c-toolbar__toggle {
  display: none;
}
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide .pf-v6-c-toolbar__group,
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide .pf-v6-c-toolbar__item {
  display: none;
}
.pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide .pf-v6-c-toolbar__toggle {
  display: inline-flex;
}

@media (min-width: 36rem) {
  .pf-v6-c-toolbar__group.pf-m-align-start-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-start-on-sm {
    margin-inline-start: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-align-center-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-center-on-sm {
    margin-inline-start: auto;
    margin-inline-end: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-align-end-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-end-on-sm {
    margin-inline-start: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-flex-grow-on-sm,
  .pf-v6-c-toolbar__item.pf-m-flex-grow-on-sm {
    flex-grow: 1;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-stretch-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-self-stretch-on-sm {
    align-self: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-baseline-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-self-baseline-on-sm {
    align-self: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-start-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-self-start-on-sm {
    align-self: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-center-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-self-center-on-sm {
    align-self: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-end-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-self-end-on-sm {
    align-self: end;
  }
  .pf-v6-c-toolbar.pf-m-inset-none-on-sm {
    padding-inline: 0;
  }
  .pf-v6-c-toolbar.pf-m-inset-xs-on-sm {
    padding-inline: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar.pf-m-inset-sm-on-sm {
    padding-inline: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar.pf-m-inset-md-on-sm {
    padding-inline: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar.pf-m-inset-lg-on-sm {
    padding-inline: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar.pf-m-inset-xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-2xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-3xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-4xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-wrap-on-sm,
  .pf-v6-c-toolbar__item.pf-m-wrap-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-wrap-on-sm {
    flex-wrap: wrap;
  }
  .pf-v6-c-toolbar__group.pf-m-nowrap-on-sm,
  .pf-v6-c-toolbar__item.pf-m-nowrap-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-nowrap-on-sm {
    flex-wrap: nowrap;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-stretch-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-items-stretch-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-stretch-on-sm {
    align-items: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-baseline-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-items-baseline-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-baseline-on-sm {
    align-items: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-start-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-items-start-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-start-on-sm {
    align-items: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-center-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-items-center-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-center-on-sm {
    align-items: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-end-on-sm,
  .pf-v6-c-toolbar__item.pf-m-align-items-end-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-end-on-sm {
    align-items: end;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-none-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-none-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-none-on-sm {
    gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xs-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-xs-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xs-on-sm {
    gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-sm-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-sm-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-sm-on-sm {
    gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-md-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-md-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-md-on-sm {
    gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-lg-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-lg-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-lg-on-sm {
    gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xl-on-sm {
    gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-2xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-2xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-2xl-on-sm {
    gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-3xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-3xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-3xl-on-sm {
    gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-4xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-gap-4xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-gap-4xl-on-sm {
    gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-none-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-none-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-none-on-sm {
    column-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-none-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-none-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-none-on-sm {
    row-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xs-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xs-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xs-on-sm {
    column-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xs-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xs-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xs-on-sm {
    row-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-sm-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-sm-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-sm-on-sm {
    column-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-sm-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-sm-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-sm-on-sm {
    row-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-md-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-md-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-md-on-sm {
    column-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-md-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-md-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-md-on-sm {
    row-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-lg-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-lg-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-lg-on-sm {
    column-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-lg-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-lg-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-lg-on-sm {
    row-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xl-on-sm {
    column-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xl-on-sm {
    row-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-2xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-2xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl-on-sm {
    column-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-2xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-2xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl-on-sm {
    row-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-3xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-3xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl-on-sm {
    column-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-3xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-3xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl-on-sm {
    row-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-4xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-column-gap-4xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl-on-sm {
    column-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-4xl-on-sm,
  .pf-v6-c-toolbar__item.pf-m-row-gap-4xl-on-sm,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl-on-sm {
    row-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-sm .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-sm .pf-v6-c-toolbar__item {
    display: flex;
    flex: 0 1 auto;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-sm .pf-v6-c-toolbar__toggle {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-sm .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-sm .pf-v6-c-toolbar__item {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-sm .pf-v6-c-toolbar__toggle {
    display: inline-flex;
  }
}
@media (min-width: 48rem) {
  .pf-v6-c-toolbar__group.pf-m-align-start-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-start-on-md {
    margin-inline-start: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-align-center-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-center-on-md {
    margin-inline-start: auto;
    margin-inline-end: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-align-end-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-end-on-md {
    margin-inline-start: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-flex-grow-on-md,
  .pf-v6-c-toolbar__item.pf-m-flex-grow-on-md {
    flex-grow: 1;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-stretch-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-self-stretch-on-md {
    align-self: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-baseline-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-self-baseline-on-md {
    align-self: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-start-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-self-start-on-md {
    align-self: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-center-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-self-center-on-md {
    align-self: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-end-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-self-end-on-md {
    align-self: end;
  }
  .pf-v6-c-toolbar.pf-m-inset-none-on-md {
    padding-inline: 0;
  }
  .pf-v6-c-toolbar.pf-m-inset-xs-on-md {
    padding-inline: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar.pf-m-inset-sm-on-md {
    padding-inline: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar.pf-m-inset-md-on-md {
    padding-inline: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar.pf-m-inset-lg-on-md {
    padding-inline: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar.pf-m-inset-xl-on-md {
    padding-inline: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-2xl-on-md {
    padding-inline: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-3xl-on-md {
    padding-inline: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-4xl-on-md {
    padding-inline: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-wrap-on-md,
  .pf-v6-c-toolbar__item.pf-m-wrap-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-wrap-on-md {
    flex-wrap: wrap;
  }
  .pf-v6-c-toolbar__group.pf-m-nowrap-on-md,
  .pf-v6-c-toolbar__item.pf-m-nowrap-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-nowrap-on-md {
    flex-wrap: nowrap;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-stretch-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-items-stretch-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-stretch-on-md {
    align-items: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-baseline-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-items-baseline-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-baseline-on-md {
    align-items: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-start-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-items-start-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-start-on-md {
    align-items: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-center-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-items-center-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-center-on-md {
    align-items: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-end-on-md,
  .pf-v6-c-toolbar__item.pf-m-align-items-end-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-end-on-md {
    align-items: end;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-none-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-none-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-none-on-md {
    gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xs-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-xs-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xs-on-md {
    gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-sm-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-sm-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-sm-on-md {
    gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-md-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-md-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-md-on-md {
    gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-lg-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-lg-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-lg-on-md {
    gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xl-on-md {
    gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-2xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-2xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-2xl-on-md {
    gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-3xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-3xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-3xl-on-md {
    gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-4xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-gap-4xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-gap-4xl-on-md {
    gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-none-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-none-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-none-on-md {
    column-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-none-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-none-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-none-on-md {
    row-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xs-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xs-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xs-on-md {
    column-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xs-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xs-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xs-on-md {
    row-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-sm-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-sm-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-sm-on-md {
    column-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-sm-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-sm-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-sm-on-md {
    row-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-md-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-md-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-md-on-md {
    column-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-md-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-md-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-md-on-md {
    row-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-lg-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-lg-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-lg-on-md {
    column-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-lg-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-lg-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-lg-on-md {
    row-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xl-on-md {
    column-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xl-on-md {
    row-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-2xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-2xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl-on-md {
    column-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-2xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-2xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl-on-md {
    row-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-3xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-3xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl-on-md {
    column-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-3xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-3xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl-on-md {
    row-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-4xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-column-gap-4xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl-on-md {
    column-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-4xl-on-md,
  .pf-v6-c-toolbar__item.pf-m-row-gap-4xl-on-md,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl-on-md {
    row-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-md .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-md .pf-v6-c-toolbar__item {
    display: flex;
    flex: 0 1 auto;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-md .pf-v6-c-toolbar__toggle {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-md .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-md .pf-v6-c-toolbar__item {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-md .pf-v6-c-toolbar__toggle {
    display: inline-flex;
  }
}
@media (min-width: 62rem) {
  .pf-v6-c-toolbar__group.pf-m-align-start-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-start-on-lg {
    margin-inline-start: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-align-center-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-center-on-lg {
    margin-inline-start: auto;
    margin-inline-end: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-align-end-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-end-on-lg {
    margin-inline-start: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-flex-grow-on-lg,
  .pf-v6-c-toolbar__item.pf-m-flex-grow-on-lg {
    flex-grow: 1;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-stretch-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-self-stretch-on-lg {
    align-self: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-baseline-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-self-baseline-on-lg {
    align-self: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-start-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-self-start-on-lg {
    align-self: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-center-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-self-center-on-lg {
    align-self: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-end-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-self-end-on-lg {
    align-self: end;
  }
  .pf-v6-c-toolbar.pf-m-inset-none-on-lg {
    padding-inline: 0;
  }
  .pf-v6-c-toolbar.pf-m-inset-xs-on-lg {
    padding-inline: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar.pf-m-inset-sm-on-lg {
    padding-inline: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar.pf-m-inset-md-on-lg {
    padding-inline: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar.pf-m-inset-lg-on-lg {
    padding-inline: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar.pf-m-inset-xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-2xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-3xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-4xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-wrap-on-lg,
  .pf-v6-c-toolbar__item.pf-m-wrap-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-wrap-on-lg {
    flex-wrap: wrap;
  }
  .pf-v6-c-toolbar__group.pf-m-nowrap-on-lg,
  .pf-v6-c-toolbar__item.pf-m-nowrap-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-nowrap-on-lg {
    flex-wrap: nowrap;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-stretch-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-items-stretch-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-stretch-on-lg {
    align-items: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-baseline-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-items-baseline-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-baseline-on-lg {
    align-items: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-start-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-items-start-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-start-on-lg {
    align-items: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-center-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-items-center-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-center-on-lg {
    align-items: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-end-on-lg,
  .pf-v6-c-toolbar__item.pf-m-align-items-end-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-end-on-lg {
    align-items: end;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-none-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-none-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-none-on-lg {
    gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xs-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-xs-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xs-on-lg {
    gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-sm-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-sm-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-sm-on-lg {
    gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-md-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-md-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-md-on-lg {
    gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-lg-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-lg-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-lg-on-lg {
    gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xl-on-lg {
    gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-2xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-2xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-2xl-on-lg {
    gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-3xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-3xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-3xl-on-lg {
    gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-4xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-gap-4xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-gap-4xl-on-lg {
    gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-none-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-none-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-none-on-lg {
    column-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-none-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-none-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-none-on-lg {
    row-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xs-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xs-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xs-on-lg {
    column-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xs-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xs-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xs-on-lg {
    row-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-sm-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-sm-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-sm-on-lg {
    column-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-sm-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-sm-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-sm-on-lg {
    row-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-md-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-md-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-md-on-lg {
    column-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-md-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-md-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-md-on-lg {
    row-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-lg-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-lg-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-lg-on-lg {
    column-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-lg-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-lg-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-lg-on-lg {
    row-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xl-on-lg {
    column-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xl-on-lg {
    row-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-2xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-2xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl-on-lg {
    column-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-2xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-2xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl-on-lg {
    row-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-3xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-3xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl-on-lg {
    column-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-3xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-3xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl-on-lg {
    row-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-4xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-column-gap-4xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl-on-lg {
    column-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-4xl-on-lg,
  .pf-v6-c-toolbar__item.pf-m-row-gap-4xl-on-lg,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl-on-lg {
    row-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-lg .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-lg .pf-v6-c-toolbar__item {
    display: flex;
    flex: 0 1 auto;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-lg .pf-v6-c-toolbar__toggle {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-lg .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-lg .pf-v6-c-toolbar__item {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-lg .pf-v6-c-toolbar__toggle {
    display: inline-flex;
  }
}
@media (min-width: 75rem) {
  .pf-v6-c-toolbar__group.pf-m-align-start-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-start-on-xl {
    margin-inline-start: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-align-center-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-center-on-xl {
    margin-inline-start: auto;
    margin-inline-end: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-align-end-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-end-on-xl {
    margin-inline-start: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-flex-grow-on-xl,
  .pf-v6-c-toolbar__item.pf-m-flex-grow-on-xl {
    flex-grow: 1;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-stretch-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-stretch-on-xl {
    align-self: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-baseline-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-baseline-on-xl {
    align-self: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-start-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-start-on-xl {
    align-self: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-center-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-center-on-xl {
    align-self: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-end-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-end-on-xl {
    align-self: end;
  }
  .pf-v6-c-toolbar.pf-m-inset-none-on-xl {
    padding-inline: 0;
  }
  .pf-v6-c-toolbar.pf-m-inset-xs-on-xl {
    padding-inline: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar.pf-m-inset-sm-on-xl {
    padding-inline: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar.pf-m-inset-md-on-xl {
    padding-inline: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar.pf-m-inset-lg-on-xl {
    padding-inline: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar.pf-m-inset-xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-2xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-3xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-4xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-wrap-on-xl,
  .pf-v6-c-toolbar__item.pf-m-wrap-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-wrap-on-xl {
    flex-wrap: wrap;
  }
  .pf-v6-c-toolbar__group.pf-m-nowrap-on-xl,
  .pf-v6-c-toolbar__item.pf-m-nowrap-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-nowrap-on-xl {
    flex-wrap: nowrap;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-stretch-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-stretch-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-stretch-on-xl {
    align-items: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-baseline-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-baseline-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-baseline-on-xl {
    align-items: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-start-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-start-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-start-on-xl {
    align-items: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-center-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-center-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-center-on-xl {
    align-items: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-end-on-xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-end-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-end-on-xl {
    align-items: end;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-none-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-none-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-none-on-xl {
    gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xs-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-xs-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xs-on-xl {
    gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-sm-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-sm-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-sm-on-xl {
    gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-md-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-md-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-md-on-xl {
    gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-lg-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-lg-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-lg-on-xl {
    gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xl-on-xl {
    gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-2xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-2xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-2xl-on-xl {
    gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-3xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-3xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-3xl-on-xl {
    gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-4xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-gap-4xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-4xl-on-xl {
    gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-none-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-none-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-none-on-xl {
    column-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-none-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-none-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-none-on-xl {
    row-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xs-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xs-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xs-on-xl {
    column-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xs-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xs-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xs-on-xl {
    row-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-sm-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-sm-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-sm-on-xl {
    column-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-sm-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-sm-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-sm-on-xl {
    row-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-md-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-md-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-md-on-xl {
    column-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-md-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-md-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-md-on-xl {
    row-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-lg-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-lg-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-lg-on-xl {
    column-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-lg-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-lg-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-lg-on-xl {
    row-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xl-on-xl {
    column-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xl-on-xl {
    row-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-2xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-2xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl-on-xl {
    column-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-2xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-2xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl-on-xl {
    row-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-3xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-3xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl-on-xl {
    column-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-3xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-3xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl-on-xl {
    row-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-4xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-4xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl-on-xl {
    column-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-4xl-on-xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-4xl-on-xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl-on-xl {
    row-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-xl .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-xl .pf-v6-c-toolbar__item {
    display: flex;
    flex: 0 1 auto;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-xl .pf-v6-c-toolbar__toggle {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-xl .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-xl .pf-v6-c-toolbar__item {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-xl .pf-v6-c-toolbar__toggle {
    display: inline-flex;
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-c-toolbar__group.pf-m-align-start-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-start-on-2xl {
    margin-inline-start: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-align-center-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-center-on-2xl {
    margin-inline-start: auto;
    margin-inline-end: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-align-end-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-end-on-2xl {
    margin-inline-start: auto;
  }
  .pf-v6-c-toolbar__group.pf-m-flex-grow-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-flex-grow-on-2xl {
    flex-grow: 1;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-stretch-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-stretch-on-2xl {
    align-self: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-baseline-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-baseline-on-2xl {
    align-self: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-start-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-start-on-2xl {
    align-self: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-center-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-center-on-2xl {
    align-self: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-self-end-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-self-end-on-2xl {
    align-self: end;
  }
  .pf-v6-c-toolbar.pf-m-inset-none-on-2xl {
    padding-inline: 0;
  }
  .pf-v6-c-toolbar.pf-m-inset-xs-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar.pf-m-inset-sm-on-2xl {
    padding-inline: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar.pf-m-inset-md-on-2xl {
    padding-inline: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar.pf-m-inset-lg-on-2xl {
    padding-inline: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar.pf-m-inset-xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-2xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-3xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar.pf-m-inset-4xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-wrap-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-wrap-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-wrap-on-2xl {
    flex-wrap: wrap;
  }
  .pf-v6-c-toolbar__group.pf-m-nowrap-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-nowrap-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-nowrap-on-2xl {
    flex-wrap: nowrap;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-stretch-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-stretch-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-stretch-on-2xl {
    align-items: stretch;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-baseline-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-baseline-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-baseline-on-2xl {
    align-items: baseline;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-start-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-start-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-start-on-2xl {
    align-items: start;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-center-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-center-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-center-on-2xl {
    align-items: center;
  }
  .pf-v6-c-toolbar__group.pf-m-align-items-end-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-align-items-end-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-align-items-end-on-2xl {
    align-items: end;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-none-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-none-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-none-on-2xl {
    gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xs-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-xs-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xs-on-2xl {
    gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-sm-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-sm-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-sm-on-2xl {
    gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-md-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-md-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-md-on-2xl {
    gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-lg-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-lg-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-lg-on-2xl {
    gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-xl-on-2xl {
    gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-2xl-on-2xl {
    gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-3xl-on-2xl {
    gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-gap-4xl-on-2xl {
    gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-none-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-none-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-none-on-2xl {
    column-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-none-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-none-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-none-on-2xl {
    row-gap: 0;
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xs-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xs-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xs-on-2xl {
    column-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xs-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xs-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xs-on-2xl {
    row-gap: var(--pf-t--global--spacer--xs);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-sm-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-sm-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-sm-on-2xl {
    column-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-sm-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-sm-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-sm-on-2xl {
    row-gap: var(--pf-t--global--spacer--sm);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-md-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-md-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-md-on-2xl {
    column-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-md-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-md-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-md-on-2xl {
    row-gap: var(--pf-t--global--spacer--md);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-lg-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-lg-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-lg-on-2xl {
    column-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-lg-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-lg-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-lg-on-2xl {
    row-gap: var(--pf-t--global--spacer--lg);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-xl-on-2xl {
    column-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-xl-on-2xl {
    row-gap: var(--pf-t--global--spacer--xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-2xl-on-2xl {
    column-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-2xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-2xl-on-2xl {
    row-gap: var(--pf-t--global--spacer--2xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-3xl-on-2xl {
    column-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-3xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-3xl-on-2xl {
    row-gap: var(--pf-t--global--spacer--3xl);
  }
  .pf-v6-c-toolbar__group.pf-m-column-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-column-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-column-gap-4xl-on-2xl {
    column-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group.pf-m-row-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__item.pf-m-row-gap-4xl-on-2xl,
  .pf-v6-c-toolbar__content-section.pf-m-row-gap-4xl-on-2xl {
    row-gap: var(--pf-t--global--spacer--4xl);
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-2xl .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-2xl .pf-v6-c-toolbar__item {
    display: flex;
    flex: 0 1 auto;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-show-on-2xl .pf-v6-c-toolbar__toggle {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__item, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-2xl .pf-v6-c-toolbar__group,
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-2xl .pf-v6-c-toolbar__item {
    display: none;
  }
  .pf-v6-c-toolbar__group:where(.pf-m-toggle-group) .pf-v6-c-toolbar__toggle, .pf-v6-c-toolbar__group:where(.pf-m-toggle-group).pf-m-hide-on-2xl .pf-v6-c-toolbar__toggle {
    display: inline-flex;
  }
}