"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Flex = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_styles_1 = require("@patternfly/react-styles");
const flex_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/layouts/Flex/flex"));
const flexToken = tslib_1.__importStar(require('@patternfly/react-tokens/dist/js/l_flex_item_Order'));
const util_1 = require("../../helpers/util");
const Flex = (_a) => {
    var { children = null, className = '', component = 'div', spacer, spaceItems, gap, rowGap, columnGap, grow, shrink, flex, direction, alignItems, alignContent, alignSelf, align, justifyContent, display, fullWidth, flexWrap, order, style } = _a, props = tslib_1.__rest(_a, ["children", "className", "component", "spacer", "spaceItems", "gap", "rowGap", "columnGap", "grow", "shrink", "flex", "direction", "alignItems", "alignContent", "alignSelf", "align", "justifyContent", "display", "fullWidth", "flexWrap", "order", "style"]);
    const Component = component;
    return ((0, jsx_runtime_1.jsx)(Component, Object.assign({ className: (0, react_styles_1.css)(flex_1.default.flex, (0, util_1.formatBreakpointMods)(spacer, flex_1.default), (0, util_1.formatBreakpointMods)(spaceItems, flex_1.default), (0, util_1.formatBreakpointMods)(grow, flex_1.default), (0, util_1.formatBreakpointMods)(shrink, flex_1.default), (0, util_1.formatBreakpointMods)(flex, flex_1.default), (0, util_1.formatBreakpointMods)(direction, flex_1.default), (0, util_1.formatBreakpointMods)(alignItems, flex_1.default), (0, util_1.formatBreakpointMods)(alignContent, flex_1.default), (0, util_1.formatBreakpointMods)(alignSelf, flex_1.default), (0, util_1.formatBreakpointMods)(align, flex_1.default), (0, util_1.formatBreakpointMods)(justifyContent, flex_1.default), (0, util_1.formatBreakpointMods)(display, flex_1.default), (0, util_1.formatBreakpointMods)(fullWidth, flex_1.default), (0, util_1.formatBreakpointMods)(flexWrap, flex_1.default), (0, util_1.formatBreakpointMods)(gap, flex_1.default), (0, util_1.formatBreakpointMods)(rowGap, flex_1.default), (0, util_1.formatBreakpointMods)(columnGap, flex_1.default), className), style: style || order ? Object.assign(Object.assign({}, style), (0, util_1.setBreakpointCssVars)(order, flexToken.l_flex_item_Order.name)) : undefined }, props, { children: children })));
};
exports.Flex = Flex;
exports.Flex.displayName = 'Flex';
//# sourceMappingURL=Flex.js.map