"use strict";
exports.__esModule = true;
require('./tile.css');
exports.default = {
  "modifiers": {
    "selected": "pf-m-selected",
    "disabled": "pf-m-disabled",
    "displayLg": "pf-m-display-lg",
    "stacked": "pf-m-stacked"
  },
  "tile": "pf-v6-c-tile",
  "tileBody": "pf-v6-c-tile__body",
  "tileHeader": "pf-v6-c-tile__header",
  "tileIcon": "pf-v6-c-tile__icon",
  "tileTitle": "pf-v6-c-tile__title"
};