/// <reference types="react" />
export interface NotificationDrawerBodyProps extends React.HTMLProps<HTMLDivElement> {
    /**  Content rendered inside the body of the notification drawer */
    children?: React.ReactNode;
    /**  Additional classes added to the notification drawer body */
    className?: string;
}
export declare const NotificationDrawerBody: React.FunctionComponent<NotificationDrawerBodyProps>;
//# sourceMappingURL=NotificationDrawerBody.d.ts.map