import { Modifier } from '../types';
/**
 * @param modifiers
 */
export default function mergeByName(modifiers: Partial<Modifier<any, any>>[]): Partial<Modifier<any, any>>[];
//# sourceMappingURL=mergeByName.d.ts.map