import { WizardFooterProps } from '../WizardFooter';
/**
 * Set a unique footer for the wizard. stepId is only required if inactive steps are hidden instead of unmounted.
 * @param footer
 * @param stepId
 */
export declare const useWizardFooter: (footer: React.ReactElement<any> | Partial<WizardFooterProps>, stepId?: string | number) => void;
//# sourceMappingURL=useWizardFooter.d.ts.map