"use strict";
exports.__esModule = true;
require('./drag-drop.css');
exports.default = {
  "draggable": "pf-v6-c-draggable",
  "droppable": "pf-v6-c-droppable",
  "modifiers": {
    "dragging": "pf-m-dragging",
    "dragOutside": "pf-m-drag-outside"
  }
};