import { createIcon } from '../createIcon';

export const CaretSquareDownIconConfig = {
  name: 'CaretSquareDownIcon',
  height: 512,
  width: 448,
  svgPath: "M448 80v352c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V80c0-26.5 21.5-48 48-48h352c26.5 0 48 21.5 48 48zM92.5 220.5l123 123c4.7 4.7 12.3 4.7 17 0l123-123c7.6-7.6 2.2-20.5-8.5-20.5H101c-10.7 0-16.1 12.9-8.5 20.5z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const CaretSquareDownIcon = createIcon(CaretSquareDownIconConfig);

export default CaretSquareDownIcon;