/// <reference types="react" />
export interface DescriptionListTermHelpTextButtonProps extends React.HTMLProps<HTMLSpanElement> {
    /** Anything that can be rendered inside of list term */
    children: React.ReactNode;
    /** Additional classes added to the DescriptionListTerm */
    className?: string;
}
export declare const DescriptionListTermHelpTextButton: React.FunctionComponent<DescriptionListTermHelpTextButtonProps>;
//# sourceMappingURL=DescriptionListTermHelpTextButton.d.ts.map