import { Window } from '../types';
/**
 * @param element
 */
export default function getNodeName(element: (Node | null | undefined) | Window): string | null | undefined;
//# sourceMappingURL=getNodeName.d.ts.map