#ws-react-c-label-filled-labels .pf-v6-c-label,
#ws-react-c-label-outlined-labels .pf-v6-c-label,
#ws-react-c-label-compact-labels .pf-v6-c-label {
  margin-inline-end: var(--pf-t--global--spacer--sm); 
  margin-block-end: var(--pf-t--global--spacer--sm); 
}