"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlertGroupContext = void 0;
const react_1 = require("react");
exports.AlertGroupContext = (0, react_1.createContext)({
    hasAnimations: false,
    updateTransitionEnd: () => { }
});
//# sourceMappingURL=AlertGroupContext.js.map