/// <reference types="react" />
export interface CodeBlockActionProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the code block action */
    children?: React.ReactNode;
    /** Additional classes passed to the code block action */
    className?: string;
}
export declare const CodeBlockAction: React.FunctionComponent<CodeBlockActionProps>;
//# sourceMappingURL=CodeBlockAction.d.ts.map