import { createContext } from 'react';
export const DualListSelectorContext = createContext({ isTree: false });
export const DualListSelectorListContext = createContext({});
export const DualListSelectorPaneContext = createContext({ isChosen: false });
//# sourceMappingURL=DualListSelectorContext.js.map