@use '../sass-utilities' as *;

@font-face {
  font-family: "Red Hat Text";
  font-style: normal;
  font-weight: 400 500;
  src: url("#{$pf-v6-global--font-path}/RedHatText/RedHatTextVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Text";
  font-style: italic;
  font-weight: 400 500;
  src: url("#{$pf-v6-global--font-path}/RedHatText/RedHatTextVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Display";
  font-style: normal;
  font-weight: 400 700;
  src: url("#{$pf-v6-global--font-path}/RedHatDisplay/RedHatDisplayVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Display";
  font-style: italic;
  font-weight: 400 700;
  src: url("#{$pf-v6-global--font-path}/RedHatDisplay/RedHatDisplayVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Mono";
  font-style: normal;
  font-weight: 400;
  src: url("#{$pf-v6-global--font-path}/RedHatMono/RedHatMonoVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Mono";
  font-style: italic;
  font-weight: 400;
  src: url("#{$pf-v6-global--font-path}/RedHatMono/RedHatMonoVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}
