/// <reference types="react" />
export interface MenuFooterProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the footer */
    children?: React.ReactNode;
    /** Additional classes added to the footer */
    className?: string;
}
export declare const MenuFooter: React.FunctionComponent<MenuFooterProps>;
//# sourceMappingURL=MenuFooter.d.ts.map