@use '../../sass-utilities/scss-variables.scss' as *;
@use '../../sass-utilities/init.scss' as *;

@font-face {
	font-family: 'pf-v6-pficon';
	src: url('#{$pf-v6-global--fonticon-path}/pf-v6-pficon.woff2') format('woff2');
}

@mixin pf-v6-pficon-styles {
	font-family: 'pf-v6-pficon';
		-webkit-font-smoothing: antialiased;
		-moz-osx-font-smoothing: grayscale;
	font-style: normal;
	font-variant: normal;
	font-weight: normal;
	// speak: none; // only necessary if not using the private unicode range (firstGlyph option)
	text-decoration-line: none;
	text-transform: none;
}

%pf-v6-pficon {
	@include pf-v6-pficon-styles;
}

@function pf-v6-pficon-char($filename) {
	$char: '';

	@if $filename == add-circle-o {
		$char: '\E61B';
	}
	@if $filename == ansible-tower {
		$char: '\E950';
	}
	@if $filename == applications {
		$char: '\E936';
	}
	@if $filename == arrow {
		$char: '\E929';
	}
	@if $filename == asleep {
		$char: '\E92E';
	}
	@if $filename == attention-bell {
		$char: '\E951';
	}
	@if $filename == automation {
		$char: '\E937';
	}
	@if $filename == bell {
		$char: '\E952';
	}
	@if $filename == blueprint {
		$char: '\E915';
	}
	@if $filename == build {
		$char: '\E902';
	}
	@if $filename == builder-image {
		$char: '\E800';
	}
	@if $filename == bundle {
		$char: '\E918';
	}
	@if $filename == catalog {
		$char: '\E953';
	}
	@if $filename == chat {
		$char: '\E954';
	}
	@if $filename == close {
		$char: '\E60B';
	}
	@if $filename == cloud-security {
		$char: '\E903';
	}
	@if $filename == cloud-tenant {
		$char: '\E904';
	}
	@if $filename == cluster {
		$char: '\E620';
	}
	@if $filename == connected {
		$char: '\E938';
	}
	@if $filename == container-node {
		$char: '\E621';
	}
	@if $filename == cpu {
		$char: '\E927';
	}
	@if $filename == critical-risk {
		$char: '\E976';
	}
	@if $filename == data-processor {
		$char: '\E97B';
	}
	@if $filename == data-sink {
		$char: '\E978';
	}
	@if $filename == data-source {
		$char: '\E979';
	}
	@if $filename == degraded {
		$char: '\E91B';
	}
	@if $filename == disconnected {
		$char: '\E955';
	}
	@if $filename == domain {
		$char: '\E919';
	}
	@if $filename == edit {
		$char: '\E60A';
	}
	@if $filename == enhancement {
		$char: '\E93A';
	}
	@if $filename == enterprise {
		$char: '\E906';
	}
	@if $filename == equalizer {
		$char: '\E956';
	}
	@if $filename == error-circle-o {
		$char: '\E926';
	}
	@if $filename == export {
		$char: '\E616';
	}
	@if $filename == filter {
		$char: '\E943';
	}
	@if $filename == flavor {
		$char: '\E957';
	}
	@if $filename == folder-close {
		$char: '\E607';
	}
	@if $filename == folder-open {
		$char: '\E606';
	}
	@if $filename == globe-route {
		$char: '\E958';
	}
	@if $filename == help {
		$char: '\E605';
	}
	@if $filename == history {
		$char: '\E617';
	}
	@if $filename == home {
		$char: '\E618';
	}
	@if $filename == import {
		$char: '\E615';
	}
	@if $filename == in-progress {
		$char: '\E933';
	}
	@if $filename == info {
		$char: '\E92B';
	}
	@if $filename == infrastructure {
		$char: '\E93D';
	}
	@if $filename == integration {
		$char: '\E948';
	}
	@if $filename == key {
		$char: '\E924';
	}
	@if $filename == locked {
		$char: '\E923';
	}
	@if $filename == maintenance {
		$char: '\E932';
	}
	@if $filename == memory {
		$char: '\E908';
	}
	@if $filename == messages {
		$char: '\E603';
	}
	@if $filename == middleware {
		$char: '\E917';
	}
	@if $filename == migration {
		$char: '\E931';
	}
	@if $filename == module {
		$char: '\E959';
	}
	@if $filename == monitoring {
		$char: '\E95A';
	}
	@if $filename == multicluster {
		$char: '\E97C';
	}
	@if $filename == namespaces {
		$char: '\E95B';
	}
	@if $filename == network {
		$char: '\E909';
	}
	@if $filename == new-process {
		$char: '\E95C';
	}
	@if $filename == not-started {
		$char: '\E95D';
	}
	@if $filename == off {
		$char: '\E92D';
	}
	@if $filename == ok {
		$char: '\E602';
	}
	@if $filename == on-running {
		$char: '\E925';
	}
	@if $filename == on {
		$char: '\E92C';
	}
	@if $filename == open-drawer-right {
		$char: '\E977';
	}
	@if $filename == openshift {
		$char: '\E95E';
	}
	@if $filename == openstack {
		$char: '\E95F';
	}
	@if $filename == optimize {
		$char: '\E93E';
	}
	@if $filename == orders {
		$char: '\E93F';
	}
	@if $filename == os-image {
		$char: '\E960';
	}
	@if $filename == package {
		$char: '\E961';
	}
	@if $filename == panel-close {
		$char: '\E962';
	}
	@if $filename == panel-open {
		$char: '\E963';
	}
	@if $filename == paused {
		$char: '\E92F';
	}
	@if $filename == pending {
		$char: '\E964';
	}
	@if $filename == pficon-dragdrop {
		$char: '\E965';
	}
	@if $filename == pficon-history {
		$char: '\E966';
	}
	@if $filename == pficon-network-range {
		$char: '\E967';
	}
	@if $filename == pficon-satellite {
		$char: '\E968';
	}
	@if $filename == pficon-sort-common-asc {
		$char: '\E94E';
	}
	@if $filename == pficon-sort-common-desc {
		$char: '\E94F';
	}
	@if $filename == pficon-template {
		$char: '\E94C';
	}
	@if $filename == pficon-vcenter {
		$char: '\E969';
	}
	@if $filename == plugged {
		$char: '\E96A';
	}
	@if $filename == port {
		$char: '\E96B';
	}
	@if $filename == print {
		$char: '\E612';
	}
	@if $filename == private {
		$char: '\E914';
	}
	@if $filename == process-automation {
		$char: '\E949';
	}
	@if $filename == project {
		$char: '\E96C';
	}
	@if $filename == rebalance {
		$char: '\E91C';
	}
	@if $filename == rebooting {
		$char: '\E96D';
	}
	@if $filename == regions {
		$char: '\E90A';
	}
	@if $filename == registry {
		$char: '\E623';
	}
	@if $filename == remove2 {
		$char: '\E96E';
	}
	@if $filename == replicator {
		$char: '\E624';
	}
	@if $filename == repository {
		$char: '\E90B';
	}
	@if $filename == resource-pool {
		$char: '\E90C';
	}
	@if $filename == resources-almost-empty {
		$char: '\E91D';
	}
	@if $filename == resources-almost-full {
		$char: '\E912';
	}
	@if $filename == resources-empty {
		$char: '\E96F';
	}
	@if $filename == resources-full {
		$char: '\E913';
	}
	@if $filename == running {
		$char: '\E970';
	}
	@if $filename == save {
		$char: '\E601';
	}
	@if $filename == screen {
		$char: '\E971';
	}
	@if $filename == security {
		$char: '\E946';
	}
	@if $filename == server-group {
		$char: '\E91A';
	}
	@if $filename == server {
		$char: '\E90D';
	}
	@if $filename == service-catalog {
		$char: '\E972';
	}
	@if $filename == service {
		$char: '\E61E';
	}
	@if $filename == services {
		$char: '\E947';
	}
	@if $filename == severity-critical {
		$char: '\E97E';
	}
	@if $filename == severity-important {
		$char: '\E97F';
	}
	@if $filename == severity-minor {
		$char: '\E980';
	}
	@if $filename == severity-moderate {
		$char: '\E981';
	}
	@if $filename == severity-none {
		$char: '\E982';
	}
	@if $filename == severity-undefined {
		$char: '\E983';
	}
	@if $filename == spinner {
		$char: '\E973';
	}
	@if $filename == spinner2 {
		$char: '\E613';
	}
	@if $filename == storage-domain {
		$char: '\E90E';
	}
	@if $filename == task {
		$char: '\E974';
	}
	@if $filename == tenant {
		$char: '\E916';
	}
	@if $filename == thumb-tack {
		$char: '\E920';
	}
	@if $filename == topology {
		$char: '\E608';
	}
	@if $filename == treeview {
		$char: '\E97D';
	}
	@if $filename == trend-down {
		$char: '\E900';
	}
	@if $filename == trend-up {
		$char: '\E901';
	}
	@if $filename == unknown {
		$char: '\E935';
	}
	@if $filename == unlocked {
		$char: '\E922';
	}
	@if $filename == unplugged {
		$char: '\E942';
	}
	@if $filename == user {
		$char: '\E91E';
	}
	@if $filename == users {
		$char: '\E91F';
	}
	@if $filename == virtual-machine {
		$char: '\E90F';
	}
	@if $filename == volume {
		$char: '\E910';
	}
	@if $filename == warning-triangle {
		$char: '\E975';
	}
	@if $filename == zone {
		$char: '\E911';
	}

	@return $char;
}

@mixin pf-v6-pficon($filename, $insert: before, $extend: true) {
	&:#{$insert} {
		@if $extend {
			@extend %pf-v6-pficon;
		} @else {
			@include pf-v6-pficon-styles;
		}
		content: pf-v6-pficon-char($filename);
	}
}

.pf-v6-pficon-add-circle-o {
	@include pf-v6-pficon(add-circle-o);
}
.pf-v6-pficon-ansible-tower {
	@include pf-v6-pficon(ansible-tower);
}
.pf-v6-pficon-applications {
	@include pf-v6-pficon(applications);
}
.pf-v6-pficon-arrow {
	@include pf-v6-pficon(arrow);
}
.pf-v6-pficon-asleep {
	@include pf-v6-pficon(asleep);
}
.pf-v6-pficon-attention-bell {
	@include pf-v6-pficon(attention-bell);
}
.pf-v6-pficon-automation {
	@include pf-v6-pficon(automation);
}
.pf-v6-pficon-bell {
	@include pf-v6-pficon(bell);
}
.pf-v6-pficon-blueprint {
	@include pf-v6-pficon(blueprint);
}
.pf-v6-pficon-build {
	@include pf-v6-pficon(build);
}
.pf-v6-pficon-builder-image {
	@include pf-v6-pficon(builder-image);
}
.pf-v6-pficon-bundle {
	@include pf-v6-pficon(bundle);
}
.pf-v6-pficon-catalog {
	@include pf-v6-pficon(catalog);
}
.pf-v6-pficon-chat {
	@include pf-v6-pficon(chat);
}
.pf-v6-pficon-close {
	@include pf-v6-pficon(close);
}
.pf-v6-pficon-cloud-security {
	@include pf-v6-pficon(cloud-security);
}
.pf-v6-pficon-cloud-tenant {
	@include pf-v6-pficon(cloud-tenant);
}
.pf-v6-pficon-cluster {
	@include pf-v6-pficon(cluster);
}
.pf-v6-pficon-connected {
	@include pf-v6-pficon(connected);
}
.pf-v6-pficon-container-node {
	@include pf-v6-pficon(container-node);
}
.pf-v6-pficon-cpu {
	@include pf-v6-pficon(cpu);
}
.pf-v6-pficon-critical-risk {
	@include pf-v6-pficon(critical-risk);
}
.pf-v6-pficon-data-processor {
	@include pf-v6-pficon(data-processor);
}
.pf-v6-pficon-data-sink {
	@include pf-v6-pficon(data-sink);
}
.pf-v6-pficon-data-source {
	@include pf-v6-pficon(data-source);
}
.pf-v6-pficon-degraded {
	@include pf-v6-pficon(degraded);
}
.pf-v6-pficon-disconnected {
	@include pf-v6-pficon(disconnected);
}
.pf-v6-pficon-domain {
	@include pf-v6-pficon(domain);
}
.pf-v6-pficon-edit {
	@include pf-v6-pficon(edit);
}
.pf-v6-pficon-enhancement {
	@include pf-v6-pficon(enhancement);
}
.pf-v6-pficon-enterprise {
	@include pf-v6-pficon(enterprise);
}
.pf-v6-pficon-equalizer {
	@include pf-v6-pficon(equalizer);
}
.pf-v6-pficon-error-circle-o {
	@include pf-v6-pficon(error-circle-o);
}
.pf-v6-pficon-export {
	@include pf-v6-pficon(export);
}
.pf-v6-pficon-filter {
	@include pf-v6-pficon(filter);
}
.pf-v6-pficon-flavor {
	@include pf-v6-pficon(flavor);
}
.pf-v6-pficon-folder-close {
	@include pf-v6-pficon(folder-close);
}
.pf-v6-pficon-folder-open {
	@include pf-v6-pficon(folder-open);
}
.pf-v6-pficon-globe-route {
	@include pf-v6-pficon(globe-route);
}
.pf-v6-pficon-help {
	@include pf-v6-pficon(help);
}
.pf-v6-pficon-history {
	@include pf-v6-pficon(history);
}
.pf-v6-pficon-home {
	@include pf-v6-pficon(home);
}
.pf-v6-pficon-import {
	@include pf-v6-pficon(import);
}
.pf-v6-pficon-in-progress {
	@include pf-v6-pficon(in-progress);
}
.pf-v6-pficon-info {
	@include pf-v6-pficon(info);
}
.pf-v6-pficon-infrastructure {
	@include pf-v6-pficon(infrastructure);
}
.pf-v6-pficon-integration {
	@include pf-v6-pficon(integration);
}
.pf-v6-pficon-key {
	@include pf-v6-pficon(key);
}
.pf-v6-pficon-locked {
	@include pf-v6-pficon(locked);
}
.pf-v6-pficon-maintenance {
	@include pf-v6-pficon(maintenance);
}
.pf-v6-pficon-memory {
	@include pf-v6-pficon(memory);
}
.pf-v6-pficon-messages {
	@include pf-v6-pficon(messages);
}
.pf-v6-pficon-middleware {
	@include pf-v6-pficon(middleware);
}
.pf-v6-pficon-migration {
	@include pf-v6-pficon(migration);
}
.pf-v6-pficon-module {
	@include pf-v6-pficon(module);
}
.pf-v6-pficon-monitoring {
	@include pf-v6-pficon(monitoring);
}
.pf-v6-pficon-multicluster {
	@include pf-v6-pficon(multicluster);
}
.pf-v6-pficon-namespaces {
	@include pf-v6-pficon(namespaces);
}
.pf-v6-pficon-network {
	@include pf-v6-pficon(network);
}
.pf-v6-pficon-new-process {
	@include pf-v6-pficon(new-process);
}
.pf-v6-pficon-not-started {
	@include pf-v6-pficon(not-started);
}
.pf-v6-pficon-off {
	@include pf-v6-pficon(off);
}
.pf-v6-pficon-ok {
	@include pf-v6-pficon(ok);
}
.pf-v6-pficon-on-running {
	@include pf-v6-pficon(on-running);
}
.pf-v6-pficon-on {
	@include pf-v6-pficon(on);
}
.pf-v6-pficon-open-drawer-right {
	@include pf-v6-pficon(open-drawer-right);
}
.pf-v6-pficon-openshift {
	@include pf-v6-pficon(openshift);
}
.pf-v6-pficon-openstack {
	@include pf-v6-pficon(openstack);
}
.pf-v6-pficon-optimize {
	@include pf-v6-pficon(optimize);
}
.pf-v6-pficon-orders {
	@include pf-v6-pficon(orders);
}
.pf-v6-pficon-os-image {
	@include pf-v6-pficon(os-image);
}
.pf-v6-pficon-package {
	@include pf-v6-pficon(package);
}
.pf-v6-pficon-panel-close {
	@include pf-v6-pficon(panel-close);
}
.pf-v6-pficon-panel-open {
	@include pf-v6-pficon(panel-open);
}
.pf-v6-pficon-paused {
	@include pf-v6-pficon(paused);
}
.pf-v6-pficon-pending {
	@include pf-v6-pficon(pending);
}
.pf-v6-pficon-pficon-dragdrop {
	@include pf-v6-pficon(pficon-dragdrop);
}
.pf-v6-pficon-pficon-history {
	@include pf-v6-pficon(pficon-history);
}
.pf-v6-pficon-pficon-network-range {
	@include pf-v6-pficon(pficon-network-range);
}
.pf-v6-pficon-pficon-satellite {
	@include pf-v6-pficon(pficon-satellite);
}
.pf-v6-pficon-pficon-sort-common-asc {
	@include pf-v6-pficon(pficon-sort-common-asc);
}
.pf-v6-pficon-pficon-sort-common-desc {
	@include pf-v6-pficon(pficon-sort-common-desc);
}
.pf-v6-pficon-pficon-template {
	@include pf-v6-pficon(pficon-template);
}
.pf-v6-pficon-pficon-vcenter {
	@include pf-v6-pficon(pficon-vcenter);
}
.pf-v6-pficon-plugged {
	@include pf-v6-pficon(plugged);
}
.pf-v6-pficon-port {
	@include pf-v6-pficon(port);
}
.pf-v6-pficon-print {
	@include pf-v6-pficon(print);
}
.pf-v6-pficon-private {
	@include pf-v6-pficon(private);
}
.pf-v6-pficon-process-automation {
	@include pf-v6-pficon(process-automation);
}
.pf-v6-pficon-project {
	@include pf-v6-pficon(project);
}
.pf-v6-pficon-rebalance {
	@include pf-v6-pficon(rebalance);
}
.pf-v6-pficon-rebooting {
	@include pf-v6-pficon(rebooting);
}
.pf-v6-pficon-regions {
	@include pf-v6-pficon(regions);
}
.pf-v6-pficon-registry {
	@include pf-v6-pficon(registry);
}
.pf-v6-pficon-remove2 {
	@include pf-v6-pficon(remove2);
}
.pf-v6-pficon-replicator {
	@include pf-v6-pficon(replicator);
}
.pf-v6-pficon-repository {
	@include pf-v6-pficon(repository);
}
.pf-v6-pficon-resource-pool {
	@include pf-v6-pficon(resource-pool);
}
.pf-v6-pficon-resources-almost-empty {
	@include pf-v6-pficon(resources-almost-empty);
}
.pf-v6-pficon-resources-almost-full {
	@include pf-v6-pficon(resources-almost-full);
}
.pf-v6-pficon-resources-empty {
	@include pf-v6-pficon(resources-empty);
}
.pf-v6-pficon-resources-full {
	@include pf-v6-pficon(resources-full);
}
.pf-v6-pficon-running {
	@include pf-v6-pficon(running);
}
.pf-v6-pficon-save {
	@include pf-v6-pficon(save);
}
.pf-v6-pficon-screen {
	@include pf-v6-pficon(screen);
}
.pf-v6-pficon-security {
	@include pf-v6-pficon(security);
}
.pf-v6-pficon-server-group {
	@include pf-v6-pficon(server-group);
}
.pf-v6-pficon-server {
	@include pf-v6-pficon(server);
}
.pf-v6-pficon-service-catalog {
	@include pf-v6-pficon(service-catalog);
}
.pf-v6-pficon-service {
	@include pf-v6-pficon(service);
}
.pf-v6-pficon-services {
	@include pf-v6-pficon(services);
}
.pf-v6-pficon-severity-critical {
	@include pf-v6-pficon(severity-critical);
}
.pf-v6-pficon-severity-important {
	@include pf-v6-pficon(severity-important);
}
.pf-v6-pficon-severity-minor {
	@include pf-v6-pficon(severity-minor);
}
.pf-v6-pficon-severity-moderate {
	@include pf-v6-pficon(severity-moderate);
}
.pf-v6-pficon-severity-none {
	@include pf-v6-pficon(severity-none);
}
.pf-v6-pficon-severity-undefined {
	@include pf-v6-pficon(severity-undefined);
}
.pf-v6-pficon-spinner {
	@include pf-v6-pficon(spinner);
}
.pf-v6-pficon-spinner2 {
	@include pf-v6-pficon(spinner2);
}
.pf-v6-pficon-storage-domain {
	@include pf-v6-pficon(storage-domain);
}
.pf-v6-pficon-task {
	@include pf-v6-pficon(task);
}
.pf-v6-pficon-tenant {
	@include pf-v6-pficon(tenant);
}
.pf-v6-pficon-thumb-tack {
	@include pf-v6-pficon(thumb-tack);
}
.pf-v6-pficon-topology {
	@include pf-v6-pficon(topology);
}
.pf-v6-pficon-treeview {
	@include pf-v6-pficon(treeview);
}
.pf-v6-pficon-trend-down {
	@include pf-v6-pficon(trend-down);
}
.pf-v6-pficon-trend-up {
	@include pf-v6-pficon(trend-up);
}
.pf-v6-pficon-unknown {
	@include pf-v6-pficon(unknown);
}
.pf-v6-pficon-unlocked {
	@include pf-v6-pficon(unlocked);
}
.pf-v6-pficon-unplugged {
	@include pf-v6-pficon(unplugged);
}
.pf-v6-pficon-user {
	@include pf-v6-pficon(user);
}
.pf-v6-pficon-users {
	@include pf-v6-pficon(users);
}
.pf-v6-pficon-virtual-machine {
	@include pf-v6-pficon(virtual-machine);
}
.pf-v6-pficon-volume {
	@include pf-v6-pficon(volume);
}
.pf-v6-pficon-warning-triangle {
	@include pf-v6-pficon(warning-triangle);
}
.pf-v6-pficon-zone {
	@include pf-v6-pficon(zone);
}
