import { List, ListItem } from '@patternfly/react-core';

export const ListBasic: React.FunctionComponent = () => (
  <List>
    <ListItem>First</ListItem>
    <ListItem>Second</ListItem>
    <ListItem>Third</ListItem>
  </List>
);
