"use strict";
exports.__esModule = true;
require('./date-picker.css');
exports.default = {
  "datePicker": "pf-v6-c-date-picker",
  "datePickerCalendar": "pf-v6-c-date-picker__calendar",
  "datePickerHelperText": "pf-v6-c-date-picker__helper-text",
  "datePickerInput": "pf-v6-c-date-picker__input",
  "formControl": "pf-v6-c-form-control",
  "modifiers": {
    "alignRight": "pf-m-align-right",
    "top": "pf-m-top",
    "static": "pf-m-static"
  }
};