import { Radio } from '@patternfly/react-core';

export const RadioLabelWraps: React.FunctionComponent = () => (
  <Radio isLabelWrapped label="Label wraps input example" id="radio-label-wraps-input" name="radio-4" />
);
