"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WizardFooter = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_styles_1 = require("@patternfly/react-styles");
const wizard_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Wizard/wizard"));
const WizardFooter = ({ children }) => ((0, jsx_runtime_1.jsx)("footer", { className: (0, react_styles_1.css)(wizard_1.default.wizardFooter), children: children }));
exports.WizardFooter = WizardFooter;
exports.WizardFooter.displayName = 'WizardFooter';
//# sourceMappingURL=WizardFooter.js.map