import type { MessageShape } from "./types.js";
import { type DescMessage } from "./descriptors.js";
/**
 * Create a deep copy of a message, including extensions and unknown fields.
 */
export declare function clone<Desc extends DescMessage>(schema: Desc, message: MessageShape<Desc>): MessageShape<Desc>;
