export interface SampleDataRow {
    name: string;
    threads: number;
    applications: number;
    workspaces: number;
    lastModified: string;
    url: string;
}
export declare const columns: string[];
export declare const rows: SampleDataRow[];
//# sourceMappingURL=sampleData.d.ts.map