/// <reference types="react" />
export interface ClipboardCopyActionProps extends React.HTMLProps<HTMLLIElement> {
    /** Content rendered inside the clipboard copy action. */
    children?: React.ReactNode;
    /** Additional classes added to the clipboard copy action. */
    className?: string;
}
export declare const ClipboardCopyAction: React.FunctionComponent<ClipboardCopyActionProps>;
//# sourceMappingURL=ClipboardCopyAction.d.ts.map