import { type DescMessage } from "./descriptors.js";
import type { MessageInitShape, MessageShape } from "./types.js";
/**
 * Create a new message instance.
 *
 * The second argument is an optional initializer object, where all fields are
 * optional.
 */
export declare function create<Desc extends DescMessage>(schema: Desc, init?: MessageInitShape<Desc>): MessageShape<Desc>;
