/// <reference types="react" />
interface AlertContext {
    title: React.ReactNode;
    variantLabel?: string;
}
export declare const AlertContext: import("react").Context<AlertContext>;
export {};
//# sourceMappingURL=AlertContext.d.ts.map