/// <reference types="react" />
/** Renders content in the footer of the modal */
export interface ModalFooterProps {
    /** Content rendered inside the modal footer. */
    children?: React.ReactNode;
    /** Additional classes added to the modal footer. */
    className?: string;
}
export declare const ModalFooter: React.FunctionComponent<ModalFooterProps>;
//# sourceMappingURL=ModalFooter.d.ts.map