/// <reference types="react" />
export interface PanelFooterProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the panel footer */
    children?: React.ReactNode;
    /** Class to add to outer div */
    className?: string;
}
export declare const PanelFooter: React.FunctionComponent<PanelFooterProps>;
//# sourceMappingURL=PanelFooter.d.ts.map