/// <reference types="react" />
export interface PanelMainBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the panel main body div */
    children?: React.ReactNode;
    /** Class to add to outer div */
    className?: string;
}
export declare const PanelMainBody: React.FunctionComponent<PanelMainBodyProps>;
//# sourceMappingURL=PanelMainBody.d.ts.map