.pf-v6-c-simple-list {
  --pf-v6-c-simple-list__item-link--PaddingBlockStart: var(--pf-t--global--spacer--xs);
  --pf-v6-c-simple-list__item-link--PaddingInlineEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-simple-list__item-link--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
  --pf-v6-c-simple-list__item-link--PaddingInlineStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-simple-list__item-link--BackgroundColor: var(--pf-t--global--background--color--action--plain--default);
  --pf-v6-c-simple-list__item-link--Color: var(--pf-t--global--text--color--subtle);
  --pf-v6-c-simple-list__item-link--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-simple-list__item-link--m-current--Color: var(--pf-t--global--text--color--regular);
  --pf-v6-c-simple-list__item-link--m-current--BackgroundColor: var(--pf-t--global--background--color--action--plain--clicked);
  --pf-v6-c-simple-list__item-link--hover--Color: var(--pf-t--global--text--color--subtle);
  --pf-v6-c-simple-list__item-link--hover--BackgroundColor: var(--pf-t--global--background--color--action--plain--hover);
  --pf-v6-c-simple-list__item-link--BorderRadius: var(--pf-t--global--border--radius--tiny);
  --pf-v6-c-simple-list__item-link--BorderWidth: var(--pf-t--global--border--width--action--plain--default);
  --pf-v6-c-simple-list__item-link--BorderColor: var(--pf-t--global--border--color--high-contrast);
  --pf-v6-c-simple-list__item-link--hover--BorderWidth: var(--pf-t--global--border--width--action--plain--hover);
  --pf-v6-c-simple-list__item-link--m-current--BorderWidth: var(--pf-t--global--border--width--action--plain--clicked);
  --pf-v6-c-simple-list__item-link--m-link--Color: var(--pf-t--global--text--color--link--default);
  --pf-v6-c-simple-list__item-link--m-link--m-current--Color: var(--pf-t--global--text--color--link--hover);
  --pf-v6-c-simple-list__item-link--m-link--hover--Color: var(--pf-t--global--text--color--link--hover);
  --pf-v6-c-simple-list__title--PaddingBlockStart: var(--pf-t--global--spacer--sm);
  --pf-v6-c-simple-list__title--PaddingInlineEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-simple-list__title--PaddingBlockEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-simple-list__title--PaddingInlineStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-simple-list__title--FontSize: var(--pf-t--global--font--size--body--sm);
  --pf-v6-c-simple-list__title--Color: var(--pf-t--global--text--color--regular);
  --pf-v6-c-simple-list__title--FontWeight: var(--pf-t--global--font--weight--body--bold);
  --pf-v6-c-simple-list__section--section--MarginBlockStart: var(--pf-t--global--spacer--sm);
}

.pf-v6-c-simple-list__item-link {
  position: relative;
  display: block;
  width: 100%;
  padding-block-start: var(--pf-v6-c-simple-list__item-link--PaddingBlockStart);
  padding-block-end: var(--pf-v6-c-simple-list__item-link--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-simple-list__item-link--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-simple-list__item-link--PaddingInlineEnd);
  font-size: var(--pf-v6-c-simple-list__item-link--FontSize);
  color: var(--pf-v6-c-simple-list__item-link--Color);
  text-align: start;
  text-decoration-line: none;
  background-color: var(--pf-v6-c-simple-list__item-link--BackgroundColor);
  border: none;
  border-radius: var(--pf-v6-c-simple-list__item-link--BorderRadius);
}
.pf-v6-c-simple-list__item-link::after {
  position: absolute;
  inset: 0;
  pointer-events: none;
  content: "";
  border: var(--pf-v6-c-simple-list__item-link--BorderWidth) solid var(--pf-v6-c-simple-list__item-link--BorderColor);
  border-radius: inherit;
}
.pf-v6-c-simple-list__item-link.pf-m-link {
  --pf-v6-c-simple-list__item-link--Color: var(--pf-v6-c-simple-list__item-link--m-link--Color);
  --pf-v6-c-simple-list__item-link--hover--Color: var(--pf-v6-c-simple-list__item-link--m-link--m-current--Color);
  --pf-v6-c-simple-list__item-link--m-current--Color: var(--pf-v6-c-simple-list__item-link--m-link--hover--Color);
}
.pf-v6-c-simple-list__item-link:is(:hover, :focus) {
  --pf-v6-c-simple-list__item-link--BackgroundColor: var(--pf-v6-c-simple-list__item-link--hover--BackgroundColor);
  --pf-v6-c-simple-list__item-link--Color: var(--pf-v6-c-simple-list__item-link--hover--Color);
  --pf-v6-c-simple-list__item-link--BorderWidth: var(--pf-v6-c-simple-list__item-link--hover--BorderWidth);
  text-decoration-line: none;
}
.pf-v6-c-simple-list__item-link.pf-m-current {
  --pf-v6-c-simple-list__item-link--BackgroundColor: var(--pf-v6-c-simple-list__item-link--m-current--BackgroundColor);
  --pf-v6-c-simple-list__item-link--Color: var(--pf-v6-c-simple-list__item-link--m-current--Color);
  --pf-v6-c-simple-list__item-link--BorderWidth: var(--pf-v6-c-simple-list__item-link--m-current--BorderWidth);
}

.pf-v6-c-simple-list__title {
  padding-block-start: var(--pf-v6-c-simple-list__title--PaddingBlockStart);
  padding-block-end: var(--pf-v6-c-simple-list__title--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-simple-list__title--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-simple-list__title--PaddingInlineEnd);
  font-size: var(--pf-v6-c-simple-list__title--FontSize);
  font-weight: var(--pf-v6-c-simple-list__title--FontWeight);
  color: var(--pf-v6-c-simple-list__title--Color);
}

.pf-v6-c-simple-list__section + .pf-v6-c-simple-list__section {
  margin-block-start: var(--pf-v6-c-simple-list__section--section--MarginBlockStart);
}