/// <reference types="react" />
export interface LoginMainFooterBandItemProps extends React.HTMLProps<HTMLParagraphElement> {
    /** Content rendered inside the footer link item */
    children?: React.ReactNode;
    /** Additional classes added to the footer link item  */
    className?: string;
}
export declare const LoginMainFooterBandItem: React.FunctionComponent<LoginMainFooterBandItemProps>;
//# sourceMappingURL=LoginMainFooterBandItem.d.ts.map