import { Placement } from '../enums';
/**
 * @param placement
 */
export default function getOppositeVariationPlacement(placement: Placement): Placement;
//# sourceMappingURL=getOppositeVariationPlacement.d.ts.map