import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const TengeIconConfig: {
  name: 'TengeIcon',
  height: 512,
  width: 384,
  svgPath: "M372 160H12c-6.6 0-12 5.4-12 12v56c0 6.6 5.4 12 12 12h140v228c0 6.6 5.4 12 12 12h56c6.6 0 12-5.4 12-12V240h140c6.6 0 12-5.4 12-12v-56c0-6.6-5.4-12-12-12zm0-128H12C5.4 32 0 37.4 0 44v56c0 6.6 5.4 12 12 12h360c6.6 0 12-5.4 12-12V44c0-6.6-5.4-12-12-12z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const TengeIcon: ComponentClass<SVGIconProps>;
export default TengeIcon;