import { SideObject } from '../types';
/**
 * @param paddingObject
 */
export default function mergePaddingObject(paddingObject: Partial<SideObject>): SideObject;
//# sourceMappingURL=mergePaddingObject.d.ts.map