import { Rect, VirtualElement, Window } from '../types';
/**
 * @param elementOrVirtualElement
 * @param offsetParent
 * @param isFixed
 */
export default function getCompositeRect(elementOrVirtualElement: Element | VirtualElement, offsetParent: Element | Window, isFixed?: boolean): Rect;
//# sourceMappingURL=getCompositeRect.d.ts.map