#ws-core-c-tile-basic-tiles .ws-preview-html .pf-v6-c-tile,
#ws-core-c-tile-extra-content .ws-preview-html .pf-v6-c-tile,
#ws-core-c-tile-stacked-tiles .ws-preview-html .pf-v6-c-tile,
#ws-core-c-tile-stacked-tiles-large .ws-preview-html .pf-v6-c-tile {
  margin-inline-end: 8px;
}

#ws-core-c-tile-extra-content .ws-preview-html {
  display: flex;
}

#ws-core-c-tile-extra-content .ws-preview-html .pf-v6-c-tile {
  width: 300px;
}
