import './Menu.css';
declare const _default: {
  "breadcrumbDropdown": "pf-v6-c-breadcrumb__dropdown",
  "menu": "pf-v6-c-menu",
  "menuBreadcrumb": "pf-v6-c-menu__breadcrumb"
};
export default _default;