import { Checkbox } from '@patternfly/react-core';

export const CheckboxStandaloneInput: React.FunctionComponent = () => (
  <Checkbox id="standalone-check" name="standalone-check" aria-label="Standalone input" />
);
