.pf-v6-u-m-auto {
  margin: auto !important;
}

.pf-v6-u-m-0 {
  margin: 0 !important;
}

.pf-v6-u-m-xs {
  margin: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-m-sm {
  margin: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-m-md {
  margin: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-m-lg {
  margin: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-m-xl {
  margin: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-m-2xl {
  margin: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-m-3xl {
  margin: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-m-4xl {
  margin: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mt-auto {
  margin-block-start: auto !important;
}

.pf-v6-u-mt-0 {
  margin-block-start: 0 !important;
}

.pf-v6-u-mt-xs {
  margin-block-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mt-sm {
  margin-block-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mt-md {
  margin-block-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mt-lg {
  margin-block-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mt-xl {
  margin-block-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mt-2xl {
  margin-block-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mt-3xl {
  margin-block-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mt-4xl {
  margin-block-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mr-auto {
  margin-inline-end: auto !important;
}

.pf-v6-u-mr-0 {
  margin-inline-end: 0 !important;
}

.pf-v6-u-mr-xs {
  margin-inline-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mr-sm {
  margin-inline-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mr-md {
  margin-inline-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mr-lg {
  margin-inline-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mr-xl {
  margin-inline-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mr-2xl {
  margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mr-3xl {
  margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mr-4xl {
  margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mb-auto {
  margin-block-end: auto !important;
}

.pf-v6-u-mb-0 {
  margin-block-end: 0 !important;
}

.pf-v6-u-mb-xs {
  margin-block-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mb-sm {
  margin-block-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mb-md {
  margin-block-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mb-lg {
  margin-block-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mb-xl {
  margin-block-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mb-2xl {
  margin-block-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mb-3xl {
  margin-block-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mb-4xl {
  margin-block-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-ml-auto {
  margin-inline-start: auto !important;
}

.pf-v6-u-ml-0 {
  margin-inline-start: 0 !important;
}

.pf-v6-u-ml-xs {
  margin-inline-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-ml-sm {
  margin-inline-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-ml-md {
  margin-inline-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-ml-lg {
  margin-inline-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-ml-xl {
  margin-inline-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-ml-2xl {
  margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-ml-3xl {
  margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-ml-4xl {
  margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mx-auto {
  margin-inline: auto !important;
}

.pf-v6-u-mx-0 {
  margin-inline: 0 !important;
}

.pf-v6-u-mx-xs {
  margin-inline: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mx-sm {
  margin-inline: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mx-md {
  margin-inline: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mx-lg {
  margin-inline: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mx-xl {
  margin-inline: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mx-2xl {
  margin-inline: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mx-3xl {
  margin-inline: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mx-4xl {
  margin-inline: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-my-auto {
  margin-block: auto !important;
}

.pf-v6-u-my-0 {
  margin-block: 0 !important;
}

.pf-v6-u-my-xs {
  margin-block: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-my-sm {
  margin-block: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-my-md {
  margin-block: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-my-lg {
  margin-block: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-my-xl {
  margin-block: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-my-2xl {
  margin-block: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-my-3xl {
  margin-block: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-my-4xl {
  margin-block: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-p-auto {
  padding: auto !important;
}

.pf-v6-u-p-0 {
  padding: 0 !important;
}

.pf-v6-u-p-xs {
  padding: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-p-sm {
  padding: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-p-md {
  padding: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-p-lg {
  padding: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-p-xl {
  padding: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-p-2xl {
  padding: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-p-3xl {
  padding: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-p-4xl {
  padding: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pt-auto {
  padding-block-start: auto !important;
}

.pf-v6-u-pt-0 {
  padding-block-start: 0 !important;
}

.pf-v6-u-pt-xs {
  padding-block-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pt-sm {
  padding-block-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pt-md {
  padding-block-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pt-lg {
  padding-block-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pt-xl {
  padding-block-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pt-2xl {
  padding-block-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pt-3xl {
  padding-block-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pt-4xl {
  padding-block-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pr-auto {
  padding-inline-end: auto !important;
}

.pf-v6-u-pr-0 {
  padding-inline-end: 0 !important;
}

.pf-v6-u-pr-xs {
  padding-inline-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pr-sm {
  padding-inline-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pr-md {
  padding-inline-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pr-lg {
  padding-inline-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pr-xl {
  padding-inline-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pr-2xl {
  padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pr-3xl {
  padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pr-4xl {
  padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pb-auto {
  padding-block-end: auto !important;
}

.pf-v6-u-pb-0 {
  padding-block-end: 0 !important;
}

.pf-v6-u-pb-xs {
  padding-block-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pb-sm {
  padding-block-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pb-md {
  padding-block-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pb-lg {
  padding-block-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pb-xl {
  padding-block-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pb-2xl {
  padding-block-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pb-3xl {
  padding-block-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pb-4xl {
  padding-block-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pl-auto {
  padding-inline-start: auto !important;
}

.pf-v6-u-pl-0 {
  padding-inline-start: 0 !important;
}

.pf-v6-u-pl-xs {
  padding-inline-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pl-sm {
  padding-inline-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pl-md {
  padding-inline-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pl-lg {
  padding-inline-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pl-xl {
  padding-inline-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pl-2xl {
  padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pl-3xl {
  padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pl-4xl {
  padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-px-auto {
  padding-inline: auto !important;
}

.pf-v6-u-px-0 {
  padding-inline: 0 !important;
}

.pf-v6-u-px-xs {
  padding-inline: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-px-sm {
  padding-inline: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-px-md {
  padding-inline: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-px-lg {
  padding-inline: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-px-xl {
  padding-inline: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-px-2xl {
  padding-inline: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-px-3xl {
  padding-inline: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-px-4xl {
  padding-inline: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-py-auto {
  padding-block: auto !important;
}

.pf-v6-u-py-0 {
  padding-block: 0 !important;
}

.pf-v6-u-py-xs {
  padding-block: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-py-sm {
  padding-block: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-py-md {
  padding-block: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-py-lg {
  padding-block: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-py-xl {
  padding-block: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-py-2xl {
  padding-block: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-py-3xl {
  padding-block: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-py-4xl {
  padding-block: var(--pf-t--global--spacer--4xl) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-auto-on-sm {
    margin: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-0-on-sm {
    margin: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-xs-on-sm {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-sm-on-sm {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-md-on-sm {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-lg-on-sm {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-xl-on-sm {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-2xl-on-sm {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-3xl-on-sm {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-4xl-on-sm {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-auto-on-sm {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-0-on-sm {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-xs-on-sm {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-sm-on-sm {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-md-on-sm {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-lg-on-sm {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-2xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-3xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-4xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-auto-on-sm {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-0-on-sm {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-xs-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-sm-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-md-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-lg-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-2xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-3xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-4xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-auto-on-sm {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-0-on-sm {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-xs-on-sm {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-sm-on-sm {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-md-on-sm {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-lg-on-sm {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-2xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-3xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-4xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-auto-on-sm {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-0-on-sm {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-xs-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-sm-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-md-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-lg-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-2xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-3xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-4xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-auto-on-sm {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-0-on-sm {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-xs-on-sm {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-sm-on-sm {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-md-on-sm {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-lg-on-sm {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-2xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-3xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-4xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-auto-on-sm {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-0-on-sm {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-xs-on-sm {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-sm-on-sm {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-md-on-sm {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-lg-on-sm {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-xl-on-sm {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-2xl-on-sm {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-3xl-on-sm {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-4xl-on-sm {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-auto-on-sm {
    padding: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-0-on-sm {
    padding: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-xs-on-sm {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-sm-on-sm {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-md-on-sm {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-lg-on-sm {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-xl-on-sm {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-2xl-on-sm {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-3xl-on-sm {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-4xl-on-sm {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-auto-on-sm {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-0-on-sm {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-xs-on-sm {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-sm-on-sm {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-md-on-sm {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-lg-on-sm {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-2xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-3xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-4xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-auto-on-sm {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-0-on-sm {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-xs-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-sm-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-md-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-lg-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-2xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-3xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-4xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-auto-on-sm {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-0-on-sm {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-xs-on-sm {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-sm-on-sm {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-md-on-sm {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-lg-on-sm {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-2xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-3xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-4xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-auto-on-sm {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-0-on-sm {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-xs-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-sm-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-md-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-lg-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-2xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-3xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-4xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-auto-on-sm {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-0-on-sm {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-xs-on-sm {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-sm-on-sm {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-md-on-sm {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-lg-on-sm {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-2xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-3xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-4xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-auto-on-sm {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-0-on-sm {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-xs-on-sm {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-sm-on-sm {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-md-on-sm {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-lg-on-sm {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-xl-on-sm {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-2xl-on-sm {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-3xl-on-sm {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-4xl-on-sm {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-auto-on-md {
    margin: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-0-on-md {
    margin: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-xs-on-md {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-sm-on-md {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-md-on-md {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-lg-on-md {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-xl-on-md {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-2xl-on-md {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-3xl-on-md {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-4xl-on-md {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-auto-on-md {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-0-on-md {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-xs-on-md {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-sm-on-md {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-md-on-md {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-lg-on-md {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-2xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-3xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-4xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-auto-on-md {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-0-on-md {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-xs-on-md {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-sm-on-md {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-md-on-md {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-lg-on-md {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-2xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-3xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-4xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-auto-on-md {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-0-on-md {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-xs-on-md {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-sm-on-md {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-md-on-md {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-lg-on-md {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-2xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-3xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-4xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-auto-on-md {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-0-on-md {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-xs-on-md {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-sm-on-md {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-md-on-md {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-lg-on-md {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-2xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-3xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-4xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-auto-on-md {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-0-on-md {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-xs-on-md {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-sm-on-md {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-md-on-md {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-lg-on-md {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-xl-on-md {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-2xl-on-md {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-3xl-on-md {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-4xl-on-md {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-auto-on-md {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-0-on-md {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-xs-on-md {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-sm-on-md {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-md-on-md {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-lg-on-md {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-xl-on-md {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-2xl-on-md {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-3xl-on-md {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-4xl-on-md {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-auto-on-md {
    padding: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-0-on-md {
    padding: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-xs-on-md {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-sm-on-md {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-md-on-md {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-lg-on-md {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-xl-on-md {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-2xl-on-md {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-3xl-on-md {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-4xl-on-md {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-auto-on-md {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-0-on-md {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-xs-on-md {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-sm-on-md {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-md-on-md {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-lg-on-md {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-2xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-3xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-4xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-auto-on-md {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-0-on-md {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-xs-on-md {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-sm-on-md {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-md-on-md {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-lg-on-md {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-2xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-3xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-4xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-auto-on-md {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-0-on-md {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-xs-on-md {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-sm-on-md {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-md-on-md {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-lg-on-md {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-2xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-3xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-4xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-auto-on-md {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-0-on-md {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-xs-on-md {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-sm-on-md {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-md-on-md {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-lg-on-md {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-2xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-3xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-4xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-auto-on-md {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-0-on-md {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-xs-on-md {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-sm-on-md {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-md-on-md {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-lg-on-md {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-xl-on-md {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-2xl-on-md {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-3xl-on-md {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-4xl-on-md {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-auto-on-md {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-0-on-md {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-xs-on-md {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-sm-on-md {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-md-on-md {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-lg-on-md {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-xl-on-md {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-2xl-on-md {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-3xl-on-md {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-4xl-on-md {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-auto-on-lg {
    margin: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-0-on-lg {
    margin: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-xs-on-lg {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-sm-on-lg {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-md-on-lg {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-lg-on-lg {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-xl-on-lg {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-2xl-on-lg {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-3xl-on-lg {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-4xl-on-lg {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-auto-on-lg {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-0-on-lg {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-xs-on-lg {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-sm-on-lg {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-md-on-lg {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-lg-on-lg {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-2xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-3xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-4xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-auto-on-lg {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-0-on-lg {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-xs-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-sm-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-md-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-lg-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-2xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-3xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-4xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-auto-on-lg {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-0-on-lg {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-xs-on-lg {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-sm-on-lg {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-md-on-lg {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-lg-on-lg {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-2xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-3xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-4xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-auto-on-lg {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-0-on-lg {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-xs-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-sm-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-md-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-lg-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-2xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-3xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-4xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-auto-on-lg {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-0-on-lg {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-xs-on-lg {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-sm-on-lg {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-md-on-lg {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-lg-on-lg {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-2xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-3xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-4xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-auto-on-lg {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-0-on-lg {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-xs-on-lg {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-sm-on-lg {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-md-on-lg {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-lg-on-lg {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-xl-on-lg {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-2xl-on-lg {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-3xl-on-lg {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-4xl-on-lg {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-auto-on-lg {
    padding: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-0-on-lg {
    padding: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-xs-on-lg {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-sm-on-lg {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-md-on-lg {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-lg-on-lg {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-xl-on-lg {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-2xl-on-lg {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-3xl-on-lg {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-4xl-on-lg {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-auto-on-lg {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-0-on-lg {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-xs-on-lg {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-sm-on-lg {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-md-on-lg {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-lg-on-lg {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-2xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-3xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-4xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-auto-on-lg {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-0-on-lg {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-xs-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-sm-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-md-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-lg-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-2xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-3xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-4xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-auto-on-lg {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-0-on-lg {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-xs-on-lg {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-sm-on-lg {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-md-on-lg {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-lg-on-lg {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-2xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-3xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-4xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-auto-on-lg {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-0-on-lg {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-xs-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-sm-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-md-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-lg-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-2xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-3xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-4xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-auto-on-lg {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-0-on-lg {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-xs-on-lg {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-sm-on-lg {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-md-on-lg {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-lg-on-lg {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-2xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-3xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-4xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-auto-on-lg {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-0-on-lg {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-xs-on-lg {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-sm-on-lg {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-md-on-lg {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-lg-on-lg {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-xl-on-lg {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-2xl-on-lg {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-3xl-on-lg {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-4xl-on-lg {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-auto-on-xl {
    margin: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-0-on-xl {
    margin: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-xs-on-xl {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-sm-on-xl {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-md-on-xl {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-lg-on-xl {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-xl-on-xl {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-2xl-on-xl {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-3xl-on-xl {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-4xl-on-xl {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-auto-on-xl {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-0-on-xl {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-xs-on-xl {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-sm-on-xl {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-md-on-xl {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-lg-on-xl {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-2xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-3xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-4xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-auto-on-xl {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-0-on-xl {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-xs-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-sm-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-md-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-lg-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-2xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-3xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-4xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-auto-on-xl {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-0-on-xl {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-xs-on-xl {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-sm-on-xl {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-md-on-xl {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-lg-on-xl {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-2xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-3xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-4xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-auto-on-xl {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-0-on-xl {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-xs-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-sm-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-md-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-lg-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-2xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-3xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-4xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-auto-on-xl {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-0-on-xl {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-xs-on-xl {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-sm-on-xl {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-md-on-xl {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-lg-on-xl {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-2xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-3xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-4xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-auto-on-xl {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-0-on-xl {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-xs-on-xl {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-sm-on-xl {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-md-on-xl {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-lg-on-xl {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-xl-on-xl {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-2xl-on-xl {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-3xl-on-xl {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-4xl-on-xl {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-auto-on-xl {
    padding: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-0-on-xl {
    padding: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-xs-on-xl {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-sm-on-xl {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-md-on-xl {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-lg-on-xl {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-xl-on-xl {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-2xl-on-xl {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-3xl-on-xl {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-4xl-on-xl {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-auto-on-xl {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-0-on-xl {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-xs-on-xl {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-sm-on-xl {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-md-on-xl {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-lg-on-xl {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-2xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-3xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-4xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-auto-on-xl {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-0-on-xl {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-xs-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-sm-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-md-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-lg-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-2xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-3xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-4xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-auto-on-xl {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-0-on-xl {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-xs-on-xl {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-sm-on-xl {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-md-on-xl {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-lg-on-xl {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-2xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-3xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-4xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-auto-on-xl {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-0-on-xl {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-xs-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-sm-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-md-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-lg-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-2xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-3xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-4xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-auto-on-xl {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-0-on-xl {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-xs-on-xl {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-sm-on-xl {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-md-on-xl {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-lg-on-xl {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-2xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-3xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-4xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-auto-on-xl {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-0-on-xl {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-xs-on-xl {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-sm-on-xl {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-md-on-xl {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-lg-on-xl {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-xl-on-xl {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-2xl-on-xl {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-3xl-on-xl {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-4xl-on-xl {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-auto-on-2xl {
    margin: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-0-on-2xl {
    margin: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-xs-on-2xl {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-sm-on-2xl {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-md-on-2xl {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-lg-on-2xl {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-xl-on-2xl {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-2xl-on-2xl {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-3xl-on-2xl {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-4xl-on-2xl {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-auto-on-2xl {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-0-on-2xl {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-xs-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-sm-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-md-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-lg-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-2xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-3xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-4xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-auto-on-2xl {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-0-on-2xl {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-xs-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-sm-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-md-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-lg-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-2xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-3xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-4xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-auto-on-2xl {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-0-on-2xl {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-xs-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-sm-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-md-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-lg-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-2xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-3xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-4xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-auto-on-2xl {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-0-on-2xl {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-xs-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-sm-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-md-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-lg-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-2xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-3xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-4xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-auto-on-2xl {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-0-on-2xl {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-xs-on-2xl {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-sm-on-2xl {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-md-on-2xl {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-lg-on-2xl {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-2xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-3xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-4xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-auto-on-2xl {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-0-on-2xl {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-xs-on-2xl {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-sm-on-2xl {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-md-on-2xl {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-lg-on-2xl {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-2xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-3xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-4xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-auto-on-2xl {
    padding: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-0-on-2xl {
    padding: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-xs-on-2xl {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-sm-on-2xl {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-md-on-2xl {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-lg-on-2xl {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-xl-on-2xl {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-2xl-on-2xl {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-3xl-on-2xl {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-4xl-on-2xl {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-auto-on-2xl {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-0-on-2xl {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-xs-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-sm-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-md-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-lg-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-2xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-3xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-4xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-auto-on-2xl {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-0-on-2xl {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-xs-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-sm-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-md-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-lg-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-2xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-3xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-4xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-auto-on-2xl {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-0-on-2xl {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-xs-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-sm-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-md-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-lg-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-2xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-3xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-4xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-auto-on-2xl {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-0-on-2xl {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-xs-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-sm-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-md-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-lg-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-2xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-3xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-4xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-auto-on-2xl {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-0-on-2xl {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-xs-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-sm-on-2xl {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-md-on-2xl {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-lg-on-2xl {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-2xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-3xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-4xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-auto-on-2xl {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-0-on-2xl {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-xs-on-2xl {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-sm-on-2xl {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-md-on-2xl {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-lg-on-2xl {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-2xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-3xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-4xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}