/// <reference types="react" />
import { AlertGroupProps } from './AlertGroup';
export declare const AlertGroupInline: React.FunctionComponent<AlertGroupProps>;
//# sourceMappingURL=AlertGroupInline.d.ts.map