"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LevelItem = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const LevelItem = (_a) => {
    var { children = null } = _a, props = tslib_1.__rest(_a, ["children"]);
    return ((0, jsx_runtime_1.jsx)("div", Object.assign({}, props, { children: children })));
};
exports.LevelItem = LevelItem;
exports.LevelItem.displayName = 'LevelItem';
//# sourceMappingURL=LevelItem.js.map