/// <reference types="react" />
export interface TooltipArrowProps extends React.HTMLProps<HTMLDivElement> {
    /** className */
    className?: string;
}
export declare const TooltipArrow: React.FunctionComponent<TooltipArrowProps>;
//# sourceMappingURL=TooltipArrow.d.ts.map