/// <reference types="react" />
export interface EmptyStateBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the empty state body */
    children?: React.ReactNode;
    /** Additional classes added to the empty state body */
    className?: string;
}
export declare const EmptyStateBody: React.FunctionComponent<EmptyStateBodyProps>;
//# sourceMappingURL=EmptyStateBody.d.ts.map