import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const ParagraphIconConfig: {
  name: 'ParagraphIcon',
  height: 512,
  width: 448,
  svgPath: "M448 48v32a16 16 0 0 1-16 16h-48v368a16 16 0 0 1-16 16h-32a16 16 0 0 1-16-16V96h-32v368a16 16 0 0 1-16 16h-32a16 16 0 0 1-16-16V352h-32a160 160 0 0 1 0-320h240a16 16 0 0 1 16 16z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const ParagraphIcon: ComponentClass<SVGIconProps>;
export default ParagraphIcon;