import './Label.css';
declare const _default: {
  "label": "pf-v6-c-label",
  "labelTruncateExample": "pf-v6-c-label-truncate--example",
  "wsPreviewHtml": "ws-preview-html"
};
export default _default;