"use strict";
exports.__esModule = true;
require('./overflow-menu.css');
exports.default = {
  "overflowMenuGroup": "pf-v6-c-overflow-menu__group",
  "overflowMenuItem": "pf-v6-c-overflow-menu__item"
};