/// <reference types="react" />
export interface MultipleFileUploadTitleIconProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside multiple file upload title icon */
    children?: React.ReactNode;
    /** Class to add to outer div */
    className?: string;
}
export declare const MultipleFileUploadTitleIcon: React.FunctionComponent<MultipleFileUploadTitleIconProps>;
//# sourceMappingURL=MultipleFileUploadTitleIcon.d.ts.map