"use strict"
exports.__esModule = true;
exports.EllipsisHIconConfig = {
  name: 'EllipsisHIcon',
  height: 512,
  width: 512,
  svgPath: "M328 256c0 39.8-32.2 72-72 72s-72-32.2-72-72 32.2-72 72-72 72 32.2 72 72zm104-72c-39.8 0-72 32.2-72 72s32.2 72 72 72 72-32.2 72-72-32.2-72-72-72zm-352 0c-39.8 0-72 32.2-72 72s32.2 72 72 72 72-32.2 72-72-32.2-72-72-72z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.EllipsisHIcon = require('../createIcon').createIcon(exports.EllipsisHIconConfig);
exports["default"] = exports.EllipsisHIcon;