import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const GripLinesVerticalIconConfig: {
  name: 'GripLinesVerticalIcon',
  height: 512,
  width: 256,
  svgPath: "M96 496V16c0-8.8-7.2-16-16-16H48c-8.8 0-16 7.2-16 16v480c0 8.8 7.2 16 16 16h32c8.8 0 16-7.2 16-16zm128 0V16c0-8.8-7.2-16-16-16h-32c-8.8 0-16 7.2-16 16v480c0 8.8 7.2 16 16 16h32c8.8 0 16-7.2 16-16z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const GripLinesVerticalIcon: ComponentClass<SVGIconProps>;
export default GripLinesVerticalIcon;