import './Navigation.css';
declare const _default: {
  "menu": "pf-v6-c-menu",
  "modifiers": {
    "flyout": "pf-m-flyout",
    "nav": "pf-m-nav"
  },
  "wsCoreCNavigation": "ws-core-c-navigation",
  "wsPreviewHtml": "ws-preview-html"
};
export default _default;