import { EffectCallback } from 'react';
/**
 * A `useEffect`-like hook that only triggers when a component unmounts. Does not require a dependency list, as the effect callback will always be kept up to date.
 */
export declare function useUnmountEffect(effect: EffectCallback): void;
//# sourceMappingURL=useUnmountEffect.d.ts.map