/// <reference types="react" />
interface DashboardHeaderProps {
    /** Render custom notification badge */
    notificationBadge?: React.ReactNode;
}
export declare const DashboardHeader: React.FC<DashboardHeaderProps>;
export {};
//# sourceMappingURL=DashboardHeader.d.ts.map