import { Radio } from '@patternfly/react-core';

export const RadioStandaloneInput: React.FunctionComponent = () => (
  <Radio id="radio-standalone" aria-label="Standalone input" name="exampleRadioStandalone" />
);
