import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const PlugIconConfig: {
  name: 'PlugIcon',
  height: 512,
  width: 384,
  svgPath: "M320,32a32,32,0,0,0-64,0v96h64Zm48,128H16A16,16,0,0,0,0,176v32a16,16,0,0,0,16,16H32v32A160.07,160.07,0,0,0,160,412.8V512h64V412.8A160.07,160.07,0,0,0,352,256V224h16a16,16,0,0,0,16-16V176A16,16,0,0,0,368,160ZM128,32a32,32,0,0,0-64,0v96h64Z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const PlugIcon: ComponentClass<SVGIconProps>;
export default PlugIcon;