import './number-input.css';
declare const _default: {
  "formControl": "pf-v6-c-form-control",
  "inputGroup": "pf-v6-c-input-group",
  "numberInput": "pf-v6-c-number-input",
  "numberInputIcon": "pf-v6-c-number-input__icon",
  "numberInputUnit": "pf-v6-c-number-input__unit"
};
export default _default;