import { Modifier } from '../types';
/**
 * @param modifiers
 */
export default function orderModifiers(modifiers: Modifier<any, any>[]): Modifier<any, any>[];
//# sourceMappingURL=orderModifiers.d.ts.map