import { Modifier } from '../types';
export interface Options {
    scroll: boolean;
    resize: boolean;
}
export type EventListenersModifier = Modifier<'eventListeners', Options>;
declare const _default: EventListenersModifier;
export default _default;
//# sourceMappingURL=eventListeners.d.ts.map