/// <reference types="react" />
export interface MultipleFileUploadTitleTextProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside multiple file upload title text */
    children?: React.ReactNode;
    /** Class to add to outer div */
    className?: string;
}
export declare const MultipleFileUploadTitleText: React.FunctionComponent<MultipleFileUploadTitleTextProps>;
//# sourceMappingURL=MultipleFileUploadTitleText.d.ts.map