/// <reference types="react" />
export interface PageBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the section */
    children?: React.ReactNode;
    /** Additional classes added to the section */
    className?: string;
}
export declare const PageBody: React.FunctionComponent<PageBodyProps>;
//# sourceMappingURL=PageBody.d.ts.map