/// <reference types="react" />
export interface ModalBoxFooterProps {
    /** Content rendered inside the modal box footer. */
    children?: React.ReactNode;
    /** Additional classes added to the modal box footer. */
    className?: string;
}
export declare const ModalBoxFooter: React.FunctionComponent<ModalBoxFooterProps>;
//# sourceMappingURL=ModalBoxFooter.d.ts.map