/// <reference types="react" />
export interface HintBodyProps {
    /** Content rendered inside the hint body. */
    children?: React.ReactNode;
    /** Additional classes applied to the hint body. */
    className?: string;
}
export declare const HintBody: React.FunctionComponent<HintBodyProps>;
//# sourceMappingURL=HintBody.d.ts.map