import { createIcon } from '../createIcon';

export const ChevronCircleUpIconConfig = {
  name: 'ChevronCircleUpIcon',
  height: 512,
  width: 512,
  svgPath: "M8 256C8 119 119 8 256 8s248 111 248 248-111 248-248 248S8 393 8 256zm231-113.9L103.5 277.6c-9.4 9.4-9.4 24.6 0 33.9l17 17c9.4 9.4 24.6 9.4 33.9 0L256 226.9l101.6 101.6c9.4 9.4 24.6 9.4 33.9 0l17-17c9.4-9.4 9.4-24.6 0-33.9L273 142.1c-9.4-9.4-24.6-9.4-34 0z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const ChevronCircleUpIcon = createIcon(ChevronCircleUpIconConfig);

export default ChevronCircleUpIcon;