/// <reference types="react" />
export interface NotificationDrawerGroupListProps extends React.HTMLProps<HTMLDivElement> {
    /**  Content rendered inside the notification drawer list body */
    children?: React.ReactNode;
    /**  Additional classes added to the notification drawer list body */
    className?: string;
}
export declare const NotificationDrawerGroupList: React.FunctionComponent<NotificationDrawerGroupListProps>;
//# sourceMappingURL=NotificationDrawerGroupList.d.ts.map