/// <reference types="react" />
export interface WizardFooterProps {
    /** Buttons in the footer */
    children: any;
}
export declare const WizardFooter: React.FunctionComponent<WizardFooterProps>;
//# sourceMappingURL=WizardFooter.d.ts.map