/// <reference types="react" />
export interface HintTitleProps {
    /** Content rendered inside the hint title. */
    children?: React.ReactNode;
    /** Additional classes applied to the hint title. */
    className?: string;
}
export declare const HintTitle: React.FunctionComponent<HintTitleProps>;
//# sourceMappingURL=HintTitle.d.ts.map