import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import { css } from '@patternfly/react-styles';
import styles from '@patternfly/react-styles/css/components/Login/login.mjs';
export const LoginMainBody = (_a) => {
    var { children = null, className = '' } = _a, props = __rest(_a, ["children", "className"]);
    return (_jsx("div", Object.assign({ className: css(styles.loginMainBody, className) }, props, { children: children })));
};
LoginMainBody.displayName = 'LoginMainBody';
//# sourceMappingURL=LoginMainBody.js.map