"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TooltipArrow = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const tooltip_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Tooltip/tooltip"));
const react_styles_1 = require("@patternfly/react-styles");
const TooltipArrow = (_a) => {
    var { className } = _a, props = tslib_1.__rest(_a, ["className"]);
    return (0, jsx_runtime_1.jsx)("div", Object.assign({ className: (0, react_styles_1.css)(tooltip_1.default.tooltipArrow, className) }, props));
};
exports.TooltipArrow = TooltipArrow;
exports.TooltipArrow.displayName = 'TooltipArrow';
//# sourceMappingURL=TooltipArrow.js.map