#ws-html-demos-c-card-status-card-expanded-with-popover {
  padding-block-start: 180px;
}

#ws-html-demos-c-card-status-card-expanded-with-popover #carview-demo--popover-parent,
.popover-parent {
  position: relative;
}

#ws-html-demos-c-card-status-card-expanded-with-popover .pf-v6-c-popover {
  position: absolute;
  margin-block-start: -12px;
  z-index: 1000;
  transform: translateY(-50%);
 inset-inline-start: calc(100% + var(--pf-v6-c-popover__arrow--Width) + var(--pf-t--global--spacer--sm));
}

#ws-html-demos-c-card-status-card-expanded-with-popover .pf-v6-c-table {
  --pf-v6-c-table__expandable-row--after--BorderInlineStartWidth: 0;
  --pf-v6-c-table__expandable-row--after--BorderColor: transparent;
  --pf-v6-c-table--m-compact--cell--first-last-child--PaddingInlineStart: var(--pf-v6-global--spacer--sm);
}

#ws-html-demos-c-card-status-card-expanded-with-popover .pf-v6-c-card {
  overflow: initial;
}

.ws-chart {
  display: flex;
  max-width: 100%;
  height: 100%;
}

.ws-chart img {
  align-self: center;
}
