"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuSearch = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const menu_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Menu/menu"));
const react_styles_1 = require("@patternfly/react-styles");
exports.MenuSearch = (0, react_1.forwardRef)((props, ref) => ((0, jsx_runtime_1.jsx)("div", Object.assign({}, props, { className: (0, react_styles_1.css)(menu_1.default.menuSearch, props.className), ref: ref }))));
exports.MenuSearch.displayName = 'MenuSearch';
//# sourceMappingURL=MenuSearch.js.map