import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const CaretRightIconConfig: {
  name: 'CaretRightIcon',
  height: 512,
  width: 192,
  svgPath: "M0 384.662V127.338c0-17.818 21.543-26.741 34.142-14.142l128.662 128.662c7.81 7.81 7.81 20.474 0 28.284L34.142 398.804C21.543 411.404 0 402.48 0 384.662z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const CaretRightIcon: ComponentClass<SVGIconProps>;
export default CaretRightIcon;