/// <reference types="react" />
export interface ToolbarExpandIconWrapperProps extends React.HTMLProps<HTMLSpanElement> {
    /** Icon content used for the expand all or collapse all indication. */
    children?: React.ReactNode;
    /** Additional classes added to the span */
    className?: string;
}
export declare const ToolbarExpandIconWrapper: React.FunctionComponent<ToolbarExpandIconWrapperProps>;
//# sourceMappingURL=ToolbarExpandIconWrapper.d.ts.map