import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const Css3IconConfig: {
  name: 'Css3Icon',
  height: 512,
  width: 512,
  svgPath: "M480 32l-64 368-223.3 80L0 400l19.6-94.8h82l-8 40.6L210 390.2l134.1-44.4 18.8-97.1H29.5l16-82h333.7l10.5-52.7H56.3l16.3-82H480z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const Css3Icon: ComponentClass<SVGIconProps>;
export default Css3Icon;