
// Do not edit directly
// Generated on Wed, 10 Sep 2025 19:58:14 GMT

@mixin pf-v6-tokens {
  --pf-t--global--background--color--action--plain--default: rgba(0, 0, 0, 0.0000);
  --pf-t--global--dark--background--color--500: rgba(21, 21, 21, 0.8000);
  --pf-t--global--dark--background--color--600: rgba(199, 199, 199, 0.1500);
  --pf-t--global--dark--box-shadow--color--100: rgba(0, 0, 0, 0.5000);
  --pf-t--global--dark--box-shadow--color--200: rgba(0, 0, 0, 0.7000);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--dark--background--color--500);
  --pf-t--global--background--color--primary--default: var(--pf-t--color--black);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--dark--background--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--dark--background--color--200: var(--pf-t--color--gray--80);
  --pf-t--global--dark--background--color--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--background--color--400: var(--pf-t--color--gray--10);
  --pf-t--global--dark--background--color--450: var(--pf-t--color--gray--20);
  --pf-t--global--dark--background--color--highlight--100: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--background--color--highlight--200: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--border--color--100: var(--pf-t--color--gray--50);
  --pf-t--global--dark--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--border--color--300: var(--pf-t--color--gray--30);
  --pf-t--global--dark--border--color--50: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--brand--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--brand--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--brand--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--disabled--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--disabled--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--disabled--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--disabled--400: var(--pf-t--color--gray--90);
  --pf-t--global--dark--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--favorite--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--blue--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--nonstatus--blue--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--nonstatus--blue--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--nonstatus--gray--100: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--nonstatus--gray--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--nonstatus--gray--50: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--nonstatus--green--100: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--nonstatus--green--200: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--nonstatus--green--300: var(--pf-t--color--green--10);
  --pf-t--global--dark--color--nonstatus--orange--100: var(--pf-t--color--orange--30);
  --pf-t--global--dark--color--nonstatus--orange--200: var(--pf-t--color--orange--20);
  --pf-t--global--dark--color--nonstatus--orange--300: var(--pf-t--color--orange--10);
  --pf-t--global--dark--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--10);
  --pf-t--global--dark--color--nonstatus--purple--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--nonstatus--purple--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--nonstatus--purple--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--nonstatus--red--100: var(--pf-t--color--red--30);
  --pf-t--global--dark--color--nonstatus--red--200: var(--pf-t--color--red--20);
  --pf-t--global--dark--color--nonstatus--red--300: var(--pf-t--color--red--10);
  --pf-t--global--dark--color--nonstatus--teal--100: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--nonstatus--teal--200: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--nonstatus--teal--300: var(--pf-t--color--teal--10);
  --pf-t--global--dark--color--nonstatus--yellow--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--nonstatus--yellow--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--yellow--300: var(--pf-t--color--yellow--10);
  --pf-t--global--dark--color--severity--critical--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--severity--critical--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--severity--important--100: var(--pf-t--color--orange--40);
  --pf-t--global--dark--color--severity--minor--100: var(--pf-t--color--gray--30);
  --pf-t--global--dark--color--severity--moderate--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--severity--none--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--severity--undefined--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--status--custom--100: var(--pf-t--color--teal--40);
  --pf-t--global--dark--color--status--custom--200: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--status--custom--300: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--status--danger--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--status--danger--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--status--danger--250: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--status--danger--300: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--status--info--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--status--info--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--status--info--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--status--success--100: var(--pf-t--color--green--40);
  --pf-t--global--dark--color--status--success--200: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--status--success--300: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--status--warning--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--focus-ring--color--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--icon--color--100: var(--pf-t--color--gray--10);
  --pf-t--global--dark--icon--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--icon--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--100: var(--pf-t--color--white);
  --pf-t--global--dark--text--color--200: var(--pf-t--color--gray--30);
  --pf-t--global--dark--text--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--400: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--text--color--link--100: var(--pf-t--color--blue--20);
  --pf-t--global--dark--text--color--link--200: var(--pf-t--color--blue--10);
  --pf-t--global--dark--text--color--link--300: var(--pf-t--color--purple--30);
  --pf-t--global--dark--text--color--link--400: var(--pf-t--color--purple--20);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--control--default: var(--pf-t--global--dark--background--color--100);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--dark--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--dark--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--dark--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--dark--background--color--100);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--dark--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--dark--border--color--300);
  --pf-t--global--border--color--disabled: var(--pf-t--global--dark--color--disabled--100);
  --pf-t--global--border--color--hover: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--200);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--dark--border--color--300);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--brand--default: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--color--brand--hover: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--favorite--default: var(--pf-t--global--dark--color--favorite--100);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--50);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--dark--color--status--custom--300);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--dark--color--status--custom--200);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--dark--color--status--custom--300);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--250);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--200);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--250);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--info--default: var(--pf-t--global--dark--color--status--info--100);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--dark--color--status--success--300);
  --pf-t--global--color--status--success--default: var(--pf-t--global--dark--color--status--success--200);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--dark--color--status--success--300);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--dark--color--status--warning--100);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--dark--focus-ring--color--100);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--dark--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--dark--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--dark--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--dark--color--severity--critical--200);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--dark--color--severity--important--100);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--dark--color--severity--minor--100);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--dark--color--severity--moderate--100);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--dark--color--severity--none--100);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--dark--color--severity--undefined--100);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--dark--icon--color--200);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--text--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--dark--text--color--link--100);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--dark--text--color--link--200);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--dark--text--color--link--400);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--dark--color--disabled--400);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--regular: var(--pf-t--global--dark--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--dark--text--color--400);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--subtle: var(--pf-t--global--dark--text--color--200);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--high-contrast: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--main--default: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
}
