import { ClientRectObject, VirtualElement } from '../types';
/**
 * @param element
 */
export default function getBoundingClientRect(element: Element | VirtualElement): ClientRectObject;
//# sourceMappingURL=getBoundingClientRect.d.ts.map