/// <reference types="react" />
/** Acts as the container for DualListSelectorListItem sub-components. */
export interface DualListSelectorListProps extends React.HTMLProps<HTMLUListElement> {
    /** Content rendered inside the dual list selector list */
    children?: React.ReactNode;
}
export declare const DualListSelectorList: React.FunctionComponent<DualListSelectorListProps>;
//# sourceMappingURL=DualListSelectorList.d.ts.map