/// <reference types="react" />
export interface DrawerMainProps extends React.HTMLProps<HTMLDivElement> {
    /** Additional classes added to the drawer main wrapper. */
    className?: string;
    /** Content to be rendered in the drawer main wrapper*/
    children?: React.ReactNode;
}
export declare const DrawerMain: React.FunctionComponent<DrawerMainProps>;
//# sourceMappingURL=DrawerMain.d.ts.map