import { Modifier, Padding } from '../types';
export interface Options {
    element: HTMLElement | string | null;
    padding: Padding;
}
export type ArrowModifier = Modifier<'arrow', Options>;
declare const _default: ArrowModifier;
export default _default;
//# sourceMappingURL=arrow.d.ts.map