"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopoverContext = void 0;
const react_1 = require("react");
exports.PopoverContext = (0, react_1.createContext)({});
//# sourceMappingURL=PopoverContext.js.map