import './data-list-grid.css';
declare const _default: {
  "dataList": "pf-v6-c-data-list",
  "dataListCell": "pf-v6-c-data-list__cell",
  "dataListExpandableContent": "pf-v6-c-data-list__expandable-content",
  "dataListItemContent": "pf-v6-c-data-list__item-content",
  "modifiers": {
    "icon": "pf-m-icon",
    "alignRight": "pf-m-align-right",
    "noFill": "pf-m-no-fill",
    "flex_2": "pf-m-flex-2",
    "flex_3": "pf-m-flex-3",
    "flex_4": "pf-m-flex-4",
    "flex_5": "pf-m-flex-5",
    "gridNone": "pf-m-grid-none",
    "gridSm": "pf-m-grid-sm",
    "gridMd": "pf-m-grid-md",
    "gridLg": "pf-m-grid-lg",
    "gridXl": "pf-m-grid-xl",
    "grid_2xl": "pf-m-grid-2xl"
  }
};
export default _default;