import { Window } from '../types';
/**
 * @param node
 */
export default function getWindowScroll(node: Node | Window): {
    scrollLeft: any;
    scrollTop: any;
};
//# sourceMappingURL=getWindowScroll.d.ts.map