import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const FolderIconConfig: {
  name: 'FolderIcon',
  height: 512,
  width: 512,
  svgPath: "M464 128H272l-64-64H48C21.49 64 0 85.49 0 112v288c0 26.51 21.49 48 48 48h416c26.51 0 48-21.49 48-48V176c0-26.51-21.49-48-48-48z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const FolderIcon: ComponentClass<SVGIconProps>;
export default FolderIcon;