import { useEffect } from 'react';
/**
 * Small wrapper around `useLayoutEffect` to get rid of the warning on SSR envs
 */
export declare const useIsomorphicLayoutEffect: typeof useEffect;
//# sourceMappingURL=useIsomorphicLayout.d.ts.map