"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeBlockCode = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const code_block_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/CodeBlock/code-block"));
const react_styles_1 = require("@patternfly/react-styles");
const CodeBlockCode = (_a) => {
    var { children = null, className, codeClassName } = _a, props = tslib_1.__rest(_a, ["children", "className", "codeClassName"]);
    return ((0, jsx_runtime_1.jsx)("pre", Object.assign({ className: (0, react_styles_1.css)(code_block_1.default.codeBlockPre, className) }, props, { children: (0, jsx_runtime_1.jsx)("code", { className: (0, react_styles_1.css)(code_block_1.default.codeBlockCode, codeClassName), children: children }) })));
};
exports.CodeBlockCode = CodeBlockCode;
exports.CodeBlockCode.displayName = 'CodeBlockCode';
//# sourceMappingURL=CodeBlockCode.js.map