/// <reference types="react" />
export interface CardHeaderMainProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the Card Head Main */
    children?: React.ReactNode;
    /** Additional classes added to the Card Head Main */
    className?: string;
}
export declare const CardHeaderMain: React.FunctionComponent<CardHeaderMainProps>;
//# sourceMappingURL=CardHeaderMain.d.ts.map