import './slider.css';
declare const _default: {
  "dirRtl": "pf-v6-m-dir-rtl",
  "formControl": "pf-v6-c-form-control",
  "modifiers": {
    "disabled": "pf-m-disabled",
    "active": "pf-m-active",
    "floating": "pf-m-floating"
  },
  "slider": "pf-v6-c-slider",
  "sliderActions": "pf-v6-c-slider__actions",
  "sliderMain": "pf-v6-c-slider__main",
  "sliderRail": "pf-v6-c-slider__rail",
  "sliderRailTrack": "pf-v6-c-slider__rail-track",
  "sliderStep": "pf-v6-c-slider__step",
  "sliderStepLabel": "pf-v6-c-slider__step-label",
  "sliderStepTick": "pf-v6-c-slider__step-tick",
  "sliderSteps": "pf-v6-c-slider__steps",
  "sliderThumb": "pf-v6-c-slider__thumb",
  "sliderValue": "pf-v6-c-slider__value"
};
export default _default;