import { Modifier } from '../types';
export type PopperOffsetsModifier = Modifier<'popperOffsets', {}>;
declare const _default: PopperOffsetsModifier;
export default _default;
//# sourceMappingURL=popperOffsets.d.ts.map