"use strict";
exports.__esModule = true;
require('./Label.css');
exports.default = {
  "label": "pf-v6-c-label",
  "labelTruncateExample": "pf-v6-c-label-truncate--example",
  "wsPreviewHtml": "ws-preview-html"
};