"use strict";
exports.__esModule = true;
require('./Menu.css');
exports.default = {
  "breadcrumbDropdown": "pf-v6-c-breadcrumb__dropdown",
  "menu": "pf-v6-c-menu",
  "menuBreadcrumb": "pf-v6-c-menu__breadcrumb"
};