"use strict";
exports.__esModule = true;
require('./Brand.css');
exports.default = {
  "modifiers": {
    "picture": "pf-m-picture"
  },
  "showDark": "show-dark",
  "showLight": "show-light",
  "themeDark": "pf-v6-theme-dark"
};