import './progress-stepper.css';
export default {
  "faExclamationTriangle": "fa-exclamation-triangle",
  "modifiers": {
    "center": "pf-m-center",
    "compact": "pf-m-compact",
    "current": "pf-m-current",
    "pending": "pf-m-pending",
    "success": "pf-m-success",
    "danger": "pf-m-danger",
    "warning": "pf-m-warning",
    "info": "pf-m-info",
    "custom": "pf-m-custom",
    "helpText": "pf-m-help-text",
    "horizontal": "pf-m-horizontal",
    "vertical": "pf-m-vertical",
    "horizontalOnSm": "pf-m-horizontal-on-sm",
    "verticalOnSm": "pf-m-vertical-on-sm",
    "horizontalOnMd": "pf-m-horizontal-on-md",
    "verticalOnMd": "pf-m-vertical-on-md",
    "horizontalOnLg": "pf-m-horizontal-on-lg",
    "verticalOnLg": "pf-m-vertical-on-lg",
    "horizontalOnXl": "pf-m-horizontal-on-xl",
    "verticalOnXl": "pf-m-vertical-on-xl",
    "horizontalOn_2xl": "pf-m-horizontal-on-2xl",
    "verticalOn_2xl": "pf-m-vertical-on-2xl"
  },
  "pficon": "pf-v6-pficon",
  "progressStepper": "pf-v6-c-progress-stepper",
  "progressStepperStep": "pf-v6-c-progress-stepper__step",
  "progressStepperStepConnector": "pf-v6-c-progress-stepper__step-connector",
  "progressStepperStepDescription": "pf-v6-c-progress-stepper__step-description",
  "progressStepperStepIcon": "pf-v6-c-progress-stepper__step-icon",
  "progressStepperStepMain": "pf-v6-c-progress-stepper__step-main",
  "progressStepperStepTitle": "pf-v6-c-progress-stepper__step-title"
};