import './calendar-month.css';
export default {
  "calendarMonth": "pf-v6-c-calendar-month",
  "calendarMonthCalendar": "pf-v6-c-calendar-month__calendar",
  "calendarMonthDate": "pf-v6-c-calendar-month__date",
  "calendarMonthDatesCell": "pf-v6-c-calendar-month__dates-cell",
  "calendarMonthDatesRow": "pf-v6-c-calendar-month__dates-row",
  "calendarMonthDay": "pf-v6-c-calendar-month__day",
  "calendarMonthDays": "pf-v6-c-calendar-month__days",
  "calendarMonthHeader": "pf-v6-c-calendar-month__header",
  "calendarMonthHeaderMonth": "pf-v6-c-calendar-month__header-month",
  "calendarMonthHeaderNavControl": "pf-v6-c-calendar-month__header-nav-control",
  "calendarMonthHeaderYear": "pf-v6-c-calendar-month__header-year",
  "dirRtl": "pf-v6-m-dir-rtl",
  "menuToggle": "pf-v6-c-menu-toggle",
  "modifiers": {
    "current": "pf-m-current",
    "inRange": "pf-m-in-range",
    "startRange": "pf-m-start-range",
    "endRange": "pf-m-end-range",
    "adjacentMonth": "pf-m-adjacent-month",
    "selected": "pf-m-selected",
    "disabled": "pf-m-disabled",
    "hover": "pf-m-hover",
    "focus": "pf-m-focus"
  }
};