#ifndef WIN_UTILS_H
#define WIN_UTILS_H

#include <string>
#include <windows.h>

std::wstring utf8ToUtf16(std::string input);
std::string utf16ToUtf8(const WCHAR *input, DWORD length);
std::string normalizePath(std::string path);

#endif
