.pf-v6-c-table {
  --pf-v6-c-table__tree-view-main--indent--base: calc(var(--pf-t--global--spacer--md) * 2 + var(--pf-v6-c-table__tree-view-icon--MinWidth));
  --pf-v6-c-table__tree-view-main--nested-indent--base: calc(var(--pf-v6-c-table__tree-view-main--indent--base) - var(--pf-t--global--spacer--md));
  --pf-v6-c-table__tree-view-main--c-button--MarginInlineEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
  --pf-v6-c-table__tree-view-main--MarginInlineStart: calc(var(--pf-v6-c-table--cell--PaddingInlineStart) * -1);
  --pf-v6-c-table__tree-view-main--c-table__check--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table__tree-view-main--c-table__check--MarginInlineEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table__tree-view-icon--MinWidth: var(--pf-t--global--spacer--md);
  --pf-v6-c-table__tree-view-icon--MarginInlineEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table--m-tree-view__toggle--Position: absolute;
  --pf-v6-c-table--m-tree-view__toggle--InsetInlineStart: var(--pf-v6-c-table__tree-view-main--PaddingInlineStart);
  --pf-v6-c-table--m-tree-view__toggle--TranslateX: -100%;
  --pf-v6-c-table--m-tree-view__toggle__toggle-icon--MinWidth: var(--pf-t--global--spacer--md);
  --pf-v6-c-table--m-no-inset__tree-view-main--PaddingInlineStart: 0;
  --pf-v6-c-table--m-no-inset__tree-view-main--MarginInlineStart: 0;
}

.pf-v6-c-table.pf-m-tree-view > tbody > tr {
  --pf-v6-c-table--m-tree-view__toggle--InsetInlineStart: var(--pf-v6-c-table__tree-view-main--PaddingInlineStart);
}
.pf-v6-c-table.pf-m-tree-view > tbody > tr.pf-m-no-inset {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: var(--pf-v6-c-table--m-no-inset__tree-view-main--PaddingInlineStart);
  --pf-v6-c-table__tree-view-main--MarginInlineStart: var(--pf-v6-c-table--m-no-inset__tree-view-main--MarginInlineStart);
}
.pf-v6-c-table.pf-m-tree-view.pf-m-no-inset {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: var(--pf-v6-c-table--m-no-inset__tree-view-main--PaddingInlineStart);
  --pf-v6-c-table__tree-view-main--MarginInlineStart: var(--pf-v6-c-table--m-no-inset__tree-view-main--MarginInlineStart);
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-v6-c-table.pf-m-tree-view tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
  --pf-v6-c-table__tree-view-main--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
}

.pf-v6-c-table__tree-view-main {
  position: relative;
  display: flex;
  align-items: baseline;
  min-width: 0;
  padding-inline-start: var(--pf-v6-c-table__tree-view-main--PaddingInlineStart);
  margin-inline-start: var(--pf-v6-c-table__tree-view-main--MarginInlineStart);
  text-align: start;
  cursor: pointer;
}
.pf-v6-c-table__tree-view-main > .pf-v6-c-table__toggle {
  transform: translateX(var(--pf-v6-c-table--m-tree-view__toggle--TranslateX));
  position: var(--pf-v6-c-table--m-tree-view__toggle--Position);
  inset-inline-start: var(--pf-v6-c-table--m-tree-view__toggle--InsetInlineStart);
}
:where(.pf-v6-m-dir-rtl, [dir=rtl]) .pf-v6-c-table__tree-view-main > .pf-v6-c-table__toggle {
  transform: translateX(calc(var(--pf-v6-c-table--m-tree-view__toggle--TranslateX) * var(--pf-v6-global--inverse--multiplier)));
}

.pf-v6-c-table__tree-view-main > .pf-v6-c-table__toggle .pf-v6-c-table__toggle-icon {
  min-width: var(--pf-v6-c-table--m-tree-view__toggle__toggle-icon--MinWidth);
}
.pf-v6-c-table__tree-view-main > .pf-v6-c-table__toggle .pf-v6-c-button {
  margin-block-start: -50%;
  margin-inline-end: var(--pf-v6-c-table__tree-view-main--c-button--MarginInlineEnd);
}
.pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
  margin-inline-end: var(--pf-v6-c-table__tree-view-main--c-table__check--MarginInlineEnd);
}
.pf-v6-c-table__tree-view-main > .pf-v6-c-table__check label {
  padding-inline-end: var(--pf-v6-c-table__tree-view-main--c-table__check--PaddingInlineEnd);
  margin-block-start: 0;
  margin-block-end: 0;
  margin-inline-start: 0;
  margin-inline-end: calc(var(--pf-v6-c-table__tree-view-main--c-table__check--MarginInlineEnd) * -1);
}

.pf-v6-c-table__tree-view-text {
  display: flex;
}

.pf-v6-c-table__tree-view-icon {
  min-width: var(--pf-v6-c-table__tree-view-icon--MinWidth);
  margin-inline-end: var(--pf-v6-c-table__tree-view-icon--MarginInlineEnd);
}

.pf-v6-c-table__tree-view-details-toggle {
  display: none;
}

.pf-m-tree-view-grid.pf-v6-c-table {
  --pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset: calc(-1 * var(--pf-t--global--spacer--xs));
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart: 0;
  --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart: var(--pf-t--global--spacer--xl);
  --pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
  --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xl);
  --pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns: repeat(auto-fit, minmax(150px, 1fr));
  --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xs);
  --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
  --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd: 0;
  --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order: 4;
  --pf-v6-c-table__tree-view-text--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-table__tbody--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart);
  --pf-v6-c-table__tbody--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd);
  --pf-v6-c-table__tree-view-details-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  --pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  --pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  --pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
}
.pf-m-tree-view-grid.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr) {
  position: relative;
  border: none;
  outline-offset: var(--pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset);
}
.pf-m-tree-view-grid.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr)::before {
  position: absolute;
  inset-block-start: 0;
  inset-block-end: 0;
  inset-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
  inset-inline-end: 0;
  content: "";
  border-block-end: var(--pf-v6-c-table--border-width--base) solid var(--pf-v6-c-table--BorderColor);
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr):not([hidden]) {
  display: grid;
  grid-template-columns: 1fr max-content;
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell {
  --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart);
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell ~ .pf-v6-c-table__action {
  --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart);
}
.pf-m-tree-view-grid.pf-v6-c-table td:where(.pf-v6-c-table__td):not(.pf-v6-c-table__tree-view-title-cell) {
  --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart);
  --pf-v6-c-table--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__tree-view-text {
  padding-inline-end: var(--pf-v6-c-table__tree-view-text--PaddingInlineEnd);
}
.pf-m-tree-view-grid.pf-v6-c-table thead:where(.pf-v6-c-table__thead) th:where(.pf-v6-c-table__th) {
  display: none;
}
.pf-m-tree-view-grid.pf-v6-c-table td:where(.pf-v6-c-table__td) {
  display: none;
}
.pf-m-tree-view-grid.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] {
  grid-template-columns: var(--pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns);
  grid-column: 1;
  grid-column-gap: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap);
  align-items: start;
}
.pf-m-tree-view-grid.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] > :where(th, td) {
  grid-column: 2;
}
.pf-m-tree-view-grid.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label]::before {
  position: revert;
  font-weight: var(--pf-t--global--font--weight--body--bold);
  text-align: start;
  content: attr(data-label);
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__tr > :where(th, td).pf-m-border-right::before {
  border-inline-end: 0;
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded {
  padding-block-end: var(--pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd);
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded td:where(.pf-v6-c-table__td)[data-label] {
  display: grid;
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__thead {
  display: none;
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle,
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__action {
  display: inline-block;
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__action {
  --pf-v6-c-table--cell--Width: auto;
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart);
  --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart);
  --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd);
  grid-row: 1;
  grid-column: 2;
  margin-block-start: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart);
  margin-block-end: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd);
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
  order: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order);
  margin-inline-start: auto;
  margin-inline-end: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd);
}
.pf-m-tree-view-grid.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle {
  margin-block-start: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockStart);
  margin-block-end: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd);
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
}
.pf-m-tree-view-grid.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
  --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
}

@media screen and (max-width: calc(48rem - 1px)) {
  .pf-m-tree-view-grid-md.pf-v6-c-table {
    --pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset: calc(-1 * var(--pf-t--global--spacer--xs));
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart: 0;
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns: repeat(auto-fit, minmax(150px, 1fr));
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd: 0;
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order: 4;
    --pf-v6-c-table__tree-view-text--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table__tbody--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart);
    --pf-v6-c-table__tbody--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr) {
    position: relative;
    border: none;
    outline-offset: var(--pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr)::before {
    position: absolute;
    inset-block-start: 0;
    inset-block-end: 0;
    inset-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
    inset-inline-end: 0;
    content: "";
    border-block-end: var(--pf-v6-c-table--border-width--base) solid var(--pf-v6-c-table--BorderColor);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr):not([hidden]) {
    display: grid;
    grid-template-columns: 1fr max-content;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell ~ .pf-v6-c-table__action {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table td:where(.pf-v6-c-table__td):not(.pf-v6-c-table__tree-view-title-cell) {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart);
    --pf-v6-c-table--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd);
    padding-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__tree-view-text {
    padding-inline-end: var(--pf-v6-c-table__tree-view-text--PaddingInlineEnd);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table thead:where(.pf-v6-c-table__thead) th:where(.pf-v6-c-table__th) {
    display: none;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table td:where(.pf-v6-c-table__td) {
    display: none;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] {
    grid-template-columns: var(--pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns);
    grid-column: 1;
    grid-column-gap: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap);
    align-items: start;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] > :where(th, td) {
    grid-column: 2;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label]::before {
    position: revert;
    font-weight: var(--pf-t--global--font--weight--body--bold);
    text-align: start;
    content: attr(data-label);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__tr > :where(th, td).pf-m-border-right::before {
    border-inline-end: 0;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded {
    padding-block-end: var(--pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded td:where(.pf-v6-c-table__td)[data-label] {
    display: grid;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__thead {
    display: none;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle,
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__action {
    display: inline-block;
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__action {
    --pf-v6-c-table--cell--Width: auto;
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd);
    grid-row: 1;
    grid-column: 2;
    margin-block-start: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
    order: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order);
    margin-inline-start: auto;
    margin-inline-end: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle {
    margin-block-start: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-md.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
}

@media screen and (max-width: calc(62rem - 1px)) {
  .pf-m-tree-view-grid-lg.pf-v6-c-table {
    --pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset: calc(-1 * var(--pf-t--global--spacer--xs));
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart: 0;
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns: repeat(auto-fit, minmax(150px, 1fr));
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd: 0;
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order: 4;
    --pf-v6-c-table__tree-view-text--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table__tbody--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart);
    --pf-v6-c-table__tbody--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr) {
    position: relative;
    border: none;
    outline-offset: var(--pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr)::before {
    position: absolute;
    inset-block-start: 0;
    inset-block-end: 0;
    inset-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
    inset-inline-end: 0;
    content: "";
    border-block-end: var(--pf-v6-c-table--border-width--base) solid var(--pf-v6-c-table--BorderColor);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr):not([hidden]) {
    display: grid;
    grid-template-columns: 1fr max-content;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell ~ .pf-v6-c-table__action {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table td:where(.pf-v6-c-table__td):not(.pf-v6-c-table__tree-view-title-cell) {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart);
    --pf-v6-c-table--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd);
    padding-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__tree-view-text {
    padding-inline-end: var(--pf-v6-c-table__tree-view-text--PaddingInlineEnd);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table thead:where(.pf-v6-c-table__thead) th:where(.pf-v6-c-table__th) {
    display: none;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table td:where(.pf-v6-c-table__td) {
    display: none;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] {
    grid-template-columns: var(--pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns);
    grid-column: 1;
    grid-column-gap: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap);
    align-items: start;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] > :where(th, td) {
    grid-column: 2;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label]::before {
    position: revert;
    font-weight: var(--pf-t--global--font--weight--body--bold);
    text-align: start;
    content: attr(data-label);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__tr > :where(th, td).pf-m-border-right::before {
    border-inline-end: 0;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded {
    padding-block-end: var(--pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded td:where(.pf-v6-c-table__td)[data-label] {
    display: grid;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__thead {
    display: none;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle,
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__action {
    display: inline-block;
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__action {
    --pf-v6-c-table--cell--Width: auto;
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd);
    grid-row: 1;
    grid-column: 2;
    margin-block-start: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
    order: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order);
    margin-inline-start: auto;
    margin-inline-end: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle {
    margin-block-start: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-lg.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
}

@media screen and (max-width: calc(75rem - 1px)) {
  .pf-m-tree-view-grid-xl.pf-v6-c-table {
    --pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset: calc(-1 * var(--pf-t--global--spacer--xs));
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart: 0;
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns: repeat(auto-fit, minmax(150px, 1fr));
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd: 0;
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order: 4;
    --pf-v6-c-table__tree-view-text--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table__tbody--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart);
    --pf-v6-c-table__tbody--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr) {
    position: relative;
    border: none;
    outline-offset: var(--pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr)::before {
    position: absolute;
    inset-block-start: 0;
    inset-block-end: 0;
    inset-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
    inset-inline-end: 0;
    content: "";
    border-block-end: var(--pf-v6-c-table--border-width--base) solid var(--pf-v6-c-table--BorderColor);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr):not([hidden]) {
    display: grid;
    grid-template-columns: 1fr max-content;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell ~ .pf-v6-c-table__action {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table td:where(.pf-v6-c-table__td):not(.pf-v6-c-table__tree-view-title-cell) {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart);
    --pf-v6-c-table--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd);
    padding-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__tree-view-text {
    padding-inline-end: var(--pf-v6-c-table__tree-view-text--PaddingInlineEnd);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table thead:where(.pf-v6-c-table__thead) th:where(.pf-v6-c-table__th) {
    display: none;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table td:where(.pf-v6-c-table__td) {
    display: none;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] {
    grid-template-columns: var(--pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns);
    grid-column: 1;
    grid-column-gap: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap);
    align-items: start;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] > :where(th, td) {
    grid-column: 2;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label]::before {
    position: revert;
    font-weight: var(--pf-t--global--font--weight--body--bold);
    text-align: start;
    content: attr(data-label);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__tr > :where(th, td).pf-m-border-right::before {
    border-inline-end: 0;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded {
    padding-block-end: var(--pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded td:where(.pf-v6-c-table__td)[data-label] {
    display: grid;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__thead {
    display: none;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle,
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__action {
    display: inline-block;
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__action {
    --pf-v6-c-table--cell--Width: auto;
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd);
    grid-row: 1;
    grid-column: 2;
    margin-block-start: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
    order: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order);
    margin-inline-start: auto;
    margin-inline-end: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle {
    margin-block-start: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
}

@media screen and (max-width: calc(90.625rem - 1px)) {
  .pf-m-tree-view-grid-2xl.pf-v6-c-table {
    --pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset: calc(-1 * var(--pf-t--global--spacer--xs));
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table__tree-view-main--indent--base);
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd: var(--pf-t--global--spacer--md);
    --pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart: 0;
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xl);
    --pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns: repeat(auto-fit, minmax(150px, 1fr));
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-t--global--spacer--xs);
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd: 0;
    --pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order: 4;
    --pf-v6-c-table__tree-view-text--PaddingInlineEnd: var(--pf-t--global--spacer--sm);
    --pf-v6-c-table__tbody--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockStart);
    --pf-v6-c-table__tbody--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingBlockEnd);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
    --pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--plain) * -1);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr) {
    position: relative;
    border: none;
    outline-offset: var(--pf-v6-c-table--m-tree-view-grid--tr--OutlineOffset);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tbody:where(.pf-v6-c-table__tbody) tr:where(.pf-v6-c-table__tr)::before {
    position: absolute;
    inset-block-start: 0;
    inset-block-end: 0;
    inset-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
    inset-inline-end: 0;
    content: "";
    border-block-end: var(--pf-v6-c-table--border-width--base) solid var(--pf-v6-c-table--BorderColor);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr):not([hidden]) {
    display: grid;
    grid-template-columns: 1fr max-content;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-expanded] .pf-v6-c-table__tree-view-title-cell ~ .pf-v6-c-table__action {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__tr--expanded__tree-view-title-cell--action--PaddingBlockStart);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table td:where(.pf-v6-c-table__td):not(.pf-v6-c-table__tree-view-title-cell) {
    --pf-v6-c-table--cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart);
    --pf-v6-c-table--cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd);
    padding-inline-start: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__tree-view-text {
    padding-inline-end: var(--pf-v6-c-table__tree-view-text--PaddingInlineEnd);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table thead:where(.pf-v6-c-table__thead) th:where(.pf-v6-c-table__th) {
    display: none;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table td:where(.pf-v6-c-table__td) {
    display: none;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] {
    grid-template-columns: var(--pf-v6-c-table--m-tree-view-grid__td--data-label--GridTemplateColumns);
    grid-column: 1;
    grid-column-gap: var(--pf-v6-c-table--m-tree-view-grid__tbody--cell--GridColumnGap);
    align-items: start;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label] > :where(th, td) {
    grid-column: 2;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table td:where(.pf-v6-c-table__td)[data-label]::before {
    position: revert;
    font-weight: var(--pf-t--global--font--weight--body--bold);
    text-align: start;
    content: attr(data-label);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__tr > :where(th, td).pf-m-border-right::before {
    border-inline-end: 0;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded {
    padding-block-end: var(--pf-v6-c-table--m-tree-view-grid--m-tree-view-details-expanded--PaddingBlockEnd);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr).pf-m-tree-view-details-expanded td:where(.pf-v6-c-table__td)[data-label] {
    display: grid;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__thead {
    display: none;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle,
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__action {
    display: inline-block;
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__action {
    --pf-v6-c-table--cell--Width: auto;
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingInlineStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockStart: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockStart);
    --pf-v6-c-table--m-tree-view-grid__td--not--c-table__tree-view-title-cell--PaddingBlockEnd: var(--pf-v6-c-table--m-tree-view-grid--c-table__action--PaddingBlockEnd);
    grid-row: 1;
    grid-column: 2;
    margin-block-start: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table--m-tree-view-grid__action--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__tree-view-main > .pf-v6-c-table__check {
    order: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--Order);
    margin-inline-start: auto;
    margin-inline-end: var(--pf-v6-c-table--m-tree-view-mobile__tree-view-main--c-table__check--MarginInlineEnd);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table .pf-v6-c-table__tree-view-details-toggle {
    margin-block-start: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockStart);
    margin-block-end: var(--pf-v6-c-table__tree-view-details-toggle--MarginBlockEnd);
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="2"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 1 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="3"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 2 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="4"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 3 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="5"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 4 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="6"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 5 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="7"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 6 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="8"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 7 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="9"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 8 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
  .pf-m-tree-view-grid-2xl.pf-v6-c-table tr:where(.pf-v6-c-table__tr)[aria-level="10"] {
    --pf-v6-c-table--m-tree-view-grid__tbody--cell--PaddingInlineStart: calc(var(--pf-v6-c-table__tree-view-main--nested-indent--base) * 9 + var(--pf-v6-c-table__tree-view-main--indent--base));
  }
}