import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const BorderAllIconConfig: {
  name: 'BorderAllIcon',
  height: 512,
  width: 448,
  svgPath: "M416 32H32A32 32 0 0 0 0 64v384a32 32 0 0 0 32 32h384a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32zm-32 64v128H256V96zm-192 0v128H64V96zM64 416V288h128v128zm192 0V288h128v128z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const BorderAllIcon: ComponentClass<SVGIconProps>;
export default BorderAllIcon;