import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const SquareFullIconConfig: {
  name: 'SquareFullIcon',
  height: 512,
  width: 512,
  svgPath: "M512 512H0V0h512v512z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const SquareFullIcon: ComponentClass<SVGIconProps>;
export default SquareFullIcon;