/// <reference types="react" />
export interface MenuSearchInputProps extends React.HTMLProps<HTMLElement> {
    /** Items within input */
    children?: React.ReactNode;
    /** @hide Forwarded ref */
    innerRef?: React.Ref<any>;
}
export declare const MenuSearchInput: import("react").ForwardRefExoticComponent<Omit<MenuSearchInputProps, "ref"> & import("react").RefAttributes<HTMLDivElement>>;
//# sourceMappingURL=MenuSearchInput.d.ts.map