"use strict"
exports.__esModule = true;
exports.SeverityNoneIconConfig = {
  name: 'SeverityNoneIcon',
  height: 1024,
  width: 1024,
  svgPath: "M64,128h896c35.3,0,64,28.7,64,64v64c0,35.3-28.7,64-64,64H64c-35.3,0-64-28.7-64-64v-64c0-35.3,28.7-64,64-64ZM64,448h896c35.3,0,64,28.7,64,64v256c0,35.3-28.7,64-64,64H64c-35.3,0-64-28.7-64-64v-256c0-35.3,28.7-64,64-64Z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.SeverityNoneIcon = require('../createIcon').createIcon(exports.SeverityNoneIconConfig);
exports["default"] = exports.SeverityNoneIcon;