import { createIcon } from '../createIcon';

export const SdCardIconConfig = {
  name: 'SdCardIcon',
  height: 512,
  width: 384,
  svgPath: "M320 0H128L0 128v320c0 35.3 28.7 64 64 64h256c35.3 0 64-28.7 64-64V64c0-35.3-28.7-64-64-64zM160 160h-48V64h48v96zm80 0h-48V64h48v96zm80 0h-48V64h48v96z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const SdCardIcon = createIcon(SdCardIconConfig);

export default SdCardIcon;