/// <reference types="react" />
export declare const PopoverCloseButton: React.FunctionComponent<PopoverCloseButtonProps>;
export interface PopoverCloseButtonProps {
    /** PopoverCloseButton onClose function */
    onClose?: (event: any) => void;
    /** Aria label for the Close button */
    'aria-label': string;
}
//# sourceMappingURL=PopoverCloseButton.d.ts.map