/// <reference types="react" />
interface AlertGroupContext {
    hasAnimations?: boolean;
    updateTransitionEnd?: (onTransitionEnd: () => void) => void;
}
export declare const AlertGroupContext: import("react").Context<AlertGroupContext>;
export {};
//# sourceMappingURL=AlertGroupContext.d.ts.map