import { Variation, Placement } from '../enums';
/**
 * @param placement
 */
export default function getVariation(placement: Placement): Variation | null | undefined;
//# sourceMappingURL=getVariation.d.ts.map