.ws-core-l-flex-border,
.ws-core-l-flex .pf-v6-l-flex .pf-v6-l-flex,
.ws-core-l-flex .pf-v6-l-flex__item {
  padding: var(--pf-t--global--spacer--sm);
  border: var(--pf-t--global--border--width--box--default) dashed var(--pf-t--global--border--color--default);
}
