/// <reference types="react" />
export interface PopoverFooterProps extends React.HTMLProps<HTMLDivElement> {
    /** Additional classes added to the Popover footer */
    className?: string;
    /** Footer node */
    children: React.ReactNode;
}
export declare const PopoverFooter: React.FunctionComponent<PopoverFooterProps>;
//# sourceMappingURL=PopoverFooter.d.ts.map