"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sidebar = exports.SidebarBackgroundVariant = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_styles_1 = require("@patternfly/react-styles");
const sidebar_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Sidebar/sidebar"));
var SidebarBackgroundVariant;
(function (SidebarBackgroundVariant) {
    SidebarBackgroundVariant["default"] = "default";
    SidebarBackgroundVariant["secondary"] = "secondary";
})(SidebarBackgroundVariant || (exports.SidebarBackgroundVariant = SidebarBackgroundVariant = {}));
const Sidebar = (_a) => {
    var { className, children, orientation, isPanelRight = false, hasGutter, hasNoBackground, hasBorder } = _a, props = tslib_1.__rest(_a, ["className", "children", "orientation", "isPanelRight", "hasGutter", "hasNoBackground", "hasBorder"]);
    return ((0, jsx_runtime_1.jsx)("div", Object.assign({ className: (0, react_styles_1.css)(sidebar_1.default.sidebar, hasGutter && sidebar_1.default.modifiers.gutter, hasNoBackground && sidebar_1.default.modifiers.noBackground, isPanelRight && sidebar_1.default.modifiers.panelRight, sidebar_1.default.modifiers[orientation], className) }, props, { children: (0, jsx_runtime_1.jsx)("div", { className: (0, react_styles_1.css)(sidebar_1.default.sidebarMain, hasBorder && sidebar_1.default.modifiers.border), children: children }) })));
};
exports.Sidebar = Sidebar;
exports.Sidebar.displayName = 'Sidebar';
//# sourceMappingURL=Sidebar.js.map