/// <reference types="react" />
export interface EmptyStateFooterProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the empty state footer */
    children?: React.ReactNode;
    /** Additional classes added to the empty state footer */
    className?: string;
}
export declare const EmptyStateFooter: React.FunctionComponent<EmptyStateFooterProps>;
//# sourceMappingURL=EmptyStateFooter.d.ts.map