import './about-modal-box.css';
declare const _default: {
  "aboutModalBox": "pf-v6-c-about-modal-box",
  "aboutModalBoxBrand": "pf-v6-c-about-modal-box__brand",
  "aboutModalBoxBrandImage": "pf-v6-c-about-modal-box__brand-image",
  "aboutModalBoxClose": "pf-v6-c-about-modal-box__close",
  "aboutModalBoxContent": "pf-v6-c-about-modal-box__content",
  "aboutModalBoxHeader": "pf-v6-c-about-modal-box__header",
  "aboutModalBoxStrapline": "pf-v6-c-about-modal-box__strapline",
  "button": "pf-v6-c-button",
  "dirRtl": "pf-v6-m-dir-rtl",
  "modifiers": {
    "plain": "pf-m-plain"
  }
};
export default _default;