import { Window, VisualViewport } from '../types';
/**
 * @param element
 * @param list
 */
export default function listScrollParents(element: Node, list?: (Element | Window)[]): (Element | Window | VisualViewport)[];
//# sourceMappingURL=listScrollParents.d.ts.map