"use strict"
exports.__esModule = true;
exports.ForwardIconConfig = {
  name: 'ForwardIcon',
  height: 512,
  width: 512,
  svgPath: "M500.5 231.4l-192-160C287.9 54.3 256 68.6 256 96v320c0 27.4 31.9 41.8 52.5 24.6l192-160c15.3-12.8 15.3-36.4 0-49.2zm-256 0l-192-160C31.9 54.3 0 68.6 0 96v320c0 27.4 31.9 41.8 52.5 24.6l192-160c15.3-12.8 15.3-36.4 0-49.2z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.ForwardIcon = require('../createIcon').createIcon(exports.ForwardIconConfig);
exports["default"] = exports.ForwardIcon;