import { createIcon } from '../createIcon';

export const PrescriptionBottleIconConfig = {
  name: 'PrescriptionBottleIcon',
  height: 512,
  width: 384,
  svgPath: "M32 192h120c4.4 0 8 3.6 8 8v16c0 4.4-3.6 8-8 8H32v64h120c4.4 0 8 3.6 8 8v16c0 4.4-3.6 8-8 8H32v64h120c4.4 0 8 3.6 8 8v16c0 4.4-3.6 8-8 8H32v64c0 17.6 14.4 32 32 32h256c17.6 0 32-14.4 32-32V128H32v64zM360 0H24C10.8 0 0 10.8 0 24v48c0 13.2 10.8 24 24 24h336c13.2 0 24-10.8 24-24V24c0-13.2-10.8-24-24-24z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const PrescriptionBottleIcon = createIcon(PrescriptionBottleIconConfig);

export default PrescriptionBottleIcon;