/// <reference types="react" />
export interface MastheadToggleProps extends React.DetailedHTMLProps<React.HTMLProps<HTMLDivElement>, HTMLDivElement> {
    /** Content rendered inside of the masthead toggle. */
    children?: React.ReactNode;
    /** Additional classes added to the masthead toggle. */
    className?: string;
}
export declare const MastheadToggle: React.FunctionComponent<MastheadToggleProps>;
//# sourceMappingURL=MastheadToggle.d.ts.map