/// <reference types="react" />
export interface TextInputGroupUtilitiesProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the text input group utilities div */
    children?: React.ReactNode;
    /** Additional classes applied to the text input group utilities container */
    className?: string;
}
export declare const TextInputGroupUtilities: React.FunctionComponent<TextInputGroupUtilitiesProps>;
//# sourceMappingURL=TextInputGroupUtilities.d.ts.map