.ws-core-u-flex .pf-v6-u-display-flex,
.ws-core-u-flex .ws-example-flex-item,
.ws-core-u-flex .pf-v6-u-display-inline-flex {
  flex-wrap: wrap;
  padding: var(--pf-t--global--spacer--sm);
  border: var(--pf-t--global--border--width--box--default) dashed var(--pf-t--global--border--color--default);
}

#ws-core-u-flex-aligned-items .pf-v6-u-display-flex,
#ws-core-u-flex-aligned-self .pf-v6-u-display-flex,
#ws-core-u-flex-aligned-content .pf-v6-u-display-flex {
  min-height: 160px;
}

#ws-core-u-flex-aligned-content .ws-example-flex-item {
  height: 40px;
}

.ws-example-u-flex-md {
  height: 60px;
}

.ws-example-u-flex-lg {
  height: 80px;
}
