import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const OutlinedStarHalfIconConfig: {
  name: 'OutlinedStarHalfIcon',
  height: 512,
  width: 576,
  svgPath: "M288 385.3l-124.3 65.4 23.7-138.4-100.6-98 139-20.2 62.2-126V0c-11.4 0-22.8 5.9-28.7 17.8L194 150.2 47.9 171.4c-26.2 3.8-36.7 36.1-17.7 54.6l105.7 103-25 145.5c-4.5 26.1 23 46 46.4 33.7L288 439.6v-54.3z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const OutlinedStarHalfIcon: ComponentClass<SVGIconProps>;
export default OutlinedStarHalfIcon;