/// <reference types="react" />
export interface EmptyStateActionsProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the empty state actions */
    children?: React.ReactNode;
    /** Additional classes added to the empty state actions */
    className?: string;
}
export declare const EmptyStateActions: React.FunctionComponent<EmptyStateActionsProps>;
//# sourceMappingURL=EmptyStateActions.d.ts.map