"use strict";
exports.__esModule = true;
require('./description-list-order.css');
exports.default = {
  "descriptionListGroup": "pf-v6-c-description-list__group",
  "modifiers": {
    "order_0": "pf-m-order-0",
    "order_1": "pf-m-order-1",
    "order_2": "pf-m-order-2",
    "order_3": "pf-m-order-3",
    "order_4": "pf-m-order-4",
    "order_5": "pf-m-order-5",
    "order_6": "pf-m-order-6",
    "order_7": "pf-m-order-7",
    "order_8": "pf-m-order-8",
    "order_9": "pf-m-order-9",
    "order_10": "pf-m-order-10",
    "order_11": "pf-m-order-11",
    "order_12": "pf-m-order-12",
    "orderFirst": "pf-m-order-first",
    "orderLast": "pf-m-order-last",
    "order_0OnSm": "pf-m-order-0-on-sm",
    "order_1OnSm": "pf-m-order-1-on-sm",
    "order_2OnSm": "pf-m-order-2-on-sm",
    "order_3OnSm": "pf-m-order-3-on-sm",
    "order_4OnSm": "pf-m-order-4-on-sm",
    "order_5OnSm": "pf-m-order-5-on-sm",
    "order_6OnSm": "pf-m-order-6-on-sm",
    "order_7OnSm": "pf-m-order-7-on-sm",
    "order_8OnSm": "pf-m-order-8-on-sm",
    "order_9OnSm": "pf-m-order-9-on-sm",
    "order_10OnSm": "pf-m-order-10-on-sm",
    "order_11OnSm": "pf-m-order-11-on-sm",
    "order_12OnSm": "pf-m-order-12-on-sm",
    "orderFirstOnSm": "pf-m-order-first-on-sm",
    "orderLastOnSm": "pf-m-order-last-on-sm",
    "order_0OnMd": "pf-m-order-0-on-md",
    "order_1OnMd": "pf-m-order-1-on-md",
    "order_2OnMd": "pf-m-order-2-on-md",
    "order_3OnMd": "pf-m-order-3-on-md",
    "order_4OnMd": "pf-m-order-4-on-md",
    "order_5OnMd": "pf-m-order-5-on-md",
    "order_6OnMd": "pf-m-order-6-on-md",
    "order_7OnMd": "pf-m-order-7-on-md",
    "order_8OnMd": "pf-m-order-8-on-md",
    "order_9OnMd": "pf-m-order-9-on-md",
    "order_10OnMd": "pf-m-order-10-on-md",
    "order_11OnMd": "pf-m-order-11-on-md",
    "order_12OnMd": "pf-m-order-12-on-md",
    "orderFirstOnMd": "pf-m-order-first-on-md",
    "orderLastOnMd": "pf-m-order-last-on-md",
    "order_0OnLg": "pf-m-order-0-on-lg",
    "order_1OnLg": "pf-m-order-1-on-lg",
    "order_2OnLg": "pf-m-order-2-on-lg",
    "order_3OnLg": "pf-m-order-3-on-lg",
    "order_4OnLg": "pf-m-order-4-on-lg",
    "order_5OnLg": "pf-m-order-5-on-lg",
    "order_6OnLg": "pf-m-order-6-on-lg",
    "order_7OnLg": "pf-m-order-7-on-lg",
    "order_8OnLg": "pf-m-order-8-on-lg",
    "order_9OnLg": "pf-m-order-9-on-lg",
    "order_10OnLg": "pf-m-order-10-on-lg",
    "order_11OnLg": "pf-m-order-11-on-lg",
    "order_12OnLg": "pf-m-order-12-on-lg",
    "orderFirstOnLg": "pf-m-order-first-on-lg",
    "orderLastOnLg": "pf-m-order-last-on-lg",
    "order_0OnXl": "pf-m-order-0-on-xl",
    "order_1OnXl": "pf-m-order-1-on-xl",
    "order_2OnXl": "pf-m-order-2-on-xl",
    "order_3OnXl": "pf-m-order-3-on-xl",
    "order_4OnXl": "pf-m-order-4-on-xl",
    "order_5OnXl": "pf-m-order-5-on-xl",
    "order_6OnXl": "pf-m-order-6-on-xl",
    "order_7OnXl": "pf-m-order-7-on-xl",
    "order_8OnXl": "pf-m-order-8-on-xl",
    "order_9OnXl": "pf-m-order-9-on-xl",
    "order_10OnXl": "pf-m-order-10-on-xl",
    "order_11OnXl": "pf-m-order-11-on-xl",
    "order_12OnXl": "pf-m-order-12-on-xl",
    "orderFirstOnXl": "pf-m-order-first-on-xl",
    "orderLastOnXl": "pf-m-order-last-on-xl",
    "order_0On_2xl": "pf-m-order-0-on-2xl",
    "order_1On_2xl": "pf-m-order-1-on-2xl",
    "order_2On_2xl": "pf-m-order-2-on-2xl",
    "order_3On_2xl": "pf-m-order-3-on-2xl",
    "order_4On_2xl": "pf-m-order-4-on-2xl",
    "order_5On_2xl": "pf-m-order-5-on-2xl",
    "order_6On_2xl": "pf-m-order-6-on-2xl",
    "order_7On_2xl": "pf-m-order-7-on-2xl",
    "order_8On_2xl": "pf-m-order-8-on-2xl",
    "order_9On_2xl": "pf-m-order-9-on-2xl",
    "order_10On_2xl": "pf-m-order-10-on-2xl",
    "order_11On_2xl": "pf-m-order-11-on-2xl",
    "order_12On_2xl": "pf-m-order-12-on-2xl",
    "orderFirstOn_2xl": "pf-m-order-first-on-2xl",
    "orderLastOn_2xl": "pf-m-order-last-on-2xl"
  }
};