/// <reference types="react" />
export interface ProgressHelperTextProps extends React.HTMLProps<HTMLDivElement> {
    /** Content which can be used to convey additional information about the progress component.
     * We recommend the helper text component as it was designed for this purpose.
     */
    children?: React.ReactNode;
}
export declare const ProgressHelperText: React.FunctionComponent<ProgressHelperTextProps>;
//# sourceMappingURL=ProgressHelperText.d.ts.map