"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectOverflow = exports.popperGenerator = exports.createPopper = void 0;
const tslib_1 = require("tslib");
// @ts-nocheck
const _1 = require(".");
Object.defineProperty(exports, "createPopper", { enumerable: true, get: function () { return _1.createPopper; } });
Object.defineProperty(exports, "popperGenerator", { enumerable: true, get: function () { return _1.popperGenerator; } });
Object.defineProperty(exports, "detectOverflow", { enumerable: true, get: function () { return _1.detectOverflow; } });
tslib_1.__exportStar(require("./types"), exports);
//# sourceMappingURL=popper-base.js.map