/**
 * @param node
 */
declare function isElement(node: any): boolean;
/**
 * @param node
 */
declare function isHTMLElement(node: any): boolean;
export { isElement, isHTMLElement };
//# sourceMappingURL=instanceOf.d.ts.map