import './drag-drop.css';
declare const _default: {
  "draggable": "pf-v6-c-draggable",
  "droppable": "pf-v6-c-droppable",
  "modifiers": {
    "dragging": "pf-m-dragging",
    "dragOutside": "pf-m-drag-outside"
  }
};
export default _default;