/// <reference types="react" />
export interface DescriptionListDescriptionProps extends React.HTMLProps<HTMLElement> {
    /** Anything that can be rendered inside of list description */
    children: React.ReactNode;
    /** Additional classes added to the DescriptionListDescription */
    className?: string;
}
export declare const DescriptionListDescription: React.FunctionComponent<DescriptionListDescriptionProps>;
//# sourceMappingURL=DescriptionListDescription.d.ts.map