"use strict";
// @ts-nocheck
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @param len
 */
function getAltLen(len) {
    return len === 'width' ? 'height' : 'width';
}
exports.default = getAltLen;
//# sourceMappingURL=getAltLen.js.map