/// <reference types="react" />
export interface DrawerHeadProps extends React.HTMLProps<HTMLDivElement> {
    /** Additional classes added to the drawer head. */
    className?: string;
    /** Content to be rendered in the drawer head */
    children?: React.ReactNode;
}
export declare const DrawerHead: React.FunctionComponent<DrawerHeadProps>;
//# sourceMappingURL=DrawerHead.d.ts.map