/// <reference types="react" />
export interface LevelItemProps extends React.HTMLProps<HTMLDivElement> {
    /** content rendered inside the Level Layout Item */
    children?: React.ReactNode;
}
export declare const LevelItem: React.FunctionComponent<LevelItemProps>;
//# sourceMappingURL=LevelItem.d.ts.map