import { BasePlacement, Placement, auto } from '../enums';
/**
 * @param placement
 */
export default function getBasePlacement(placement: Placement | typeof auto): BasePlacement;
//# sourceMappingURL=getBasePlacement.d.ts.map