
// Do not edit directly
// Generated on Wed, 10 Sep 2025 19:58:14 GMT

@mixin pf-v6-tokens {
  --pf-t--global--background--color--500: rgba(21, 21, 21, 0.2000);
  --pf-t--global--background--color--600: rgba(199, 199, 199, 0.2500);
  --pf-t--global--background--color--action--plain--default: rgba(255, 255, 255, 0.0000);
  --pf-t--global--border--radius--0: 0px;
  --pf-t--global--border--radius--100: 4px;
  --pf-t--global--border--radius--200: 6px;
  --pf-t--global--border--radius--300: 16px;
  --pf-t--global--border--radius--400: 24px;
  --pf-t--global--border--radius--500: 999px;
  --pf-t--global--border--width--100: 1px;
  --pf-t--global--border--width--200: 2px;
  --pf-t--global--border--width--300: 3px;
  --pf-t--global--border--width--400: 4px;
  --pf-t--global--border--width--action--plain--default: 0px;
  --pf-t--global--box-shadow--X--100: -10px;
  --pf-t--global--box-shadow--X--200: -4px;
  --pf-t--global--box-shadow--X--300: -1px;
  --pf-t--global--box-shadow--X--400: 0px;
  --pf-t--global--box-shadow--X--50: -20px;
  --pf-t--global--box-shadow--X--500: 1px;
  --pf-t--global--box-shadow--X--600: 4px;
  --pf-t--global--box-shadow--X--700: 10px;
  --pf-t--global--box-shadow--X--800: 20px;
  --pf-t--global--box-shadow--Y--100: -10px;
  --pf-t--global--box-shadow--Y--200: -4px;
  --pf-t--global--box-shadow--Y--300: -1px;
  --pf-t--global--box-shadow--Y--400: 0px;
  --pf-t--global--box-shadow--Y--50: -20px;
  --pf-t--global--box-shadow--Y--500: 1px;
  --pf-t--global--box-shadow--Y--600: 4px;
  --pf-t--global--box-shadow--Y--700: 10px;
  --pf-t--global--box-shadow--Y--800: 20px;
  --pf-t--global--box-shadow--blur--100: 4px;
  --pf-t--global--box-shadow--blur--200: 9px;
  --pf-t--global--box-shadow--blur--300: 20px;
  --pf-t--global--box-shadow--color--100: rgba(41, 41, 41, 0.1500);
  --pf-t--global--box-shadow--color--200: rgba(41, 41, 41, 0.2000);
  --pf-t--global--box-shadow--spread--100: 0px;
  --pf-t--global--box-shadow--spread--200: -4px;
  --pf-t--global--box-shadow--spread--300: -8px;
  --pf-t--global--box-shadow--spread--400: -20px;
  --pf-t--global--breakpoint--100: 0rem;
  --pf-t--global--breakpoint--200: 36rem;
  --pf-t--global--breakpoint--250: 40rem;
  --pf-t--global--breakpoint--300: 48rem;
  --pf-t--global--breakpoint--350: 60rem;
  --pf-t--global--breakpoint--400: 62rem;
  --pf-t--global--breakpoint--500: 75rem;
  --pf-t--global--breakpoint--550: 80rem;
  --pf-t--global--breakpoint--600: 90.625rem;
  --pf-t--global--color--nonstatus--green--400: #3d7019;
  --pf-t--global--color--status--success--150: #3d7019;
  --pf-t--global--focus-ring--position--inset: -4px;
  --pf-t--global--focus-ring--position--offset: 2px;
  --pf-t--global--focus-ring--width--inset: 3px;
  --pf-t--global--focus-ring--width--offset: 2px;
  --pf-t--global--font--family--100: "Red Hat Text", "RedHatText", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--200: "Red Hat Display", "RedHatDisplay", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--300: "Red Hat Mono", "RedHatMono", "Courier New", Courier, monospace;
  --pf-t--global--font--line-height--100: 1.3;
  --pf-t--global--font--line-height--200: 1.5;
  --pf-t--global--font--size--100: 0.75rem;
  --pf-t--global--font--size--200: 0.875rem;
  --pf-t--global--font--size--300: 1rem;
  --pf-t--global--font--size--400: 1.125rem;
  --pf-t--global--font--size--500: 1.25rem;
  --pf-t--global--font--size--600: 1.5rem;
  --pf-t--global--font--size--700: 1.75rem;
  --pf-t--global--font--size--800: 2.25rem;
  --pf-t--global--font--weight--100: 400;
  --pf-t--global--font--weight--200: 500;
  --pf-t--global--font--weight--300: 500;
  --pf-t--global--font--weight--400: 700;
  --pf-t--global--icon--size--100: 0.75rem;
  --pf-t--global--icon--size--200: 0.875rem;
  --pf-t--global--icon--size--250: 1rem;
  --pf-t--global--icon--size--300: 1.5rem;
  --pf-t--global--icon--size--400: 3.5rem;
  --pf-t--global--icon--size--500: 6rem;
  --pf-t--global--spacer--100: 0.25rem;
  --pf-t--global--spacer--200: 0.5rem;
  --pf-t--global--spacer--300: 1rem;
  --pf-t--global--spacer--400: 1.5rem;
  --pf-t--global--spacer--500: 2rem;
  --pf-t--global--spacer--600: 3rem;
  --pf-t--global--spacer--700: 4rem;
  --pf-t--global--spacer--800: 5rem;
  --pf-t--global--text-decoration--line--100: none;
  --pf-t--global--text-decoration--line--200: underline;
  --pf-t--global--text-decoration--style--100: solid;
  --pf-t--global--text-decoration--style--200: dashed;
  --pf-t--global--z-index--100: 100;
  --pf-t--global--z-index--200: 200;
  --pf-t--global--z-index--300: 300;
  --pf-t--global--z-index--400: 400;
  --pf-t--global--z-index--500: 500;
  --pf-t--global--z-index--600: 600;
  --pf-t--global--background--color--100: var(--pf-t--color--white);
  --pf-t--global--background--color--200: var(--pf-t--color--gray--10);
  --pf-t--global--background--color--300: var(--pf-t--color--gray--20);
  --pf-t--global--background--color--400: var(--pf-t--color--gray--80);
  --pf-t--global--background--color--450: var(--pf-t--color--gray--70);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--background--color--500);
  --pf-t--global--background--color--highlight--100: var(--pf-t--color--yellow--30);
  --pf-t--global--background--color--highlight--200: var(--pf-t--color--yellow--40);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--background--color--600);
  --pf-t--global--border--color--100: var(--pf-t--color--gray--30);
  --pf-t--global--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--border--color--300: var(--pf-t--color--gray--50);
  --pf-t--global--border--color--400: var(--pf-t--color--gray--60);
  --pf-t--global--border--color--50: var(--pf-t--color--gray--20);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--400);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--150);
  --pf-t--global--border--radius--large: var(--pf-t--global--border--radius--400);
  --pf-t--global--border--radius--medium: var(--pf-t--global--border--radius--300);
  --pf-t--global--border--radius--pill: var(--pf-t--global--border--radius--500);
  --pf-t--global--border--radius--sharp: var(--pf-t--global--border--radius--0);
  --pf-t--global--border--radius--small: var(--pf-t--global--border--radius--200);
  --pf-t--global--border--radius--tiny: var(--pf-t--global--border--radius--100);
  --pf-t--global--border--width--action--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--action--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--plain--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--plain--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--clicked: var(--pf-t--global--border--width--300);
  --pf-t--global--border--width--box--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--status--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--status--read: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--control--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--divider--clicked: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--extra-strong: var(--pf-t--global--border--width--300);
  --pf-t--global--border--width--main--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--regular: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--strong: var(--pf-t--global--border--width--200);
  --pf-t--global--box-shadow--X--lg--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--left: var(--pf-t--global--box-shadow--X--50);
  --pf-t--global--box-shadow--X--lg--right: var(--pf-t--global--box-shadow--X--800);
  --pf-t--global--box-shadow--X--lg--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--left: var(--pf-t--global--box-shadow--X--100);
  --pf-t--global--box-shadow--X--md--right: var(--pf-t--global--box-shadow--X--700);
  --pf-t--global--box-shadow--X--md--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--left: var(--pf-t--global--box-shadow--X--200);
  --pf-t--global--box-shadow--X--sm--right: var(--pf-t--global--box-shadow--X--600);
  --pf-t--global--box-shadow--X--sm--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--Y--lg--bottom: var(--pf-t--global--box-shadow--Y--800);
  --pf-t--global--box-shadow--Y--lg--default: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--lg--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--top: var(--pf-t--global--box-shadow--Y--50);
  --pf-t--global--box-shadow--Y--md--bottom: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--md--default: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--md--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--top: var(--pf-t--global--box-shadow--Y--100);
  --pf-t--global--box-shadow--Y--sm--bottom: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--sm--default: var(--pf-t--global--box-shadow--Y--500);
  --pf-t--global--box-shadow--Y--sm--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--top: var(--pf-t--global--box-shadow--Y--200);
  --pf-t--global--box-shadow--blur--lg: var(--pf-t--global--box-shadow--blur--300);
  --pf-t--global--box-shadow--blur--md: var(--pf-t--global--box-shadow--blur--200);
  --pf-t--global--box-shadow--blur--sm: var(--pf-t--global--box-shadow--blur--100);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--spread--lg--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--lg--directional: var(--pf-t--global--box-shadow--spread--400);
  --pf-t--global--box-shadow--spread--md--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--md--directional: var(--pf-t--global--box-shadow--spread--300);
  --pf-t--global--box-shadow--spread--sm--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--sm--directional: var(--pf-t--global--box-shadow--spread--200);
  --pf-t--global--breakpoint--2xl: var(--pf-t--global--breakpoint--600);
  --pf-t--global--breakpoint--height--2xl: var(--pf-t--global--breakpoint--550);
  --pf-t--global--breakpoint--height--lg: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--height--md: var(--pf-t--global--breakpoint--250);
  --pf-t--global--breakpoint--height--sm: var(--pf-t--global--breakpoint--100);
  --pf-t--global--breakpoint--height--xl: var(--pf-t--global--breakpoint--350);
  --pf-t--global--breakpoint--lg: var(--pf-t--global--breakpoint--400);
  --pf-t--global--breakpoint--md: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--sm: var(--pf-t--global--breakpoint--200);
  --pf-t--global--breakpoint--xl: var(--pf-t--global--breakpoint--500);
  --pf-t--global--breakpoint--xs: var(--pf-t--global--breakpoint--100);
  --pf-t--global--color--brand--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--brand--200: var(--pf-t--color--blue--50);
  --pf-t--global--color--brand--300: var(--pf-t--color--blue--60);
  --pf-t--global--color--brand--400: var(--pf-t--color--blue--70);
  --pf-t--global--color--brand--500: var(--pf-t--color--blue--80);
  --pf-t--global--color--disabled--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--disabled--200: var(--pf-t--color--gray--40);
  --pf-t--global--color--disabled--300: var(--pf-t--color--gray--60);
  --pf-t--global--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--favorite--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--favorite--300: var(--pf-t--color--yellow--70);
  --pf-t--global--color--favorite--400: var(--pf-t--color--yellow--80);
  --pf-t--global--color--nonstatus--blue--100: var(--pf-t--color--blue--20);
  --pf-t--global--color--nonstatus--blue--200: var(--pf-t--color--blue--30);
  --pf-t--global--color--nonstatus--blue--300: var(--pf-t--color--blue--40);
  --pf-t--global--color--nonstatus--blue--400: var(--pf-t--color--blue--60);
  --pf-t--global--color--nonstatus--blue--500: var(--pf-t--color--blue--70);
  --pf-t--global--color--nonstatus--gray--100: var(--pf-t--color--gray--20);
  --pf-t--global--color--nonstatus--gray--200: var(--pf-t--color--gray--30);
  --pf-t--global--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--color--nonstatus--gray--400: var(--pf-t--color--gray--60);
  --pf-t--global--color--nonstatus--gray--50: var(--pf-t--color--gray--10);
  --pf-t--global--color--nonstatus--gray--500: var(--pf-t--color--gray--70);
  --pf-t--global--color--nonstatus--green--100: var(--pf-t--color--green--20);
  --pf-t--global--color--nonstatus--green--200: var(--pf-t--color--green--30);
  --pf-t--global--color--nonstatus--green--300: var(--pf-t--color--green--40);
  --pf-t--global--color--nonstatus--green--500: var(--pf-t--color--green--70);
  --pf-t--global--color--nonstatus--orange--100: var(--pf-t--color--orange--20);
  --pf-t--global--color--nonstatus--orange--200: var(--pf-t--color--orange--30);
  --pf-t--global--color--nonstatus--orange--300: var(--pf-t--color--orange--40);
  --pf-t--global--color--nonstatus--orange--400: var(--pf-t--color--orange--60);
  --pf-t--global--color--nonstatus--orange--500: var(--pf-t--color--orange--70);
  --pf-t--global--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--20);
  --pf-t--global--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--30);
  --pf-t--global--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--40);
  --pf-t--global--color--nonstatus--orangered--400: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--nonstatus--orangered--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--nonstatus--purple--100: var(--pf-t--color--purple--20);
  --pf-t--global--color--nonstatus--purple--200: var(--pf-t--color--purple--30);
  --pf-t--global--color--nonstatus--purple--300: var(--pf-t--color--purple--40);
  --pf-t--global--color--nonstatus--purple--400: var(--pf-t--color--purple--50);
  --pf-t--global--color--nonstatus--purple--500: var(--pf-t--color--purple--60);
  --pf-t--global--color--nonstatus--red--100: var(--pf-t--color--red--20);
  --pf-t--global--color--nonstatus--red--200: var(--pf-t--color--red--30);
  --pf-t--global--color--nonstatus--red--300: var(--pf-t--color--red--40);
  --pf-t--global--color--nonstatus--red--400: var(--pf-t--color--red--60);
  --pf-t--global--color--nonstatus--red--500: var(--pf-t--color--red--70);
  --pf-t--global--color--nonstatus--teal--100: var(--pf-t--color--teal--20);
  --pf-t--global--color--nonstatus--teal--200: var(--pf-t--color--teal--30);
  --pf-t--global--color--nonstatus--teal--300: var(--pf-t--color--teal--40);
  --pf-t--global--color--nonstatus--teal--400: var(--pf-t--color--teal--70);
  --pf-t--global--color--nonstatus--teal--500: var(--pf-t--color--teal--80);
  --pf-t--global--color--nonstatus--yellow--100: var(--pf-t--color--yellow--20);
  --pf-t--global--color--nonstatus--yellow--200: var(--pf-t--color--yellow--30);
  --pf-t--global--color--nonstatus--yellow--300: var(--pf-t--color--yellow--40);
  --pf-t--global--color--nonstatus--yellow--400: var(--pf-t--color--yellow--70);
  --pf-t--global--color--nonstatus--yellow--500: var(--pf-t--color--yellow--80);
  --pf-t--global--color--severity--critical--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--severity--important--100: var(--pf-t--color--orange--50);
  --pf-t--global--color--severity--important--200: var(--pf-t--color--orange--60);
  --pf-t--global--color--severity--minor--100: var(--pf-t--color--gray--50);
  --pf-t--global--color--severity--minor--200: var(--pf-t--color--gray--80);
  --pf-t--global--color--severity--moderate--100: var(--pf-t--color--yellow--40);
  --pf-t--global--color--severity--moderate--200: var(--pf-t--color--yellow--70);
  --pf-t--global--color--severity--none--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--severity--none--200: var(--pf-t--color--blue--60);
  --pf-t--global--color--severity--undefined--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--severity--undefined--200: var(--pf-t--color--gray--60);
  --pf-t--global--color--status--custom--100: var(--pf-t--color--teal--60);
  --pf-t--global--color--status--custom--200: var(--pf-t--color--teal--70);
  --pf-t--global--color--status--custom--300: var(--pf-t--color--teal--80);
  --pf-t--global--color--status--danger--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--status--danger--200: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--status--danger--300: var(--pf-t--color--red-orange--80);
  --pf-t--global--color--status--info--100: var(--pf-t--color--purple--50);
  --pf-t--global--color--status--info--200: var(--pf-t--color--purple--60);
  --pf-t--global--color--status--info--300: var(--pf-t--color--purple--70);
  --pf-t--global--color--status--success--100: var(--pf-t--color--green--60);
  --pf-t--global--color--status--success--200: var(--pf-t--color--green--70);
  --pf-t--global--color--status--success--300: var(--pf-t--color--green--80);
  --pf-t--global--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--status--warning--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--status--warning--300: var(--pf-t--color--yellow--50);
  --pf-t--global--color--status--warning--400: var(--pf-t--color--yellow--60);
  --pf-t--global--color--status--warning--500: var(--pf-t--color--yellow--70);
  --pf-t--global--color--status--warning--600: var(--pf-t--color--yellow--80);
  --pf-t--global--focus-ring--color--100: var(--pf-t--color--blue--50);
  --pf-t--global--focus-ring--color--200: var(--pf-t--color--blue--60);
  --pf-t--global--font--family--body: var(--pf-t--global--font--family--100);
  --pf-t--global--font--family--heading: var(--pf-t--global--font--family--200);
  --pf-t--global--font--family--mono: var(--pf-t--global--font--family--300);
  --pf-t--global--font--line-height--body: var(--pf-t--global--font--line-height--200);
  --pf-t--global--font--line-height--heading: var(--pf-t--global--font--line-height--100);
  --pf-t--global--font--size--2xl: var(--pf-t--global--font--size--600);
  --pf-t--global--font--size--3xl: var(--pf-t--global--font--size--700);
  --pf-t--global--font--size--4xl: var(--pf-t--global--font--size--800);
  --pf-t--global--font--size--lg: var(--pf-t--global--font--size--400);
  --pf-t--global--font--size--md: var(--pf-t--global--font--size--300);
  --pf-t--global--font--size--sm: var(--pf-t--global--font--size--200);
  --pf-t--global--font--size--xl: var(--pf-t--global--font--size--500);
  --pf-t--global--font--size--xs: var(--pf-t--global--font--size--100);
  --pf-t--global--font--weight--body--bold: var(--pf-t--global--font--weight--200);
  --pf-t--global--font--weight--body--default: var(--pf-t--global--font--weight--100);
  --pf-t--global--font--weight--heading--bold: var(--pf-t--global--font--weight--400);
  --pf-t--global--font--weight--heading--default: var(--pf-t--global--font--weight--300);
  --pf-t--global--icon--color--100: var(--pf-t--color--gray--90);
  --pf-t--global--icon--color--150: var(--pf-t--color--gray--60);
  --pf-t--global--icon--color--200: var(--pf-t--color--gray--50);
  --pf-t--global--icon--color--300: var(--pf-t--color--white);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--color--blue--70);
  --pf-t--global--icon--color--brand--default: var(--pf-t--color--blue--60);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--color--blue--70);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--150);
  --pf-t--global--icon--size--2xl: var(--pf-t--global--icon--size--400);
  --pf-t--global--icon--size--3xl: var(--pf-t--global--icon--size--500);
  --pf-t--global--icon--size--lg: var(--pf-t--global--icon--size--250);
  --pf-t--global--icon--size--md: var(--pf-t--global--icon--size--200);
  --pf-t--global--icon--size--sm: var(--pf-t--global--icon--size--100);
  --pf-t--global--icon--size--xl: var(--pf-t--global--icon--size--300);
  --pf-t--global--spacer--2xl: var(--pf-t--global--spacer--600);
  --pf-t--global--spacer--3xl: var(--pf-t--global--spacer--700);
  --pf-t--global--spacer--4xl: var(--pf-t--global--spacer--800);
  --pf-t--global--spacer--lg: var(--pf-t--global--spacer--400);
  --pf-t--global--spacer--md: var(--pf-t--global--spacer--300);
  --pf-t--global--spacer--sm: var(--pf-t--global--spacer--200);
  --pf-t--global--spacer--xl: var(--pf-t--global--spacer--500);
  --pf-t--global--spacer--xs: var(--pf-t--global--spacer--100);
  --pf-t--global--text--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--text--color--200: var(--pf-t--color--gray--60);
  --pf-t--global--text--color--250: var(--pf-t--color--gray--70);
  --pf-t--global--text--color--300: var(--pf-t--color--white);
  --pf-t--global--text--color--400: var(--pf-t--color--red-orange--40);
  --pf-t--global--text--color--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--color--blue--80);
  --pf-t--global--text--color--brand--default: var(--pf-t--color--blue--70);
  --pf-t--global--text--color--brand--hover: var(--pf-t--color--blue--80);
  --pf-t--global--text--color--link--100: var(--pf-t--color--blue--50);
  --pf-t--global--text--color--link--200: var(--pf-t--color--blue--60);
  --pf-t--global--text--color--link--250: var(--pf-t--color--blue--70);
  --pf-t--global--text--color--link--300: var(--pf-t--color--purple--50);
  --pf-t--global--text--color--link--350: var(--pf-t--color--purple--60);
  --pf-t--global--text-decoration--editable-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--editable-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--link--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--style--default: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--text-decoration--link--style--hover: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--z-index--2xl: var(--pf-t--global--z-index--600);
  --pf-t--global--z-index--lg: var(--pf-t--global--z-index--400);
  --pf-t--global--z-index--md: var(--pf-t--global--z-index--300);
  --pf-t--global--z-index--sm: var(--pf-t--global--z-index--200);
  --pf-t--global--z-index--xl: var(--pf-t--global--z-index--500);
  --pf-t--global--z-index--xs: var(--pf-t--global--z-index--100);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--color--disabled--100);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--primary--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--background--color--300);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--background--color--300);
  --pf-t--global--border--color--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--border--color--hover: var(--pf-t--global--color--brand--300);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--400);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--400);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--400);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--400);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--400);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--400);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--400);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--400);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--width--high-contrast--extra-strong: var(--pf-t--global--border--width--extra-strong);
  --pf-t--global--border--width--high-contrast--regular: var(--pf-t--global--border--width--regular);
  --pf-t--global--border--width--high-contrast--strong: var(--pf-t--global--border--width--strong);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--brand--default: var(--pf-t--global--color--brand--300);
  --pf-t--global--color--brand--hover: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--favorite--default: var(--pf-t--global--color--favorite--300);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--50);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--color--status--custom--200);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--info--default: var(--pf-t--global--color--status--info--200);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--focus-ring--color--200);
  --pf-t--global--font--size--body--default: var(--pf-t--global--font--size--sm);
  --pf-t--global--font--size--body--lg: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--body--sm: var(--pf-t--global--font--size--xs);
  --pf-t--global--font--size--heading--h1: var(--pf-t--global--font--size--2xl);
  --pf-t--global--font--size--heading--h2: var(--pf-t--global--font--size--xl);
  --pf-t--global--font--size--heading--h3: var(--pf-t--global--font--size--lg);
  --pf-t--global--font--size--heading--h4: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h5: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h6: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--color--severity--critical--100);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--color--severity--important--200);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--color--severity--minor--200);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--color--severity--moderate--200);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--color--severity--none--200);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--color--severity--undefined--200);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--100);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--icon--color--150);
  --pf-t--global--icon--size--font--2xl: var(--pf-t--global--font--size--2xl);
  --pf-t--global--icon--size--font--3xl: var(--pf-t--global--font--size--3xl);
  --pf-t--global--icon--size--font--4xl: var(--pf-t--global--font--size--4xl);
  --pf-t--global--icon--size--font--lg: var(--pf-t--global--font--size--lg);
  --pf-t--global--icon--size--font--md: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--size--font--sm: var(--pf-t--global--font--size--sm);
  --pf-t--global--icon--size--font--xl: var(--pf-t--global--font--size--xl);
  --pf-t--global--icon--size--font--xs: var(--pf-t--global--font--size--xs);
  --pf-t--global--spacer--action--horizontal--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--action--horizontal--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--action--horizontal--plain--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--action--horizontal--plain--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--action--horizontal--spacious: var(--pf-t--global--spacer--xl);
  --pf-t--global--spacer--control--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--control--horizontal--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--spacious: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--control--vertical--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--control--vertical--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--spacious: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--plain: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--control-to-control--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--group--horizontal: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group--vertical: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--default: var(--pf-t--global--spacer--2xl);
  --pf-t--global--spacer--gap--group-to-group--vertical--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group-to-group--vertical--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--gap--text-to-element--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--text-to-element--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gutter--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--inset--page-chrome: var(--pf-t--global--spacer--lg);
  --pf-t--global--text--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--text--color--link--200);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--text--color--link--250);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--text--color--link--350);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--regular: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--text--color--500);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--subtle: var(--pf-t--global--text--color--250);
  --pf-t--global--text-decoration--offset--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--text-decoration--width--default: var(--pf-t--global--border--width--regular);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--control--default: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--high-contrast: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--main--default: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--size--font--body--default: var(--pf-t--global--font--size--body--default);
  --pf-t--global--icon--size--font--body--lg: var(--pf-t--global--font--size--body--lg);
  --pf-t--global--icon--size--font--body--sm: var(--pf-t--global--font--size--body--sm);
  --pf-t--global--icon--size--font--heading--h1: var(--pf-t--global--font--size--heading--h1);
  --pf-t--global--icon--size--font--heading--h2: var(--pf-t--global--font--size--heading--h2);
  --pf-t--global--icon--size--font--heading--h3: var(--pf-t--global--font--size--heading--h3);
  --pf-t--global--icon--size--font--heading--h4: var(--pf-t--global--font--size--heading--h4);
  --pf-t--global--icon--size--font--heading--h5: var(--pf-t--global--font--size--heading--h5);
  --pf-t--global--icon--size--font--heading--h6: var(--pf-t--global--font--size--heading--h6);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
}
