/// <reference types="react" />
export interface LoginMainFooterLinksItemProps extends React.HTMLProps<HTMLLIElement> {
    /** Content rendered inside the footer link item */
    children?: React.ReactNode;
    /** Additional classes added to the footer link item  */
    className?: string;
}
export declare const LoginMainFooterLinksItem: React.FunctionComponent<LoginMainFooterLinksItemProps>;
//# sourceMappingURL=LoginMainFooterLinksItem.d.ts.map