import { createIcon } from '../createIcon';

export const YandexInternationalIconConfig = {
  name: 'YandexInternationalIcon',
  height: 512,
  width: 320,
  svgPath: "M129.5 512V345.9L18.5 48h55.8l81.8 229.7L250.2 0h51.3L180.8 347.8V512h-51.3z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const YandexInternationalIcon = createIcon(YandexInternationalIconConfig);

export default YandexInternationalIcon;