import './multiple-file-upload.css';
export default {
  "modifiers": {
    "horizontal": "pf-m-horizontal",
    "dragOver": "pf-m-drag-over"
  },
  "multipleFileUpload": "pf-v6-c-multiple-file-upload",
  "multipleFileUploadInfo": "pf-v6-c-multiple-file-upload__info",
  "multipleFileUploadMain": "pf-v6-c-multiple-file-upload__main",
  "multipleFileUploadStatus": "pf-v6-c-multiple-file-upload__status",
  "multipleFileUploadStatusItem": "pf-v6-c-multiple-file-upload__status-item",
  "multipleFileUploadStatusItemIcon": "pf-v6-c-multiple-file-upload__status-item-icon",
  "multipleFileUploadStatusItemMain": "pf-v6-c-multiple-file-upload__status-item-main",
  "multipleFileUploadStatusItemProgress": "pf-v6-c-multiple-file-upload__status-item-progress",
  "multipleFileUploadStatusItemProgressSize": "pf-v6-c-multiple-file-upload__status-item-progress-size",
  "multipleFileUploadStatusItemProgressText": "pf-v6-c-multiple-file-upload__status-item-progress-text",
  "multipleFileUploadStatusProgress": "pf-v6-c-multiple-file-upload__status-progress",
  "multipleFileUploadStatusProgressIcon": "pf-v6-c-multiple-file-upload__status-progress-icon",
  "multipleFileUploadTitle": "pf-v6-c-multiple-file-upload__title",
  "multipleFileUploadTitleIcon": "pf-v6-c-multiple-file-upload__title-icon",
  "multipleFileUploadTitleText": "pf-v6-c-multiple-file-upload__title-text",
  "multipleFileUploadTitleTextSeparator": "pf-v6-c-multiple-file-upload__title-text-separator",
  "multipleFileUploadUpload": "pf-v6-c-multiple-file-upload__upload"
};