/// <reference types="react" />
export declare const SIDE: {
    RIGHT: string;
    LEFT: string;
    BOTH: string;
    NONE: string;
};
export declare const KEYHANDLER_DIRECTION: {
    UP: string;
    DOWN: string;
    RIGHT: string;
    LEFT: string;
};
export declare enum ValidatedOptions {
    success = "success",
    error = "error",
    warning = "warning",
    default = "default"
}
export declare const KeyTypes: {
    Tab: string;
    Space: string;
    Escape: string;
    Enter: string;
    ArrowUp: string;
    ArrowDown: string;
    ArrowLeft: string;
    ArrowRight: string;
};
export declare const globalWidthBreakpoints: {
    sm: number;
    md: number;
    lg: number;
    xl: number;
    '2xl': number;
};
export declare const globalHeightBreakpoints: {
    sm: number;
    md: number;
    lg: number;
    xl: number;
    '2xl': number;
};
export declare const statusIcons: {
    success: import("react").ComponentClass<SVGIconProps, any>;
    danger: import("react").ComponentClass<SVGIconProps, any>;
    warning: import("react").ComponentClass<SVGIconProps, any>;
    info: import("react").ComponentClass<SVGIconProps, any>;
    custom: import("react").ComponentClass<SVGIconProps, any>;
};
//# sourceMappingURL=constants.d.ts.map