"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TabContentBody = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_styles_1 = require("@patternfly/react-styles");
const tab_content_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/TabContent/tab-content"));
const TabContentBody = (_a) => {
    var { children, className, hasPadding } = _a, props = tslib_1.__rest(_a, ["children", "className", "hasPadding"]);
    return ((0, jsx_runtime_1.jsx)("div", Object.assign({ className: (0, react_styles_1.css)(tab_content_1.default.tabContentBody, hasPadding && tab_content_1.default.modifiers.padding, className) }, props, { children: children })));
};
exports.TabContentBody = TabContentBody;
exports.TabContentBody.displayName = 'TabContentBody';
//# sourceMappingURL=TabContentBody.js.map