import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const DoorClosedIconConfig: {
  name: 'DoorClosedIcon',
  height: 512,
  width: 640,
  svgPath: "M624 448H512V50.8C512 22.78 490.47 0 464 0H175.99c-26.47 0-48 22.78-48 50.8V448H16c-8.84 0-16 7.16-16 16v32c0 8.84 7.16 16 16 16h608c8.84 0 16-7.16 16-16v-32c0-8.84-7.16-16-16-16zM415.99 288c-17.67 0-32-14.33-32-32s14.33-32 32-32 32 14.33 32 32c.01 17.67-14.32 32-32 32z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const DoorClosedIcon: ComponentClass<SVGIconProps>;
export default DoorClosedIcon;