"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @param placement
 */
function getBasePlacement(placement) {
    return placement.split('-')[0];
}
exports.default = getBasePlacement;
//# sourceMappingURL=getBasePlacement.js.map