import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const BrushIconConfig: {
  name: 'BrushIcon',
  height: 512,
  width: 384,
  svgPath: "M352 0H32C14.33 0 0 14.33 0 32v224h384V32c0-17.67-14.33-32-32-32zM0 320c0 35.35 28.66 64 64 64h64v64c0 35.35 28.66 64 64 64s64-28.65 64-64v-64h64c35.34 0 64-28.65 64-64v-32H0v32zm192 104c13.25 0 24 10.74 24 24 0 13.25-10.75 24-24 24s-24-10.75-24-24c0-13.26 10.75-24 24-24z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const BrushIcon: ComponentClass<SVGIconProps>;
export default BrushIcon;