/// <reference types="react" />
export interface AccordionItemProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the accordion item. */
    children?: React.ReactNode;
    /** Additional classes added to the accordion item. */
    className?: string;
    /** Flag to indicate whether the accordion item is expanded. */
    isExpanded?: boolean;
}
export declare const AccordionItem: React.FunctionComponent<AccordionItemProps>;
//# sourceMappingURL=AccordionItem.d.ts.map