/// <reference types="react" />
export interface LoginFooterProps extends React.HTMLProps<HTMLElement> {
    /** Content rendered inside the footer of the login layout */
    children?: React.ReactNode;
    /** Additional props are spread to the container <footer> */
    className?: string;
}
export declare const LoginFooter: React.FunctionComponent<LoginFooterProps>;
//# sourceMappingURL=LoginFooter.d.ts.map