"use strict";
exports.__esModule = true;
require('./timestamp.css');
exports.default = {
  "modifiers": {
    "helpText": "pf-m-help-text"
  },
  "timestamp": "pf-v6-c-timestamp",
  "timestampText": "pf-v6-c-timestamp__text"
};