import { Placement } from '../enums';
/**
 * @param placement
 */
export default function getMainAxisFromPlacement(placement: Placement): 'x' | 'y';
//# sourceMappingURL=getMainAxisFromPlacement.d.ts.map