export const data = [
  {
    id: 0,
    name: 'PatternFly',
    description: 'PatternFly is a community project that promotes design commonality and improves user experience.',
    icon: 'pfIcon'
  },
  {
    id: 1,
    name: 'ActiveMQ',
    description:
      'The ActiveMQ component allows messages to be sent to a JMS Queue or Topic; or messages to be consumed from a JMS Queue or Topic using Apache ActiveMQ.',
    icon: 'activeMQIcon'
  },
  {
    id: 2,
    name: 'Apache Spark',
    description: 'This documentation page covers the Apache Spark component for the Apache Camel.',
    icon: 'sparkIcon'
  },
  {
    id: 3,
    name: 'Avro',
    description:
      'This component provides a dataformat for avro, which allows serialization and deserialization of messages using Apache Avro’s binary dataformat. Moreover, it provides support for Apache Avro’s rpc, by providing producers and consumers endpoint for using avro over netty or http.',
    icon: 'avroIcon'
  },
  {
    id: 4,
    name: 'Azure Services',
    description: 'The Camel Components for Windows Azure Services provide connectivity to Azure services from Camel.',
    icon: 'azureIcon'
  },
  {
    id: 5,
    name: 'Crypto',
    description:
      'For providing flexible endpoints to sign and verify exchanges using the Signature Service of the Java Cryptographic Extension.',
    icon: 'saxonIcon'
  },
  {
    id: 6,
    name: 'DropBox',
    description:
      'The dropbox component allows you to treat Dropbox remote folders as a producer or consumer of messages.',
    icon: 'dropBoxIcon'
  },
  {
    id: 7,
    name: 'JBoss Data Grid',
    description: 'Read or write to a fully-supported distributed cache and data grid for faster integration services.',
    icon: 'infinispanIcon'
  },
  {
    id: 8,
    name: 'REST',
    description:
      'The rest component allows to define REST endpoints (consumer) using the Rest DSL and plugin to other Camel components as the REST transport. From Camel 2.18 onwards the rest component can also be used as a client (producer) to call REST services.',
    icon: 'restIcon'
  },
  {
    id: 9,
    name: 'SWAGGER',
    description: 'Expose REST services and their APIs using Swagger specification.',
    icon: 'swaggerIcon'
  }
];
