"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlertContext = void 0;
const react_1 = require("react");
exports.AlertContext = (0, react_1.createContext)(null);
//# sourceMappingURL=AlertContext.js.map