import './progress.css';
declare const _default: {
  "modifiers": {
    "sm": "pf-m-sm",
    "lg": "pf-m-lg",
    "inside": "pf-m-inside",
    "outside": "pf-m-outside",
    "staticWidth": "pf-m-static-width",
    "singleline": "pf-m-singleline",
    "success": "pf-m-success",
    "warning": "pf-m-warning",
    "danger": "pf-m-danger",
    "truncate": "pf-m-truncate"
  },
  "progress": "pf-v6-c-progress",
  "progressBar": "pf-v6-c-progress__bar",
  "progressDescription": "pf-v6-c-progress__description",
  "progressHelperText": "pf-v6-c-progress__helper-text",
  "progressIndicator": "pf-v6-c-progress__indicator",
  "progressMeasure": "pf-v6-c-progress__measure",
  "progressStatus": "pf-v6-c-progress__status",
  "progressStatusIcon": "pf-v6-c-progress__status-icon"
};
export default _default;