"use strict";
exports.__esModule = true;
require('./tab-content.css');
exports.default = {
  "modifiers": {
    "secondary": "pf-m-secondary",
    "padding": "pf-m-padding"
  },
  "tabContent": "pf-v6-c-tab-content",
  "tabContentBody": "pf-v6-c-tab-content__body"
};