/// <reference types="react" />
export interface MastheadMainProps extends React.DetailedHTMLProps<React.HTMLProps<HTMLDivElement>, HTMLDivElement> {
    /** Content rendered inside of the masthead main block. */
    children?: React.ReactNode;
    /** Additional classes added to the masthead main. */
    className?: string;
}
export declare const MastheadMain: React.FunctionComponent<MastheadMainProps>;
//# sourceMappingURL=MastheadMain.d.ts.map