import './inline-edit.css';
export default {
  "modifiers": {
    "editing": "pf-m-editing",
    "tableEditingFirstRow": "pf-m-table-editing-first-row",
    "tableEditingLastRow": "pf-m-table-editing-last-row",
    "top": "pf-m-top",
    "bottom": "pf-m-bottom",
    "bold": "pf-m-bold"
  },
  "tableEditableRow": "pf-v6-c-table__editable-row",
  "tableInlineEditButtons": "pf-v6-c-table__inline-edit-buttons"
};