/// <reference types="react" />
export interface TreeViewListProps extends React.HTMLProps<HTMLUListElement> {
    /** Child nodes of the current tree view. */
    children: React.ReactNode;
    /** Flag indicating if the tree view is nested under another tree view. */
    isNested?: boolean;
    /** Toolbar to display above the tree view. */
    toolbar?: React.ReactNode;
    /** Flag indicating whether multiple nodes can be selected in the tree view. This will also set the
     * aria-multiselectable attribute on the tree view list which is required to be true when multiple selection is intended.
     * Can only be applied to the root tree view list.
     */
    isMultiSelectable?: boolean;
    /** A text string that sets the accessible name of the tree view list. Either this or the aria-labelledby property must
     * be passed in.
     */
    'aria-label'?: string;
    /** A space separated list of element id's that sets the accessible name of the tree view list. Either
     * this or the aria-label property must be passed in.
     */
    'aria-labelledby'?: string;
}
export declare const TreeViewList: React.FunctionComponent<TreeViewListProps>;
//# sourceMappingURL=TreeViewList.d.ts.map