import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const CompactDiscIconConfig: {
  name: 'CompactDiscIcon',
  height: 512,
  width: 496,
  svgPath: "M248 8C111 8 0 119 0 256s111 248 248 248 248-111 248-248S385 8 248 8zM88 256H56c0-105.9 86.1-192 192-192v32c-88.2 0-160 71.8-160 160zm160 96c-53 0-96-43-96-96s43-96 96-96 96 43 96 96-43 96-96 96zm0-128c-17.7 0-32 14.3-32 32s14.3 32 32 32 32-14.3 32-32-14.3-32-32-32z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const CompactDiscIcon: ComponentClass<SVGIconProps>;
export default CompactDiscIcon;