/// <reference types="react" />
export interface MultipleFileUploadInfoProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside multiple file upload info */
    children?: React.ReactNode;
    /** Class to add to outer div */
    className?: string;
}
export declare const MultipleFileUploadInfo: React.FunctionComponent<MultipleFileUploadInfoProps>;
//# sourceMappingURL=MultipleFileUploadInfo.d.ts.map