import './hint.css';
export default {
  "button": "pf-v6-c-button",
  "hint": "pf-v6-c-hint",
  "hintActions": "pf-v6-c-hint__actions",
  "hintBody": "pf-v6-c-hint__body",
  "hintFooter": "pf-v6-c-hint__footer",
  "hintTitle": "pf-v6-c-hint__title",
  "modifiers": {
    "link": "pf-m-link",
    "inline": "pf-m-inline",
    "noOffset": "pf-m-no-offset"
  }
};