/// <reference types="react" />
export interface MultipleFileUploadButtonProps extends React.HTMLProps<HTMLDivElement> {
    /** Class to add to outer div */
    className?: string;
    /** Aria-label for the button */
    'aria-label'?: string;
    /** Visible text label for the button */
    browseButtonText?: string;
}
export declare const MultipleFileUploadButton: React.FunctionComponent<MultipleFileUploadButtonProps>;
//# sourceMappingURL=MultipleFileUploadButton.d.ts.map