"use strict";
exports.__esModule = true;
require('./back-to-top.css');
exports.default = {
  "backToTop": "pf-v6-c-back-to-top",
  "button": "pf-v6-c-button",
  "modifiers": {
    "hidden": "pf-m-hidden"
  }
};