import { Radio } from '@patternfly/react-core';

export const RadioUncontrolled: React.FunctionComponent = () => (
  <Radio label="Uncontrolled radio example" id="radio-uncontrolled" name="radio-2" />
);
