import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const OutlinedCalendarMinusIconConfig: {
  name: 'OutlinedCalendarMinusIcon',
  height: 512,
  width: 448,
  svgPath: "M124 328c-6.6 0-12-5.4-12-12v-24c0-6.6 5.4-12 12-12h200c6.6 0 12 5.4 12 12v24c0 6.6-5.4 12-12 12H124zm324-216v352c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V112c0-26.5 21.5-48 48-48h48V12c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v52h128V12c0-6.6 5.4-12 12-12h40c6.6 0 12 5.4 12 12v52h48c26.5 0 48 21.5 48 48zm-48 346V160H48v298c0 3.3 2.7 6 6 6h340c3.3 0 6-2.7 6-6z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const OutlinedCalendarMinusIcon: ComponentClass<SVGIconProps>;
export default OutlinedCalendarMinusIcon;