/// <reference types="react" />
export interface ActionGroupProps extends React.HTMLProps<HTMLDivElement> {
    /** Anything that can be rendered as ActionGroup content. */
    children?: React.ReactNode;
    /** Additional classes added to the ActionGroup. */
    className?: string;
}
export declare const ActionGroup: React.FunctionComponent<ActionGroupProps>;
//# sourceMappingURL=ActionGroup.d.ts.map