"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWizardFooter = void 0;
var useWizardFooter_1 = require("./useWizardFooter");
Object.defineProperty(exports, "useWizardFooter", { enumerable: true, get: function () { return useWizardFooter_1.useWizardFooter; } });
//# sourceMappingURL=index.js.map