import { createIcon } from '../createIcon';

export const OutlinedCaretSquareRightIconConfig = {
  name: 'OutlinedCaretSquareRightIcon',
  height: 512,
  width: 448,
  svgPath: "M176 354.9V157.1c0-10.7 13-16.1 20.5-8.5l98.3 98.9c4.7 4.7 4.7 12.2 0 16.9l-98.3 98.9c-7.5 7.7-20.5 2.3-20.5-8.4zM448 80v352c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V80c0-26.5 21.5-48 48-48h352c26.5 0 48 21.5 48 48zm-48 346V86c0-3.3-2.7-6-6-6H54c-3.3 0-6 2.7-6 6v340c0 3.3 2.7 6 6 6h340c3.3 0 6-2.7 6-6z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const OutlinedCaretSquareRightIcon = createIcon(OutlinedCaretSquareRightIconConfig);

export default OutlinedCaretSquareRightIcon;