/// <reference types="react" />
export interface PopoverHeaderIconProps extends React.HTMLProps<HTMLSpanElement> {
    /** Content of the header icon */
    children: React.ReactNode;
    /** Class to be applied to the header icon */
    className?: string;
}
export declare const PopoverHeaderIcon: React.FunctionComponent<PopoverHeaderIconProps>;
//# sourceMappingURL=PopoverHeaderIcon.d.ts.map