import { ClientRectObject } from '../types';
import { Boundary, RootBoundary } from '../enums';
/**
 * @param element
 * @param boundary
 * @param rootBoundary
 */
export default function getClippingRect(element: Element, boundary: Boundary, rootBoundary: RootBoundary): ClientRectObject;
//# sourceMappingURL=getClippingRect.d.ts.map