/// <reference types="react" />
export interface LoginMainBodyProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the login main body */
    children?: React.ReactNode;
    /** Additional classes added to the login main body */
    className?: string;
}
export declare const LoginMainBody: React.FunctionComponent<LoginMainBodyProps>;
//# sourceMappingURL=LoginMainBody.d.ts.map