"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WizardHeader = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const wizard_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Wizard/wizard"));
const react_styles_1 = require("@patternfly/react-styles");
const Button_1 = require("../Button");
const times_icon_1 = tslib_1.__importDefault(require('@patternfly/react-icons/dist/js/icons/times-icon'));
const WizardHeader = (_a) => {
    var { onClose = () => undefined, title, description, isCloseHidden, closeButtonAriaLabel, titleId, descriptionComponent: Component = 'div', descriptionId, className } = _a, props = tslib_1.__rest(_a, ["onClose", "title", "description", "isCloseHidden", "closeButtonAriaLabel", "titleId", "descriptionComponent", "descriptionId", "className"]);
    return ((0, jsx_runtime_1.jsxs)("div", Object.assign({ className: (0, react_styles_1.css)(wizard_1.default.wizardHeader, className) }, props, { children: [!isCloseHidden && ((0, jsx_runtime_1.jsx)("div", { className: (0, react_styles_1.css)(wizard_1.default.wizardClose), children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "plain", "aria-label": closeButtonAriaLabel, onClick: onClose, icon: (0, jsx_runtime_1.jsx)(times_icon_1.default, {}) }) })), (0, jsx_runtime_1.jsx)("div", { className: (0, react_styles_1.css)(wizard_1.default.wizardTitle), children: (0, jsx_runtime_1.jsx)("h2", { className: (0, react_styles_1.css)(wizard_1.default.wizardTitleText), id: titleId, children: title || (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: "\u00A0" }) }) }), description && ((0, jsx_runtime_1.jsx)(Component, { className: (0, react_styles_1.css)(wizard_1.default.wizardDescription), id: descriptionId, children: description }))] })));
};
exports.WizardHeader = WizardHeader;
exports.WizardHeader.displayName = 'WizardHeader';
//# sourceMappingURL=WizardHeader.js.map