/// <reference types="react" />
export declare const PopoverArrow: React.FunctionComponent<PopoverArrowProps>;
export interface PopoverArrowProps extends React.HTMLProps<HTMLDivElement> {
    /** Popover arrow additional className */
    className?: string;
}
//# sourceMappingURL=PopoverArrow.d.ts.map