import { Modifier } from '../types';
export type ApplyStylesModifier = Modifier<'applyStyles', {}>;
declare const _default: ApplyStylesModifier;
export default _default;
//# sourceMappingURL=applyStyles.d.ts.map