import './_index.css';
export default {
  "aboutModalBox": "pf-v6-c-about-modal-box",
  "aboutModalBoxBrand": "pf-v6-c-about-modal-box__brand",
  "aboutModalBoxBrandImage": "pf-v6-c-about-modal-box__brand-image",
  "aboutModalBoxClose": "pf-v6-c-about-modal-box__close",
  "aboutModalBoxContent": "pf-v6-c-about-modal-box__content",
  "aboutModalBoxHeader": "pf-v6-c-about-modal-box__header",
  "aboutModalBoxStrapline": "pf-v6-c-about-modal-box__strapline",
  "accordion": "pf-v6-c-accordion",
  "accordionExpandableContent": "pf-v6-c-accordion__expandable-content",
  "accordionExpandableContentBody": "pf-v6-c-accordion__expandable-content-body",
  "accordionItem": "pf-v6-c-accordion__item",
  "accordionToggle": "pf-v6-c-accordion__toggle",
  "accordionToggleIcon": "pf-v6-c-accordion__toggle-icon",
  "accordionToggleText": "pf-v6-c-accordion__toggle-text",
  "actionList": "pf-v6-c-action-list",
  "actionListGroup": "pf-v6-c-action-list__group",
  "alert": "pf-v6-c-alert",
  "alertAction": "pf-v6-c-alert__action",
  "alertActionGroup": "pf-v6-c-alert__action-group",
  "alertDescription": "pf-v6-c-alert__description",
  "alertGroup": "pf-v6-c-alert-group",
  "alertGroupItem": "pf-v6-c-alert-group__item",
  "alertGroupOverflowButton": "pf-v6-c-alert-group__overflow-button",
  "alertIcon": "pf-v6-c-alert__icon",
  "alertTitle": "pf-v6-c-alert__title",
  "alertToggle": "pf-v6-c-alert__toggle",
  "alertToggleIcon": "pf-v6-c-alert__toggle-icon",
  "avatar": "pf-v6-c-avatar",
  "backToTop": "pf-v6-c-back-to-top",
  "backdrop": "pf-v6-c-backdrop",
  "backdropOpen": "pf-v6-c-backdrop__open",
  "backgroundImage": "pf-v6-c-background-image",
  "badge": "pf-v6-c-badge",
  "badgeToggleIcon": "pf-v6-c-badge__toggle-icon",
  "banner": "pf-v6-c-banner",
  "brand": "pf-v6-c-brand",
  "breadcrumb": "pf-v6-c-breadcrumb",
  "breadcrumbDropdown": "pf-v6-c-breadcrumb__dropdown",
  "breadcrumbHeading": "pf-v6-c-breadcrumb__heading",
  "breadcrumbItem": "pf-v6-c-breadcrumb__item",
  "breadcrumbItemDivider": "pf-v6-c-breadcrumb__item-divider",
  "breadcrumbLink": "pf-v6-c-breadcrumb__link",
  "breadcrumbList": "pf-v6-c-breadcrumb__list",
  "button": "pf-v6-c-button",
  "buttonCount": "pf-v6-c-button__count",
  "buttonHamburgerIcon": "pf-v6-c-button--hamburger-icon",
  "buttonHamburgerIconArrow": "pf-v6-c-button--hamburger-icon--arrow",
  "buttonHamburgerIconBottom": "pf-v6-c-button--hamburger-icon--bottom",
  "buttonHamburgerIconMiddle": "pf-v6-c-button--hamburger-icon--middle",
  "buttonHamburgerIconTop": "pf-v6-c-button--hamburger-icon--top",
  "buttonIcon": "pf-v6-c-button__icon",
  "buttonIconFavorite": "pf-v6-c-button__icon-favorite",
  "buttonIconFavorited": "pf-v6-c-button__icon-favorited",
  "buttonProgress": "pf-v6-c-button__progress",
  "buttonText": "pf-v6-c-button__text",
  "calendarMonth": "pf-v6-c-calendar-month",
  "calendarMonthCalendar": "pf-v6-c-calendar-month__calendar",
  "calendarMonthDate": "pf-v6-c-calendar-month__date",
  "calendarMonthDatesCell": "pf-v6-c-calendar-month__dates-cell",
  "calendarMonthDatesRow": "pf-v6-c-calendar-month__dates-row",
  "calendarMonthDay": "pf-v6-c-calendar-month__day",
  "calendarMonthDays": "pf-v6-c-calendar-month__days",
  "calendarMonthHeader": "pf-v6-c-calendar-month__header",
  "calendarMonthHeaderMonth": "pf-v6-c-calendar-month__header-month",
  "calendarMonthHeaderNavControl": "pf-v6-c-calendar-month__header-nav-control",
  "calendarMonthHeaderYear": "pf-v6-c-calendar-month__header-year",
  "card": "pf-v6-c-card",
  "cardActions": "pf-v6-c-card__actions",
  "cardBody": "pf-v6-c-card__body",
  "cardClickableAction": "pf-v6-c-card__clickable-action",
  "cardExpandableContent": "pf-v6-c-card__expandable-content",
  "cardFooter": "pf-v6-c-card__footer",
  "cardHeader": "pf-v6-c-card__header",
  "cardHeaderMain": "pf-v6-c-card__header-main",
  "cardHeaderToggle": "pf-v6-c-card__header-toggle",
  "cardHeaderToggleIcon": "pf-v6-c-card__header-toggle-icon",
  "cardSelectableActions": "pf-v6-c-card__selectable-actions",
  "cardTitle": "pf-v6-c-card__title",
  "cardTitleText": "pf-v6-c-card__title-text",
  "check": "pf-v6-c-check",
  "checkBody": "pf-v6-c-check__body",
  "checkDescription": "pf-v6-c-check__description",
  "checkInput": "pf-v6-c-check__input",
  "checkLabel": "pf-v6-c-check__label",
  "checkLabelRequired": "pf-v6-c-check__label-required",
  "clipboardCopy": "pf-v6-c-clipboard-copy",
  "clipboardCopyActions": "pf-v6-c-clipboard-copy__actions",
  "clipboardCopyActionsItem": "pf-v6-c-clipboard-copy__actions-item",
  "clipboardCopyExpandableContent": "pf-v6-c-clipboard-copy__expandable-content",
  "clipboardCopyGroup": "pf-v6-c-clipboard-copy__group",
  "clipboardCopyText": "pf-v6-c-clipboard-copy__text",
  "clipboardCopyToggleIcon": "pf-v6-c-clipboard-copy__toggle-icon",
  "codeBlock": "pf-v6-c-code-block",
  "codeBlockActions": "pf-v6-c-code-block__actions",
  "codeBlockCode": "pf-v6-c-code-block__code",
  "codeBlockContent": "pf-v6-c-code-block__content",
  "codeBlockHeader": "pf-v6-c-code-block__header",
  "codeBlockPre": "pf-v6-c-code-block__pre",
  "codeEditor": "pf-v6-c-code-editor",
  "codeEditorCode": "pf-v6-c-code-editor__code",
  "codeEditorCodePre": "pf-v6-c-code-editor__code-pre",
  "codeEditorContainer": "pf-v6-c-code-editor__container",
  "codeEditorControls": "pf-v6-c-code-editor__controls",
  "codeEditorHeader": "pf-v6-c-code-editor__header",
  "codeEditorHeaderContent": "pf-v6-c-code-editor__header-content",
  "codeEditorHeaderMain": "pf-v6-c-code-editor__header-main",
  "codeEditorMain": "pf-v6-c-code-editor__main",
  "codeEditorTab": "pf-v6-c-code-editor__tab",
  "codeEditorTabIcon": "pf-v6-c-code-editor__tab-icon",
  "codeEditorTabText": "pf-v6-c-code-editor__tab-text",
  "codeEditorUpload": "pf-v6-c-code-editor__upload",
  "content": "pf-v6-c-content",
  "contentA": "pf-v6-c-content--a",
  "contentBlockquote": "pf-v6-c-content--blockquote",
  "contentDd": "pf-v6-c-content--dd",
  "contentDl": "pf-v6-c-content--dl",
  "contentDt": "pf-v6-c-content--dt",
  "contentH1": "pf-v6-c-content--h1",
  "contentH2": "pf-v6-c-content--h2",
  "contentH3": "pf-v6-c-content--h3",
  "contentH4": "pf-v6-c-content--h4",
  "contentH5": "pf-v6-c-content--h5",
  "contentH6": "pf-v6-c-content--h6",
  "contentHr": "pf-v6-c-content--hr",
  "contentLi": "pf-v6-c-content--li",
  "contentOl": "pf-v6-c-content--ol",
  "contentP": "pf-v6-c-content--p",
  "contentPre": "pf-v6-c-content--pre",
  "contentSmall": "pf-v6-c-content--small",
  "contentTable": "pf-v6-c-content--table",
  "contentUl": "pf-v6-c-content--ul",
  "dataList": "pf-v6-c-data-list",
  "dataListCell": "pf-v6-c-data-list__cell",
  "dataListCheck": "pf-v6-c-data-list__check",
  "dataListExpandableContent": "pf-v6-c-data-list__expandable-content",
  "dataListExpandableContentBody": "pf-v6-c-data-list__expandable-content-body",
  "dataListItem": "pf-v6-c-data-list__item",
  "dataListItemAction": "pf-v6-c-data-list__item-action",
  "dataListItemContent": "pf-v6-c-data-list__item-content",
  "dataListItemControl": "pf-v6-c-data-list__item-control",
  "dataListItemDraggableButton": "pf-v6-c-data-list__item-draggable-button",
  "dataListItemDraggableIcon": "pf-v6-c-data-list__item-draggable-icon",
  "dataListItemRow": "pf-v6-c-data-list__item-row",
  "dataListText": "pf-v6-c-data-list__text",
  "dataListToggle": "pf-v6-c-data-list__toggle",
  "dataListToggleIcon": "pf-v6-c-data-list__toggle-icon",
  "datePicker": "pf-v6-c-date-picker",
  "datePickerCalendar": "pf-v6-c-date-picker__calendar",
  "datePickerHelperText": "pf-v6-c-date-picker__helper-text",
  "datePickerInput": "pf-v6-c-date-picker__input",
  "descriptionList": "pf-v6-c-description-list",
  "descriptionListDescription": "pf-v6-c-description-list__description",
  "descriptionListGroup": "pf-v6-c-description-list__group",
  "descriptionListTerm": "pf-v6-c-description-list__term",
  "descriptionListTermIcon": "pf-v6-c-description-list__term-icon",
  "descriptionListText": "pf-v6-c-description-list__text",
  "dirRtl": "pf-v6-m-dir-rtl",
  "divider": "pf-v6-c-divider",
  "draggable": "pf-v6-c-draggable",
  "drawer": "pf-v6-c-drawer",
  "drawerActions": "pf-v6-c-drawer__actions",
  "drawerBody": "pf-v6-c-drawer__body",
  "drawerClose": "pf-v6-c-drawer__close",
  "drawerContent": "pf-v6-c-drawer__content",
  "drawerDescription": "pf-v6-c-drawer__description",
  "drawerHead": "pf-v6-c-drawer__head",
  "drawerMain": "pf-v6-c-drawer__main",
  "drawerPanel": "pf-v6-c-drawer__panel",
  "drawerPanelMain": "pf-v6-c-drawer__panel-main",
  "drawerSection": "pf-v6-c-drawer__section",
  "drawerSplitter": "pf-v6-c-drawer__splitter",
  "drawerSplitterHandle": "pf-v6-c-drawer__splitter-handle",
  "droppable": "pf-v6-c-droppable",
  "dualListSelector": "pf-v6-c-dual-list-selector",
  "dualListSelectorControls": "pf-v6-c-dual-list-selector__controls",
  "dualListSelectorControlsItem": "pf-v6-c-dual-list-selector__controls-item",
  "dualListSelectorDraggable": "pf-v6-c-dual-list-selector__draggable",
  "dualListSelectorHeader": "pf-v6-c-dual-list-selector__header",
  "dualListSelectorItem": "pf-v6-c-dual-list-selector__item",
  "dualListSelectorItemCheck": "pf-v6-c-dual-list-selector__item-check",
  "dualListSelectorItemCount": "pf-v6-c-dual-list-selector__item-count",
  "dualListSelectorItemMain": "pf-v6-c-dual-list-selector__item-main",
  "dualListSelectorItemText": "pf-v6-c-dual-list-selector__item-text",
  "dualListSelectorItemToggle": "pf-v6-c-dual-list-selector__item-toggle",
  "dualListSelectorItemToggleIcon": "pf-v6-c-dual-list-selector__item-toggle-icon",
  "dualListSelectorList": "pf-v6-c-dual-list-selector__list",
  "dualListSelectorListItem": "pf-v6-c-dual-list-selector__list-item",
  "dualListSelectorListItemRow": "pf-v6-c-dual-list-selector__list-item-row",
  "dualListSelectorMain": "pf-v6-c-dual-list-selector__main",
  "dualListSelectorMenu": "pf-v6-c-dual-list-selector__menu",
  "dualListSelectorPane": "pf-v6-c-dual-list-selector__pane",
  "dualListSelectorStatus": "pf-v6-c-dual-list-selector__status",
  "dualListSelectorStatusText": "pf-v6-c-dual-list-selector__status-text",
  "dualListSelectorTitleText": "pf-v6-c-dual-list-selector__title-text",
  "dualListSelectorTools": "pf-v6-c-dual-list-selector__tools",
  "dualListSelectorToolsActions": "pf-v6-c-dual-list-selector__tools-actions",
  "dualListSelectorToolsFilter": "pf-v6-c-dual-list-selector__tools-filter",
  "emptyState": "pf-v6-c-empty-state",
  "emptyStateActions": "pf-v6-c-empty-state__actions",
  "emptyStateBody": "pf-v6-c-empty-state__body",
  "emptyStateContent": "pf-v6-c-empty-state__content",
  "emptyStateFooter": "pf-v6-c-empty-state__footer",
  "emptyStateIcon": "pf-v6-c-empty-state__icon",
  "emptyStateTitleText": "pf-v6-c-empty-state__title-text",
  "expandableSection": "pf-v6-c-expandable-section",
  "expandableSectionContent": "pf-v6-c-expandable-section__content",
  "expandableSectionToggleIcon": "pf-v6-c-expandable-section__toggle-icon",
  "faExclamationTriangle": "fa-exclamation-triangle",
  "fileUpload": "pf-v6-c-file-upload",
  "fileUploadFileDetails": "pf-v6-c-file-upload__file-details",
  "fileUploadFileDetailsSpinner": "pf-v6-c-file-upload__file-details-spinner",
  "fileUploadFileSelect": "pf-v6-c-file-upload__file-select",
  "form": "pf-v6-c-form",
  "formActions": "pf-v6-c-form__actions",
  "formControl": "pf-v6-c-form-control",
  "formControlIcon": "pf-v6-c-form-control__icon",
  "formControlToggleIcon": "pf-v6-c-form-control__toggle-icon",
  "formControlUtilities": "pf-v6-c-form-control__utilities",
  "formFieldGroup": "pf-v6-c-form__field-group",
  "formFieldGroupBody": "pf-v6-c-form__field-group-body",
  "formFieldGroupHeader": "pf-v6-c-form__field-group-header",
  "formFieldGroupHeaderActions": "pf-v6-c-form__field-group-header-actions",
  "formFieldGroupHeaderDescription": "pf-v6-c-form__field-group-header-description",
  "formFieldGroupHeaderMain": "pf-v6-c-form__field-group-header-main",
  "formFieldGroupHeaderTitle": "pf-v6-c-form__field-group-header-title",
  "formFieldGroupHeaderTitleText": "pf-v6-c-form__field-group-header-title-text",
  "formFieldGroupToggle": "pf-v6-c-form__field-group-toggle",
  "formFieldGroupToggleButton": "pf-v6-c-form__field-group-toggle-button",
  "formFieldGroupToggleIcon": "pf-v6-c-form__field-group-toggle-icon",
  "formFieldset": "pf-v6-c-form__fieldset",
  "formGroup": "pf-v6-c-form__group",
  "formGroupControl": "pf-v6-c-form__group-control",
  "formGroupLabel": "pf-v6-c-form__group-label",
  "formGroupLabelHelp": "pf-v6-c-form__group-label-help",
  "formGroupLabelInfo": "pf-v6-c-form__group-label-info",
  "formGroupLabelMain": "pf-v6-c-form__group-label-main",
  "formHelperText": "pf-v6-c-form__helper-text",
  "formLabel": "pf-v6-c-form__label",
  "formLabelRequired": "pf-v6-c-form__label-required",
  "formLabelText": "pf-v6-c-form__label-text",
  "formSection": "pf-v6-c-form__section",
  "formSectionTitle": "pf-v6-c-form__section-title",
  "helperText": "pf-v6-c-helper-text",
  "helperTextItem": "pf-v6-c-helper-text__item",
  "helperTextItemIcon": "pf-v6-c-helper-text__item-icon",
  "helperTextItemText": "pf-v6-c-helper-text__item-text",
  "hint": "pf-v6-c-hint",
  "hintActions": "pf-v6-c-hint__actions",
  "hintBody": "pf-v6-c-hint__body",
  "hintFooter": "pf-v6-c-hint__footer",
  "hintTitle": "pf-v6-c-hint__title",
  "icon": "pf-v6-c-icon",
  "iconContent": "pf-v6-c-icon__content",
  "iconProgress": "pf-v6-c-icon__progress",
  "inlineEdit": "pf-v6-c-inline-edit",
  "inlineEditAction": "pf-v6-c-inline-edit__action",
  "inlineEditEditableText": "pf-v6-c-inline-edit__editable-text",
  "inlineEditGroup": "pf-v6-c-inline-edit__group",
  "inlineEditInput": "pf-v6-c-inline-edit__input",
  "inlineEditLabel": "pf-v6-c-inline-edit__label",
  "inlineEditValue": "pf-v6-c-inline-edit__value",
  "inputGroup": "pf-v6-c-input-group",
  "inputGroupItem": "pf-v6-c-input-group__item",
  "inputGroupText": "pf-v6-c-input-group__text",
  "jumpLinks": "pf-v6-c-jump-links",
  "jumpLinksItem": "pf-v6-c-jump-links__item",
  "jumpLinksLabel": "pf-v6-c-jump-links__label",
  "jumpLinksLink": "pf-v6-c-jump-links__link",
  "jumpLinksLinkText": "pf-v6-c-jump-links__link-text",
  "jumpLinksList": "pf-v6-c-jump-links__list",
  "jumpLinksMain": "pf-v6-c-jump-links__main",
  "jumpLinksToggle": "pf-v6-c-jump-links__toggle",
  "jumpLinksToggleIcon": "pf-v6-c-jump-links__toggle-icon",
  "label": "pf-v6-c-label",
  "labelActions": "pf-v6-c-label__actions",
  "labelContent": "pf-v6-c-label__content",
  "labelGroup": "pf-v6-c-label-group",
  "labelGroupClose": "pf-v6-c-label-group__close",
  "labelGroupLabel": "pf-v6-c-label-group__label",
  "labelGroupList": "pf-v6-c-label-group__list",
  "labelGroupListItem": "pf-v6-c-label-group__list-item",
  "labelGroupMain": "pf-v6-c-label-group__main",
  "labelGroupTextarea": "pf-v6-c-label-group__textarea",
  "labelIcon": "pf-v6-c-label__icon",
  "labelName": "label-name",
  "labelText": "pf-v6-c-label__text",
  "list": "pf-v6-c-list",
  "listItem": "pf-v6-c-list__item",
  "listItemIcon": "pf-v6-c-list__item-icon",
  "login": "pf-v6-c-login",
  "loginContainer": "pf-v6-c-login__container",
  "loginFooter": "pf-v6-c-login__footer",
  "loginHeader": "pf-v6-c-login__header",
  "loginMain": "pf-v6-c-login__main",
  "loginMainBody": "pf-v6-c-login__main-body",
  "loginMainFooter": "pf-v6-c-login__main-footer",
  "loginMainFooterBand": "pf-v6-c-login__main-footer-band",
  "loginMainFooterLinks": "pf-v6-c-login__main-footer-links",
  "loginMainFooterLinksItem": "pf-v6-c-login__main-footer-links-item",
  "loginMainHeader": "pf-v6-c-login__main-header",
  "loginMainHeaderDesc": "pf-v6-c-login__main-header-desc",
  "loginMainHeaderUtilities": "pf-v6-c-login__main-header-utilities",
  "masthead": "pf-v6-c-masthead",
  "mastheadBrand": "pf-v6-c-masthead__brand",
  "mastheadContent": "pf-v6-c-masthead__content",
  "mastheadExpandableContent": "pf-v6-c-masthead__expandable-content",
  "mastheadLogo": "pf-v6-c-masthead__logo",
  "mastheadMain": "pf-v6-c-masthead__main",
  "mastheadToggle": "pf-v6-c-masthead__toggle",
  "menu": "pf-v6-c-menu",
  "menuBreadcrumb": "pf-v6-c-menu__breadcrumb",
  "menuContent": "pf-v6-c-menu__content",
  "menuFooter": "pf-v6-c-menu__footer",
  "menuGroup": "pf-v6-c-menu__group",
  "menuGroupTitle": "pf-v6-c-menu__group-title",
  "menuHeader": "pf-v6-c-menu__header",
  "menuItem": "pf-v6-c-menu__item",
  "menuItemAction": "pf-v6-c-menu__item-action",
  "menuItemActionIcon": "pf-v6-c-menu__item-action-icon",
  "menuItemCheck": "pf-v6-c-menu__item-check",
  "menuItemDescription": "pf-v6-c-menu__item-description",
  "menuItemExternalIcon": "pf-v6-c-menu__item-external-icon",
  "menuItemIcon": "pf-v6-c-menu__item-icon",
  "menuItemMain": "pf-v6-c-menu__item-main",
  "menuItemSelectIcon": "pf-v6-c-menu__item-select-icon",
  "menuItemText": "pf-v6-c-menu__item-text",
  "menuItemToggleIcon": "pf-v6-c-menu__item-toggle-icon",
  "menuList": "pf-v6-c-menu__list",
  "menuListItem": "pf-v6-c-menu__list-item",
  "menuSearch": "pf-v6-c-menu__search",
  "menuToggle": "pf-v6-c-menu-toggle",
  "menuToggleButton": "pf-v6-c-menu-toggle__button",
  "menuToggleControls": "pf-v6-c-menu-toggle__controls",
  "menuToggleCount": "pf-v6-c-menu-toggle__count",
  "menuToggleIcon": "pf-v6-c-menu-toggle__icon",
  "menuToggleStatusIcon": "pf-v6-c-menu-toggle__status-icon",
  "menuToggleText": "pf-v6-c-menu-toggle__text",
  "menuToggleToggleIcon": "pf-v6-c-menu-toggle__toggle-icon",
  "modalBox": "pf-v6-c-modal-box",
  "modalBoxBody": "pf-v6-c-modal-box__body",
  "modalBoxClose": "pf-v6-c-modal-box__close",
  "modalBoxDescription": "pf-v6-c-modal-box__description",
  "modalBoxFooter": "pf-v6-c-modal-box__footer",
  "modalBoxHeader": "pf-v6-c-modal-box__header",
  "modalBoxHeaderMain": "pf-v6-c-modal-box__header-main",
  "modalBoxTitle": "pf-v6-c-modal-box__title",
  "modalBoxTitleIcon": "pf-v6-c-modal-box__title-icon",
  "modalBoxTitleText": "pf-v6-c-modal-box__title-text",
  "modifiers": {
    "plain": "pf-m-plain",
    "toggleStart": "pf-m-toggle-start",
    "displayLg": "pf-m-display-lg",
    "bordered": "pf-m-bordered",
    "expanded": "pf-m-expanded",
    "fixed": "pf-m-fixed",
    "icons": "pf-m-icons",
    "custom": "pf-m-custom",
    "success": "pf-m-success",
    "danger": "pf-m-danger",
    "warning": "pf-m-warning",
    "info": "pf-m-info",
    "inline": "pf-m-inline",
    "expandable": "pf-m-expandable",
    "truncate": "pf-m-truncate",
    "toast": "pf-m-toast",
    "offstageTop": "pf-m-offstage-top",
    "incoming": "pf-m-incoming",
    "offstageRight": "pf-m-offstage-right",
    "outgoing": "pf-m-outgoing",
    "sm": "pf-m-sm",
    "md": "pf-m-md",
    "lg": "pf-m-lg",
    "xl": "pf-m-xl",
    "hidden": "pf-m-hidden",
    "read": "pf-m-read",
    "unread": "pf-m-unread",
    "disabled": "pf-m-disabled",
    "red": "pf-m-red",
    "orangered": "pf-m-orangered",
    "orange": "pf-m-orange",
    "yellow": "pf-m-yellow",
    "green": "pf-m-green",
    "teal": "pf-m-teal",
    "blue": "pf-m-blue",
    "purple": "pf-m-purple",
    "sticky": "pf-m-sticky",
    "picture": "pf-m-picture",
    "current": "pf-m-current",
    "primary": "pf-m-primary",
    "secondary": "pf-m-secondary",
    "tertiary": "pf-m-tertiary",
    "link": "pf-m-link",
    "control": "pf-m-control",
    "stateful": "pf-m-stateful",
    "attention": "pf-m-attention",
    "noPadding": "pf-m-no-padding",
    "block": "pf-m-block",
    "small": "pf-m-small",
    "favorite": "pf-m-favorite",
    "favorited": "pf-m-favorited",
    "settings": "pf-m-settings",
    "hamburger": "pf-m-hamburger",
    "expand": "pf-m-expand",
    "collapse": "pf-m-collapse",
    "clicked": "pf-m-clicked",
    "ariaDisabled": "pf-m-aria-disabled",
    "progress": "pf-m-progress",
    "inProgress": "pf-m-in-progress",
    "notify": "pf-m-notify",
    "start": "pf-m-start",
    "end": "pf-m-end",
    "inRange": "pf-m-in-range",
    "startRange": "pf-m-start-range",
    "endRange": "pf-m-end-range",
    "adjacentMonth": "pf-m-adjacent-month",
    "selected": "pf-m-selected",
    "hover": "pf-m-hover",
    "focus": "pf-m-focus",
    "selectable": "pf-m-selectable",
    "clickable": "pf-m-clickable",
    "compact": "pf-m-compact",
    "fullHeight": "pf-m-full-height",
    "toggleRight": "pf-m-toggle-right",
    "wrap": "pf-m-wrap",
    "noOffset": "pf-m-no-offset",
    "noFill": "pf-m-no-fill",
    "standalone": "pf-m-standalone",
    "code": "pf-m-code",
    "readOnly": "pf-m-read-only",
    "dragHover": "pf-m-drag-hover",
    "editorial": "pf-m-editorial",
    "visited": "pf-m-visited",
    "pageTitle": "pf-m-page-title",
    "icon": "pf-m-icon",
    "alignRight": "pf-m-align-right",
    "flex_2": "pf-m-flex-2",
    "flex_3": "pf-m-flex-3",
    "flex_4": "pf-m-flex-4",
    "flex_5": "pf-m-flex-5",
    "gridNone": "pf-m-grid-none",
    "gridSm": "pf-m-grid-sm",
    "gridMd": "pf-m-grid-md",
    "gridLg": "pf-m-grid-lg",
    "gridXl": "pf-m-grid-xl",
    "grid_2xl": "pf-m-grid-2xl",
    "dragOver": "pf-m-drag-over",
    "breakWord": "pf-m-break-word",
    "nowrap": "pf-m-nowrap",
    "ghostRow": "pf-m-ghost-row",
    "hiddenOnSm": "pf-m-hidden-on-sm",
    "visibleOnSm": "pf-m-visible-on-sm",
    "hiddenOnMd": "pf-m-hidden-on-md",
    "visibleOnMd": "pf-m-visible-on-md",
    "hiddenOnLg": "pf-m-hidden-on-lg",
    "visibleOnLg": "pf-m-visible-on-lg",
    "hiddenOnXl": "pf-m-hidden-on-xl",
    "visibleOnXl": "pf-m-visible-on-xl",
    "hiddenOn_2xl": "pf-m-hidden-on-2xl",
    "visibleOn_2xl": "pf-m-visible-on-2xl",
    "inlineGrid": "pf-m-inline-grid",
    "autoColumnWidths": "pf-m-auto-column-widths",
    "autoFit": "pf-m-auto-fit",
    "fluid": "pf-m-fluid",
    "fillColumns": "pf-m-fill-columns",
    "display_2xl": "pf-m-display-2xl",
    "helpText": "pf-m-help-text",
    "1Col": "pf-m-1-col",
    "2Col": "pf-m-2-col",
    "3Col": "pf-m-3-col",
    "horizontal": "pf-m-horizontal",
    "vertical": "pf-m-vertical",
    "1ColOnSm": "pf-m-1-col-on-sm",
    "2ColOnSm": "pf-m-2-col-on-sm",
    "3ColOnSm": "pf-m-3-col-on-sm",
    "horizontalOnSm": "pf-m-horizontal-on-sm",
    "verticalOnSm": "pf-m-vertical-on-sm",
    "1ColOnMd": "pf-m-1-col-on-md",
    "2ColOnMd": "pf-m-2-col-on-md",
    "3ColOnMd": "pf-m-3-col-on-md",
    "horizontalOnMd": "pf-m-horizontal-on-md",
    "verticalOnMd": "pf-m-vertical-on-md",
    "1ColOnLg": "pf-m-1-col-on-lg",
    "2ColOnLg": "pf-m-2-col-on-lg",
    "3ColOnLg": "pf-m-3-col-on-lg",
    "horizontalOnLg": "pf-m-horizontal-on-lg",
    "verticalOnLg": "pf-m-vertical-on-lg",
    "1ColOnXl": "pf-m-1-col-on-xl",
    "2ColOnXl": "pf-m-2-col-on-xl",
    "3ColOnXl": "pf-m-3-col-on-xl",
    "horizontalOnXl": "pf-m-horizontal-on-xl",
    "verticalOnXl": "pf-m-vertical-on-xl",
    "1ColOn_2xl": "pf-m-1-col-on-2xl",
    "2ColOn_2xl": "pf-m-2-col-on-2xl",
    "3ColOn_2xl": "pf-m-3-col-on-2xl",
    "horizontalOn_2xl": "pf-m-horizontal-on-2xl",
    "verticalOn_2xl": "pf-m-vertical-on-2xl",
    "dragging": "pf-m-dragging",
    "dragOutside": "pf-m-drag-outside",
    "chosen": "pf-m-chosen",
    "animateExpand": "pf-m-animate-expand",
    "check": "pf-m-check",
    "top": "pf-m-top",
    "static": "pf-m-static",
    "insetNone": "pf-m-inset-none",
    "insetXs": "pf-m-inset-xs",
    "insetSm": "pf-m-inset-sm",
    "insetMd": "pf-m-inset-md",
    "insetLg": "pf-m-inset-lg",
    "insetXl": "pf-m-inset-xl",
    "inset_2xl": "pf-m-inset-2xl",
    "inset_3xl": "pf-m-inset-3xl",
    "insetNoneOnSm": "pf-m-inset-none-on-sm",
    "insetXsOnSm": "pf-m-inset-xs-on-sm",
    "insetSmOnSm": "pf-m-inset-sm-on-sm",
    "insetMdOnSm": "pf-m-inset-md-on-sm",
    "insetLgOnSm": "pf-m-inset-lg-on-sm",
    "insetXlOnSm": "pf-m-inset-xl-on-sm",
    "inset_2xlOnSm": "pf-m-inset-2xl-on-sm",
    "inset_3xlOnSm": "pf-m-inset-3xl-on-sm",
    "insetNoneOnMd": "pf-m-inset-none-on-md",
    "insetXsOnMd": "pf-m-inset-xs-on-md",
    "insetSmOnMd": "pf-m-inset-sm-on-md",
    "insetMdOnMd": "pf-m-inset-md-on-md",
    "insetLgOnMd": "pf-m-inset-lg-on-md",
    "insetXlOnMd": "pf-m-inset-xl-on-md",
    "inset_2xlOnMd": "pf-m-inset-2xl-on-md",
    "inset_3xlOnMd": "pf-m-inset-3xl-on-md",
    "insetNoneOnLg": "pf-m-inset-none-on-lg",
    "insetXsOnLg": "pf-m-inset-xs-on-lg",
    "insetSmOnLg": "pf-m-inset-sm-on-lg",
    "insetMdOnLg": "pf-m-inset-md-on-lg",
    "insetLgOnLg": "pf-m-inset-lg-on-lg",
    "insetXlOnLg": "pf-m-inset-xl-on-lg",
    "inset_2xlOnLg": "pf-m-inset-2xl-on-lg",
    "inset_3xlOnLg": "pf-m-inset-3xl-on-lg",
    "insetNoneOnXl": "pf-m-inset-none-on-xl",
    "insetXsOnXl": "pf-m-inset-xs-on-xl",
    "insetSmOnXl": "pf-m-inset-sm-on-xl",
    "insetMdOnXl": "pf-m-inset-md-on-xl",
    "insetLgOnXl": "pf-m-inset-lg-on-xl",
    "insetXlOnXl": "pf-m-inset-xl-on-xl",
    "inset_2xlOnXl": "pf-m-inset-2xl-on-xl",
    "inset_3xlOnXl": "pf-m-inset-3xl-on-xl",
    "insetNoneOn_2xl": "pf-m-inset-none-on-2xl",
    "insetXsOn_2xl": "pf-m-inset-xs-on-2xl",
    "insetSmOn_2xl": "pf-m-inset-sm-on-2xl",
    "insetMdOn_2xl": "pf-m-inset-md-on-2xl",
    "insetLgOn_2xl": "pf-m-inset-lg-on-2xl",
    "insetXlOn_2xl": "pf-m-inset-xl-on-2xl",
    "inset_2xlOn_2xl": "pf-m-inset-2xl-on-2xl",
    "inset_3xlOn_2xl": "pf-m-inset-3xl-on-2xl",
    "panelBottom": "pf-m-panel-bottom",
    "noBorder": "pf-m-no-border",
    "resizable": "pf-m-resizable",
    "panelLeft": "pf-m-panel-left",
    "resizing": "pf-m-resizing",
    "noBackground": "pf-m-no-background",
    "padding": "pf-m-padding",
    "width_25": "pf-m-width-25",
    "width_33": "pf-m-width-33",
    "width_50": "pf-m-width-50",
    "width_66": "pf-m-width-66",
    "width_75": "pf-m-width-75",
    "width_100": "pf-m-width-100",
    "width_25OnLg": "pf-m-width-25-on-lg",
    "width_33OnLg": "pf-m-width-33-on-lg",
    "width_50OnLg": "pf-m-width-50-on-lg",
    "width_66OnLg": "pf-m-width-66-on-lg",
    "width_75OnLg": "pf-m-width-75-on-lg",
    "width_100OnLg": "pf-m-width-100-on-lg",
    "width_25OnXl": "pf-m-width-25-on-xl",
    "width_33OnXl": "pf-m-width-33-on-xl",
    "width_50OnXl": "pf-m-width-50-on-xl",
    "width_66OnXl": "pf-m-width-66-on-xl",
    "width_75OnXl": "pf-m-width-75-on-xl",
    "width_100OnXl": "pf-m-width-100-on-xl",
    "width_25On_2xl": "pf-m-width-25-on-2xl",
    "width_33On_2xl": "pf-m-width-33-on-2xl",
    "width_50On_2xl": "pf-m-width-50-on-2xl",
    "width_66On_2xl": "pf-m-width-66-on-2xl",
    "width_75On_2xl": "pf-m-width-75-on-2xl",
    "width_100On_2xl": "pf-m-width-100-on-2xl",
    "inlineOnLg": "pf-m-inline-on-lg",
    "staticOnLg": "pf-m-static-on-lg",
    "inlineOnXl": "pf-m-inline-on-xl",
    "staticOnXl": "pf-m-static-on-xl",
    "inlineOn_2xl": "pf-m-inline-on-2xl",
    "staticOn_2xl": "pf-m-static-on-2xl",
    "xs": "pf-m-xs",
    "expandTop": "pf-m-expand-top",
    "expandBottom": "pf-m-expand-bottom",
    "limitWidth": "pf-m-limit-width",
    "indented": "pf-m-indented",
    "loading": "pf-m-loading",
    "noPaddingTop": "pf-m-no-padding-top",
    "horizontalOnXs": "pf-m-horizontal-on-xs",
    "action": "pf-m-action",
    "stack": "pf-m-stack",
    "inactive": "pf-m-inactive",
    "textarea": "pf-m-textarea",
    "error": "pf-m-error",
    "readonly": "pf-m-readonly",
    "status": "pf-m-status",
    "placeholder": "pf-m-placeholder",
    "resizeVertical": "pf-m-resize-vertical",
    "resizeHorizontal": "pf-m-resize-horizontal",
    "resizeBoth": "pf-m-resize-both",
    "indeterminate": "pf-m-indeterminate",
    "dynamic": "pf-m-dynamic",
    "2xl": "pf-m-2xl",
    "3xl": "pf-m-3xl",
    "bodySm": "pf-m-body-sm",
    "bodyDefault": "pf-m-body-default",
    "bodyLg": "pf-m-body-lg",
    "headingSm": "pf-m-heading-sm",
    "headingMd": "pf-m-heading-md",
    "headingLg": "pf-m-heading-lg",
    "headingXl": "pf-m-heading-xl",
    "heading_2xl": "pf-m-heading-2xl",
    "heading_3xl": "pf-m-heading-3xl",
    "iconGroup": "pf-m-icon-group",
    "footer": "pf-m-footer",
    "column": "pf-m-column",
    "valid": "pf-m-valid",
    "actionGroup": "pf-m-action-group",
    "enableEditable": "pf-m-enable-editable",
    "inlineEditable": "pf-m-inline-editable",
    "enable": "pf-m-enable",
    "bold": "pf-m-bold",
    "searchExpandable": "pf-m-search-expandable",
    "searchInput": "pf-m-search-input",
    "searchExpand": "pf-m-search-expand",
    "searchAction": "pf-m-search-action",
    "expandStart": "pf-m-expand-start",
    "box": "pf-m-box",
    "fill": "pf-m-fill",
    "center": "pf-m-center",
    "nonExpandable": "pf-m-non-expandable",
    "expandableOnSm": "pf-m-expandable-on-sm",
    "nonExpandableOnSm": "pf-m-non-expandable-on-sm",
    "expandableOnMd": "pf-m-expandable-on-md",
    "nonExpandableOnMd": "pf-m-non-expandable-on-md",
    "expandableOnLg": "pf-m-expandable-on-lg",
    "nonExpandableOnLg": "pf-m-non-expandable-on-lg",
    "expandableOnXl": "pf-m-expandable-on-xl",
    "nonExpandableOnXl": "pf-m-non-expandable-on-xl",
    "expandableOn_2xl": "pf-m-expandable-on-2xl",
    "nonExpandableOn_2xl": "pf-m-non-expandable-on-2xl",
    "filled": "pf-m-filled",
    "outline": "pf-m-outline",
    "editable": "pf-m-editable",
    "editableActive": "pf-m-editable-active",
    "overflow": "pf-m-overflow",
    "add": "pf-m-add",
    "category": "pf-m-category",
    "iconLg": "pf-m-icon-lg",
    "resizeObserver": "pf-m-resize-observer",
    "displayStack": "pf-m-display-stack",
    "displayInline": "pf-m-display-inline",
    "displayStackOnSm": "pf-m-display-stack-on-sm",
    "displayInlineOnSm": "pf-m-display-inline-on-sm",
    "displayStackOnMd": "pf-m-display-stack-on-md",
    "displayInlineOnMd": "pf-m-display-inline-on-md",
    "displayStackOnLg": "pf-m-display-stack-on-lg",
    "displayInlineOnLg": "pf-m-display-inline-on-lg",
    "displayStackOnXl": "pf-m-display-stack-on-xl",
    "displayInlineOnXl": "pf-m-display-inline-on-xl",
    "displayStackOn_2xl": "pf-m-display-stack-on-2xl",
    "displayInlineOn_2xl": "pf-m-display-inline-on-2xl",
    "flyout": "pf-m-flyout",
    "left": "pf-m-left",
    "drilldown": "pf-m-drilldown",
    "drilledIn": "pf-m-drilled-in",
    "currentPath": "pf-m-current-path",
    "scrollable": "pf-m-scrollable",
    "load": "pf-m-load",
    "fullWidth": "pf-m-full-width",
    "splitButton": "pf-m-split-button",
    "typeahead": "pf-m-typeahead",
    "text": "pf-m-text",
    "avatar": "pf-m-avatar",
    "alignTop": "pf-m-align-top",
    "help": "pf-m-help",
    "overflowHidden": "pf-m-overflow-hidden",
    "inset": "pf-m-inset",
    "subnav": "pf-m-subnav",
    "hoverable": "pf-m-hoverable",
    "buttonGroup": "pf-m-button-group",
    "iconButtonGroup": "pf-m-icon-button-group",
    "collapsed": "pf-m-collapsed",
    "pageInsets": "pf-m-page-insets",
    "contextSelector": "pf-m-context-selector",
    "alignCenter": "pf-m-align-center",
    "overflowScroll": "pf-m-overflow-scroll",
    "shadowBottom": "pf-m-shadow-bottom",
    "shadowTop": "pf-m-shadow-top",
    "stickyTop": "pf-m-sticky-top",
    "stickyBottom": "pf-m-sticky-bottom",
    "stickyTopOnSmHeight": "pf-m-sticky-top-on-sm-height",
    "stickyBottomOnSmHeight": "pf-m-sticky-bottom-on-sm-height",
    "stickyTopOnMdHeight": "pf-m-sticky-top-on-md-height",
    "stickyBottomOnMdHeight": "pf-m-sticky-bottom-on-md-height",
    "stickyTopOnLgHeight": "pf-m-sticky-top-on-lg-height",
    "stickyBottomOnLgHeight": "pf-m-sticky-bottom-on-lg-height",
    "stickyTopOnXlHeight": "pf-m-sticky-top-on-xl-height",
    "stickyBottomOnXlHeight": "pf-m-sticky-bottom-on-xl-height",
    "stickyTopOn_2xlHeight": "pf-m-sticky-top-on-2xl-height",
    "stickyBottomOn_2xlHeight": "pf-m-sticky-bottom-on-2xl-height",
    "noSidebar": "pf-m-no-sidebar",
    "paddingOnSm": "pf-m-padding-on-sm",
    "noPaddingOnSm": "pf-m-no-padding-on-sm",
    "paddingOnMd": "pf-m-padding-on-md",
    "noPaddingOnMd": "pf-m-no-padding-on-md",
    "paddingOnLg": "pf-m-padding-on-lg",
    "noPaddingOnLg": "pf-m-no-padding-on-lg",
    "paddingOnXl": "pf-m-padding-on-xl",
    "noPaddingOnXl": "pf-m-no-padding-on-xl",
    "paddingOn_2xl": "pf-m-padding-on-2xl",
    "noPaddingOn_2xl": "pf-m-no-padding-on-2xl",
    "bottom": "pf-m-bottom",
    "first": "pf-m-first",
    "last": "pf-m-last",
    "displaySummary": "pf-m-display-summary",
    "displayFull": "pf-m-display-full",
    "displaySummaryOnSm": "pf-m-display-summary-on-sm",
    "displayFullOnSm": "pf-m-display-full-on-sm",
    "displaySummaryOnMd": "pf-m-display-summary-on-md",
    "displayFullOnMd": "pf-m-display-full-on-md",
    "displaySummaryOnLg": "pf-m-display-summary-on-lg",
    "displayFullOnLg": "pf-m-display-full-on-lg",
    "displaySummaryOnXl": "pf-m-display-summary-on-xl",
    "displayFullOnXl": "pf-m-display-full-on-xl",
    "displaySummaryOn_2xl": "pf-m-display-summary-on-2xl",
    "displayFullOn_2xl": "pf-m-display-full-on-2xl",
    "raised": "pf-m-raised",
    "widthAuto": "pf-m-width-auto",
    "topLeft": "pf-m-top-left",
    "topRight": "pf-m-top-right",
    "bottomLeft": "pf-m-bottom-left",
    "bottomRight": "pf-m-bottom-right",
    "leftTop": "pf-m-left-top",
    "leftBottom": "pf-m-left-bottom",
    "right": "pf-m-right",
    "rightTop": "pf-m-right-top",
    "rightBottom": "pf-m-right-bottom",
    "inside": "pf-m-inside",
    "outside": "pf-m-outside",
    "staticWidth": "pf-m-static-width",
    "singleline": "pf-m-singleline",
    "pending": "pf-m-pending",
    "gutter": "pf-m-gutter",
    "panelRight": "pf-m-panel-right",
    "split": "pf-m-split",
    "border": "pf-m-border",
    "widthDefault": "pf-m-width-default",
    "widthDefaultOnSm": "pf-m-width-default-on-sm",
    "width_25OnSm": "pf-m-width-25-on-sm",
    "width_33OnSm": "pf-m-width-33-on-sm",
    "width_50OnSm": "pf-m-width-50-on-sm",
    "width_66OnSm": "pf-m-width-66-on-sm",
    "width_75OnSm": "pf-m-width-75-on-sm",
    "width_100OnSm": "pf-m-width-100-on-sm",
    "widthDefaultOnMd": "pf-m-width-default-on-md",
    "width_25OnMd": "pf-m-width-25-on-md",
    "width_33OnMd": "pf-m-width-33-on-md",
    "width_50OnMd": "pf-m-width-50-on-md",
    "width_66OnMd": "pf-m-width-66-on-md",
    "width_75OnMd": "pf-m-width-75-on-md",
    "width_100OnMd": "pf-m-width-100-on-md",
    "widthDefaultOnLg": "pf-m-width-default-on-lg",
    "widthDefaultOnXl": "pf-m-width-default-on-xl",
    "widthDefaultOn_2xl": "pf-m-width-default-on-2xl",
    "circle": "pf-m-circle",
    "square": "pf-m-square",
    "widthSm": "pf-m-width-sm",
    "widthMd": "pf-m-width-md",
    "widthLg": "pf-m-width-lg",
    "heightSm": "pf-m-height-sm",
    "heightMd": "pf-m-height-md",
    "heightLg": "pf-m-height-lg",
    "height_25": "pf-m-height-25",
    "height_33": "pf-m-height-33",
    "height_50": "pf-m-height-50",
    "height_66": "pf-m-height-66",
    "height_75": "pf-m-height-75",
    "height_100": "pf-m-height-100",
    "text_4xl": "pf-m-text-4xl",
    "text_3xl": "pf-m-text-3xl",
    "text_2xl": "pf-m-text-2xl",
    "textXl": "pf-m-text-xl",
    "textLg": "pf-m-text-lg",
    "textMd": "pf-m-text-md",
    "textSm": "pf-m-text-sm",
    "active": "pf-m-active",
    "floating": "pf-m-floating",
    "reverse": "pf-m-reverse",
    "grid": "pf-m-grid",
    "fitContent": "pf-m-fit-content",
    "stickyHeader": "pf-m-sticky-header",
    "nestedColumnHeader": "pf-m-nested-column-header",
    "striped": "pf-m-striped",
    "stripedEven": "pf-m-striped-even",
    "borderRight": "pf-m-border-right",
    "borderLeft": "pf-m-border-left",
    "noBorderRows": "pf-m-no-border-rows",
    "firstCellOffsetReset": "pf-m-first-cell-offset-reset",
    "noAnimateExpand": "pf-m-no-animate-expand",
    "borderRow": "pf-m-border-row",
    "width_10": "pf-m-width-10",
    "width_15": "pf-m-width-15",
    "width_20": "pf-m-width-20",
    "width_30": "pf-m-width-30",
    "width_35": "pf-m-width-35",
    "width_40": "pf-m-width-40",
    "width_45": "pf-m-width-45",
    "width_60": "pf-m-width-60",
    "width_70": "pf-m-width-70",
    "width_80": "pf-m-width-80",
    "width_90": "pf-m-width-90",
    "inlineEnd": "pf-m-inline-end",
    "inlineStart": "pf-m-inline-start",
    "treeView": "pf-m-tree-view",
    "noInset": "pf-m-no-inset",
    "treeViewGrid": "pf-m-tree-view-grid",
    "treeViewDetailsExpanded": "pf-m-tree-view-details-expanded",
    "treeViewGridMd": "pf-m-tree-view-grid-md",
    "treeViewGridLg": "pf-m-tree-view-grid-lg",
    "treeViewGridXl": "pf-m-tree-view-grid-xl",
    "treeViewGrid_2xl": "pf-m-tree-view-grid-2xl",
    "noBorderBottom": "pf-m-no-border-bottom",
    "subtab": "pf-m-subtab",
    "animateCurrent": "pf-m-animate-current",
    "initializingAccent": "pf-m-initializing-accent",
    "hint": "pf-m-hint",
    "stacked": "pf-m-stacked",
    "4xl": "pf-m-4xl",
    "h1": "pf-m-h1",
    "h2": "pf-m-h2",
    "h3": "pf-m-h3",
    "h4": "pf-m-h4",
    "h5": "pf-m-h5",
    "h6": "pf-m-h6",
    "expandAll": "pf-m-expand-all",
    "label": "pf-m-label",
    "pagination": "pf-m-pagination",
    "overflowContainer": "pf-m-overflow-container",
    "filterGroup": "pf-m-filter-group",
    "labelGroup": "pf-m-label-group",
    "actionGroupPlain": "pf-m-action-group-plain",
    "actionGroupInline": "pf-m-action-group-inline",
    "alignStart": "pf-m-align-start",
    "alignEnd": "pf-m-align-end",
    "flexGrow": "pf-m-flex-grow",
    "alignSelfStretch": "pf-m-align-self-stretch",
    "alignSelfBaseline": "pf-m-align-self-baseline",
    "alignSelfStart": "pf-m-align-self-start",
    "alignSelfCenter": "pf-m-align-self-center",
    "alignSelfEnd": "pf-m-align-self-end",
    "inset_4xl": "pf-m-inset-4xl",
    "alignItemsStretch": "pf-m-align-items-stretch",
    "alignItemsBaseline": "pf-m-align-items-baseline",
    "alignItemsStart": "pf-m-align-items-start",
    "alignItemsCenter": "pf-m-align-items-center",
    "alignItemsEnd": "pf-m-align-items-end",
    "gapNone": "pf-m-gap-none",
    "gapXs": "pf-m-gap-xs",
    "gapSm": "pf-m-gap-sm",
    "gapMd": "pf-m-gap-md",
    "gapLg": "pf-m-gap-lg",
    "gapXl": "pf-m-gap-xl",
    "gap_2xl": "pf-m-gap-2xl",
    "gap_3xl": "pf-m-gap-3xl",
    "gap_4xl": "pf-m-gap-4xl",
    "columnGapNone": "pf-m-column-gap-none",
    "rowGapNone": "pf-m-row-gap-none",
    "columnGapXs": "pf-m-column-gap-xs",
    "rowGapXs": "pf-m-row-gap-xs",
    "columnGapSm": "pf-m-column-gap-sm",
    "rowGapSm": "pf-m-row-gap-sm",
    "columnGapMd": "pf-m-column-gap-md",
    "rowGapMd": "pf-m-row-gap-md",
    "columnGapLg": "pf-m-column-gap-lg",
    "rowGapLg": "pf-m-row-gap-lg",
    "columnGapXl": "pf-m-column-gap-xl",
    "rowGapXl": "pf-m-row-gap-xl",
    "columnGap_2xl": "pf-m-column-gap-2xl",
    "rowGap_2xl": "pf-m-row-gap-2xl",
    "columnGap_3xl": "pf-m-column-gap-3xl",
    "rowGap_3xl": "pf-m-row-gap-3xl",
    "columnGap_4xl": "pf-m-column-gap-4xl",
    "rowGap_4xl": "pf-m-row-gap-4xl",
    "toggleGroup": "pf-m-toggle-group",
    "show": "pf-m-show",
    "hide": "pf-m-hide",
    "alignStartOnSm": "pf-m-align-start-on-sm",
    "alignCenterOnSm": "pf-m-align-center-on-sm",
    "alignEndOnSm": "pf-m-align-end-on-sm",
    "flexGrowOnSm": "pf-m-flex-grow-on-sm",
    "alignSelfStretchOnSm": "pf-m-align-self-stretch-on-sm",
    "alignSelfBaselineOnSm": "pf-m-align-self-baseline-on-sm",
    "alignSelfStartOnSm": "pf-m-align-self-start-on-sm",
    "alignSelfCenterOnSm": "pf-m-align-self-center-on-sm",
    "alignSelfEndOnSm": "pf-m-align-self-end-on-sm",
    "inset_4xlOnSm": "pf-m-inset-4xl-on-sm",
    "wrapOnSm": "pf-m-wrap-on-sm",
    "nowrapOnSm": "pf-m-nowrap-on-sm",
    "alignItemsStretchOnSm": "pf-m-align-items-stretch-on-sm",
    "alignItemsBaselineOnSm": "pf-m-align-items-baseline-on-sm",
    "alignItemsStartOnSm": "pf-m-align-items-start-on-sm",
    "alignItemsCenterOnSm": "pf-m-align-items-center-on-sm",
    "alignItemsEndOnSm": "pf-m-align-items-end-on-sm",
    "gapNoneOnSm": "pf-m-gap-none-on-sm",
    "gapXsOnSm": "pf-m-gap-xs-on-sm",
    "gapSmOnSm": "pf-m-gap-sm-on-sm",
    "gapMdOnSm": "pf-m-gap-md-on-sm",
    "gapLgOnSm": "pf-m-gap-lg-on-sm",
    "gapXlOnSm": "pf-m-gap-xl-on-sm",
    "gap_2xlOnSm": "pf-m-gap-2xl-on-sm",
    "gap_3xlOnSm": "pf-m-gap-3xl-on-sm",
    "gap_4xlOnSm": "pf-m-gap-4xl-on-sm",
    "columnGapNoneOnSm": "pf-m-column-gap-none-on-sm",
    "rowGapNoneOnSm": "pf-m-row-gap-none-on-sm",
    "columnGapXsOnSm": "pf-m-column-gap-xs-on-sm",
    "rowGapXsOnSm": "pf-m-row-gap-xs-on-sm",
    "columnGapSmOnSm": "pf-m-column-gap-sm-on-sm",
    "rowGapSmOnSm": "pf-m-row-gap-sm-on-sm",
    "columnGapMdOnSm": "pf-m-column-gap-md-on-sm",
    "rowGapMdOnSm": "pf-m-row-gap-md-on-sm",
    "columnGapLgOnSm": "pf-m-column-gap-lg-on-sm",
    "rowGapLgOnSm": "pf-m-row-gap-lg-on-sm",
    "columnGapXlOnSm": "pf-m-column-gap-xl-on-sm",
    "rowGapXlOnSm": "pf-m-row-gap-xl-on-sm",
    "columnGap_2xlOnSm": "pf-m-column-gap-2xl-on-sm",
    "rowGap_2xlOnSm": "pf-m-row-gap-2xl-on-sm",
    "columnGap_3xlOnSm": "pf-m-column-gap-3xl-on-sm",
    "rowGap_3xlOnSm": "pf-m-row-gap-3xl-on-sm",
    "columnGap_4xlOnSm": "pf-m-column-gap-4xl-on-sm",
    "rowGap_4xlOnSm": "pf-m-row-gap-4xl-on-sm",
    "showOnSm": "pf-m-show-on-sm",
    "hideOnSm": "pf-m-hide-on-sm",
    "alignStartOnMd": "pf-m-align-start-on-md",
    "alignCenterOnMd": "pf-m-align-center-on-md",
    "alignEndOnMd": "pf-m-align-end-on-md",
    "flexGrowOnMd": "pf-m-flex-grow-on-md",
    "alignSelfStretchOnMd": "pf-m-align-self-stretch-on-md",
    "alignSelfBaselineOnMd": "pf-m-align-self-baseline-on-md",
    "alignSelfStartOnMd": "pf-m-align-self-start-on-md",
    "alignSelfCenterOnMd": "pf-m-align-self-center-on-md",
    "alignSelfEndOnMd": "pf-m-align-self-end-on-md",
    "inset_4xlOnMd": "pf-m-inset-4xl-on-md",
    "wrapOnMd": "pf-m-wrap-on-md",
    "nowrapOnMd": "pf-m-nowrap-on-md",
    "alignItemsStretchOnMd": "pf-m-align-items-stretch-on-md",
    "alignItemsBaselineOnMd": "pf-m-align-items-baseline-on-md",
    "alignItemsStartOnMd": "pf-m-align-items-start-on-md",
    "alignItemsCenterOnMd": "pf-m-align-items-center-on-md",
    "alignItemsEndOnMd": "pf-m-align-items-end-on-md",
    "gapNoneOnMd": "pf-m-gap-none-on-md",
    "gapXsOnMd": "pf-m-gap-xs-on-md",
    "gapSmOnMd": "pf-m-gap-sm-on-md",
    "gapMdOnMd": "pf-m-gap-md-on-md",
    "gapLgOnMd": "pf-m-gap-lg-on-md",
    "gapXlOnMd": "pf-m-gap-xl-on-md",
    "gap_2xlOnMd": "pf-m-gap-2xl-on-md",
    "gap_3xlOnMd": "pf-m-gap-3xl-on-md",
    "gap_4xlOnMd": "pf-m-gap-4xl-on-md",
    "columnGapNoneOnMd": "pf-m-column-gap-none-on-md",
    "rowGapNoneOnMd": "pf-m-row-gap-none-on-md",
    "columnGapXsOnMd": "pf-m-column-gap-xs-on-md",
    "rowGapXsOnMd": "pf-m-row-gap-xs-on-md",
    "columnGapSmOnMd": "pf-m-column-gap-sm-on-md",
    "rowGapSmOnMd": "pf-m-row-gap-sm-on-md",
    "columnGapMdOnMd": "pf-m-column-gap-md-on-md",
    "rowGapMdOnMd": "pf-m-row-gap-md-on-md",
    "columnGapLgOnMd": "pf-m-column-gap-lg-on-md",
    "rowGapLgOnMd": "pf-m-row-gap-lg-on-md",
    "columnGapXlOnMd": "pf-m-column-gap-xl-on-md",
    "rowGapXlOnMd": "pf-m-row-gap-xl-on-md",
    "columnGap_2xlOnMd": "pf-m-column-gap-2xl-on-md",
    "rowGap_2xlOnMd": "pf-m-row-gap-2xl-on-md",
    "columnGap_3xlOnMd": "pf-m-column-gap-3xl-on-md",
    "rowGap_3xlOnMd": "pf-m-row-gap-3xl-on-md",
    "columnGap_4xlOnMd": "pf-m-column-gap-4xl-on-md",
    "rowGap_4xlOnMd": "pf-m-row-gap-4xl-on-md",
    "showOnMd": "pf-m-show-on-md",
    "hideOnMd": "pf-m-hide-on-md",
    "alignStartOnLg": "pf-m-align-start-on-lg",
    "alignCenterOnLg": "pf-m-align-center-on-lg",
    "alignEndOnLg": "pf-m-align-end-on-lg",
    "flexGrowOnLg": "pf-m-flex-grow-on-lg",
    "alignSelfStretchOnLg": "pf-m-align-self-stretch-on-lg",
    "alignSelfBaselineOnLg": "pf-m-align-self-baseline-on-lg",
    "alignSelfStartOnLg": "pf-m-align-self-start-on-lg",
    "alignSelfCenterOnLg": "pf-m-align-self-center-on-lg",
    "alignSelfEndOnLg": "pf-m-align-self-end-on-lg",
    "inset_4xlOnLg": "pf-m-inset-4xl-on-lg",
    "wrapOnLg": "pf-m-wrap-on-lg",
    "nowrapOnLg": "pf-m-nowrap-on-lg",
    "alignItemsStretchOnLg": "pf-m-align-items-stretch-on-lg",
    "alignItemsBaselineOnLg": "pf-m-align-items-baseline-on-lg",
    "alignItemsStartOnLg": "pf-m-align-items-start-on-lg",
    "alignItemsCenterOnLg": "pf-m-align-items-center-on-lg",
    "alignItemsEndOnLg": "pf-m-align-items-end-on-lg",
    "gapNoneOnLg": "pf-m-gap-none-on-lg",
    "gapXsOnLg": "pf-m-gap-xs-on-lg",
    "gapSmOnLg": "pf-m-gap-sm-on-lg",
    "gapMdOnLg": "pf-m-gap-md-on-lg",
    "gapLgOnLg": "pf-m-gap-lg-on-lg",
    "gapXlOnLg": "pf-m-gap-xl-on-lg",
    "gap_2xlOnLg": "pf-m-gap-2xl-on-lg",
    "gap_3xlOnLg": "pf-m-gap-3xl-on-lg",
    "gap_4xlOnLg": "pf-m-gap-4xl-on-lg",
    "columnGapNoneOnLg": "pf-m-column-gap-none-on-lg",
    "rowGapNoneOnLg": "pf-m-row-gap-none-on-lg",
    "columnGapXsOnLg": "pf-m-column-gap-xs-on-lg",
    "rowGapXsOnLg": "pf-m-row-gap-xs-on-lg",
    "columnGapSmOnLg": "pf-m-column-gap-sm-on-lg",
    "rowGapSmOnLg": "pf-m-row-gap-sm-on-lg",
    "columnGapMdOnLg": "pf-m-column-gap-md-on-lg",
    "rowGapMdOnLg": "pf-m-row-gap-md-on-lg",
    "columnGapLgOnLg": "pf-m-column-gap-lg-on-lg",
    "rowGapLgOnLg": "pf-m-row-gap-lg-on-lg",
    "columnGapXlOnLg": "pf-m-column-gap-xl-on-lg",
    "rowGapXlOnLg": "pf-m-row-gap-xl-on-lg",
    "columnGap_2xlOnLg": "pf-m-column-gap-2xl-on-lg",
    "rowGap_2xlOnLg": "pf-m-row-gap-2xl-on-lg",
    "columnGap_3xlOnLg": "pf-m-column-gap-3xl-on-lg",
    "rowGap_3xlOnLg": "pf-m-row-gap-3xl-on-lg",
    "columnGap_4xlOnLg": "pf-m-column-gap-4xl-on-lg",
    "rowGap_4xlOnLg": "pf-m-row-gap-4xl-on-lg",
    "showOnLg": "pf-m-show-on-lg",
    "hideOnLg": "pf-m-hide-on-lg",
    "alignStartOnXl": "pf-m-align-start-on-xl",
    "alignCenterOnXl": "pf-m-align-center-on-xl",
    "alignEndOnXl": "pf-m-align-end-on-xl",
    "flexGrowOnXl": "pf-m-flex-grow-on-xl",
    "alignSelfStretchOnXl": "pf-m-align-self-stretch-on-xl",
    "alignSelfBaselineOnXl": "pf-m-align-self-baseline-on-xl",
    "alignSelfStartOnXl": "pf-m-align-self-start-on-xl",
    "alignSelfCenterOnXl": "pf-m-align-self-center-on-xl",
    "alignSelfEndOnXl": "pf-m-align-self-end-on-xl",
    "inset_4xlOnXl": "pf-m-inset-4xl-on-xl",
    "wrapOnXl": "pf-m-wrap-on-xl",
    "nowrapOnXl": "pf-m-nowrap-on-xl",
    "alignItemsStretchOnXl": "pf-m-align-items-stretch-on-xl",
    "alignItemsBaselineOnXl": "pf-m-align-items-baseline-on-xl",
    "alignItemsStartOnXl": "pf-m-align-items-start-on-xl",
    "alignItemsCenterOnXl": "pf-m-align-items-center-on-xl",
    "alignItemsEndOnXl": "pf-m-align-items-end-on-xl",
    "gapNoneOnXl": "pf-m-gap-none-on-xl",
    "gapXsOnXl": "pf-m-gap-xs-on-xl",
    "gapSmOnXl": "pf-m-gap-sm-on-xl",
    "gapMdOnXl": "pf-m-gap-md-on-xl",
    "gapLgOnXl": "pf-m-gap-lg-on-xl",
    "gapXlOnXl": "pf-m-gap-xl-on-xl",
    "gap_2xlOnXl": "pf-m-gap-2xl-on-xl",
    "gap_3xlOnXl": "pf-m-gap-3xl-on-xl",
    "gap_4xlOnXl": "pf-m-gap-4xl-on-xl",
    "columnGapNoneOnXl": "pf-m-column-gap-none-on-xl",
    "rowGapNoneOnXl": "pf-m-row-gap-none-on-xl",
    "columnGapXsOnXl": "pf-m-column-gap-xs-on-xl",
    "rowGapXsOnXl": "pf-m-row-gap-xs-on-xl",
    "columnGapSmOnXl": "pf-m-column-gap-sm-on-xl",
    "rowGapSmOnXl": "pf-m-row-gap-sm-on-xl",
    "columnGapMdOnXl": "pf-m-column-gap-md-on-xl",
    "rowGapMdOnXl": "pf-m-row-gap-md-on-xl",
    "columnGapLgOnXl": "pf-m-column-gap-lg-on-xl",
    "rowGapLgOnXl": "pf-m-row-gap-lg-on-xl",
    "columnGapXlOnXl": "pf-m-column-gap-xl-on-xl",
    "rowGapXlOnXl": "pf-m-row-gap-xl-on-xl",
    "columnGap_2xlOnXl": "pf-m-column-gap-2xl-on-xl",
    "rowGap_2xlOnXl": "pf-m-row-gap-2xl-on-xl",
    "columnGap_3xlOnXl": "pf-m-column-gap-3xl-on-xl",
    "rowGap_3xlOnXl": "pf-m-row-gap-3xl-on-xl",
    "columnGap_4xlOnXl": "pf-m-column-gap-4xl-on-xl",
    "rowGap_4xlOnXl": "pf-m-row-gap-4xl-on-xl",
    "showOnXl": "pf-m-show-on-xl",
    "hideOnXl": "pf-m-hide-on-xl",
    "alignStartOn_2xl": "pf-m-align-start-on-2xl",
    "alignCenterOn_2xl": "pf-m-align-center-on-2xl",
    "alignEndOn_2xl": "pf-m-align-end-on-2xl",
    "flexGrowOn_2xl": "pf-m-flex-grow-on-2xl",
    "alignSelfStretchOn_2xl": "pf-m-align-self-stretch-on-2xl",
    "alignSelfBaselineOn_2xl": "pf-m-align-self-baseline-on-2xl",
    "alignSelfStartOn_2xl": "pf-m-align-self-start-on-2xl",
    "alignSelfCenterOn_2xl": "pf-m-align-self-center-on-2xl",
    "alignSelfEndOn_2xl": "pf-m-align-self-end-on-2xl",
    "inset_4xlOn_2xl": "pf-m-inset-4xl-on-2xl",
    "wrapOn_2xl": "pf-m-wrap-on-2xl",
    "nowrapOn_2xl": "pf-m-nowrap-on-2xl",
    "alignItemsStretchOn_2xl": "pf-m-align-items-stretch-on-2xl",
    "alignItemsBaselineOn_2xl": "pf-m-align-items-baseline-on-2xl",
    "alignItemsStartOn_2xl": "pf-m-align-items-start-on-2xl",
    "alignItemsCenterOn_2xl": "pf-m-align-items-center-on-2xl",
    "alignItemsEndOn_2xl": "pf-m-align-items-end-on-2xl",
    "gapNoneOn_2xl": "pf-m-gap-none-on-2xl",
    "gapXsOn_2xl": "pf-m-gap-xs-on-2xl",
    "gapSmOn_2xl": "pf-m-gap-sm-on-2xl",
    "gapMdOn_2xl": "pf-m-gap-md-on-2xl",
    "gapLgOn_2xl": "pf-m-gap-lg-on-2xl",
    "gapXlOn_2xl": "pf-m-gap-xl-on-2xl",
    "gap_2xlOn_2xl": "pf-m-gap-2xl-on-2xl",
    "gap_3xlOn_2xl": "pf-m-gap-3xl-on-2xl",
    "gap_4xlOn_2xl": "pf-m-gap-4xl-on-2xl",
    "columnGapNoneOn_2xl": "pf-m-column-gap-none-on-2xl",
    "rowGapNoneOn_2xl": "pf-m-row-gap-none-on-2xl",
    "columnGapXsOn_2xl": "pf-m-column-gap-xs-on-2xl",
    "rowGapXsOn_2xl": "pf-m-row-gap-xs-on-2xl",
    "columnGapSmOn_2xl": "pf-m-column-gap-sm-on-2xl",
    "rowGapSmOn_2xl": "pf-m-row-gap-sm-on-2xl",
    "columnGapMdOn_2xl": "pf-m-column-gap-md-on-2xl",
    "rowGapMdOn_2xl": "pf-m-row-gap-md-on-2xl",
    "columnGapLgOn_2xl": "pf-m-column-gap-lg-on-2xl",
    "rowGapLgOn_2xl": "pf-m-row-gap-lg-on-2xl",
    "columnGapXlOn_2xl": "pf-m-column-gap-xl-on-2xl",
    "rowGapXlOn_2xl": "pf-m-row-gap-xl-on-2xl",
    "columnGap_2xlOn_2xl": "pf-m-column-gap-2xl-on-2xl",
    "rowGap_2xlOn_2xl": "pf-m-row-gap-2xl-on-2xl",
    "columnGap_3xlOn_2xl": "pf-m-column-gap-3xl-on-2xl",
    "rowGap_3xlOn_2xl": "pf-m-row-gap-3xl-on-2xl",
    "columnGap_4xlOn_2xl": "pf-m-column-gap-4xl-on-2xl",
    "rowGap_4xlOn_2xl": "pf-m-row-gap-4xl-on-2xl",
    "showOn_2xl": "pf-m-show-on-2xl",
    "hideOn_2xl": "pf-m-hide-on-2xl",
    "textAlignLeft": "pf-m-text-align-left",
    "guides": "pf-m-guides",
    "finished": "pf-m-finished"
  },
  "monacoEditor": "monaco-editor",
  "multipleFileUpload": "pf-v6-c-multiple-file-upload",
  "multipleFileUploadInfo": "pf-v6-c-multiple-file-upload__info",
  "multipleFileUploadMain": "pf-v6-c-multiple-file-upload__main",
  "multipleFileUploadStatus": "pf-v6-c-multiple-file-upload__status",
  "multipleFileUploadStatusItem": "pf-v6-c-multiple-file-upload__status-item",
  "multipleFileUploadStatusItemIcon": "pf-v6-c-multiple-file-upload__status-item-icon",
  "multipleFileUploadStatusItemMain": "pf-v6-c-multiple-file-upload__status-item-main",
  "multipleFileUploadStatusItemProgress": "pf-v6-c-multiple-file-upload__status-item-progress",
  "multipleFileUploadStatusItemProgressSize": "pf-v6-c-multiple-file-upload__status-item-progress-size",
  "multipleFileUploadStatusItemProgressText": "pf-v6-c-multiple-file-upload__status-item-progress-text",
  "multipleFileUploadStatusProgress": "pf-v6-c-multiple-file-upload__status-progress",
  "multipleFileUploadStatusProgressIcon": "pf-v6-c-multiple-file-upload__status-progress-icon",
  "multipleFileUploadTitle": "pf-v6-c-multiple-file-upload__title",
  "multipleFileUploadTitleIcon": "pf-v6-c-multiple-file-upload__title-icon",
  "multipleFileUploadTitleText": "pf-v6-c-multiple-file-upload__title-text",
  "multipleFileUploadTitleTextSeparator": "pf-v6-c-multiple-file-upload__title-text-separator",
  "multipleFileUploadUpload": "pf-v6-c-multiple-file-upload__upload",
  "nav": "pf-v6-c-nav",
  "navItem": "pf-v6-c-nav__item",
  "navLink": "pf-v6-c-nav__link",
  "navLinkIcon": "pf-v6-c-nav__link-icon",
  "navList": "pf-v6-c-nav__list",
  "navNav": "pf-v6-c-nav__nav",
  "navScrollButton": "pf-v6-c-nav__scroll-button",
  "navSection": "pf-v6-c-nav__section",
  "navSectionTitle": "pf-v6-c-nav__section-title",
  "navSubnav": "pf-v6-c-nav__subnav",
  "navToggle": "pf-v6-c-nav__toggle",
  "navToggleIcon": "pf-v6-c-nav__toggle-icon",
  "notificationDrawer": "pf-v6-c-notification-drawer",
  "notificationDrawerBody": "pf-v6-c-notification-drawer__body",
  "notificationDrawerGroup": "pf-v6-c-notification-drawer__group",
  "notificationDrawerGroupList": "pf-v6-c-notification-drawer__group-list",
  "notificationDrawerGroupToggle": "pf-v6-c-notification-drawer__group-toggle",
  "notificationDrawerGroupToggleCount": "pf-v6-c-notification-drawer__group-toggle-count",
  "notificationDrawerGroupToggleIcon": "pf-v6-c-notification-drawer__group-toggle-icon",
  "notificationDrawerGroupToggleTitle": "pf-v6-c-notification-drawer__group-toggle-title",
  "notificationDrawerHeader": "pf-v6-c-notification-drawer__header",
  "notificationDrawerHeaderAction": "pf-v6-c-notification-drawer__header-action",
  "notificationDrawerHeaderStatus": "pf-v6-c-notification-drawer__header-status",
  "notificationDrawerHeaderTitle": "pf-v6-c-notification-drawer__header-title",
  "notificationDrawerList": "pf-v6-c-notification-drawer__list",
  "notificationDrawerListItem": "pf-v6-c-notification-drawer__list-item",
  "notificationDrawerListItemAction": "pf-v6-c-notification-drawer__list-item-action",
  "notificationDrawerListItemDescription": "pf-v6-c-notification-drawer__list-item-description",
  "notificationDrawerListItemHeader": "pf-v6-c-notification-drawer__list-item-header",
  "notificationDrawerListItemHeaderIcon": "pf-v6-c-notification-drawer__list-item-header-icon",
  "notificationDrawerListItemHeaderTitle": "pf-v6-c-notification-drawer__list-item-header-title",
  "notificationDrawerListItemTimestamp": "pf-v6-c-notification-drawer__list-item-timestamp",
  "numberInput": "pf-v6-c-number-input",
  "numberInputIcon": "pf-v6-c-number-input__icon",
  "numberInputUnit": "pf-v6-c-number-input__unit",
  "overflowMenu": "pf-v6-c-overflow-menu",
  "overflowMenuContent": "pf-v6-c-overflow-menu__content",
  "overflowMenuControl": "pf-v6-c-overflow-menu__control",
  "overflowMenuGroup": "pf-v6-c-overflow-menu__group",
  "overflowMenuItem": "pf-v6-c-overflow-menu__item",
  "page": "pf-v6-c-page",
  "pageDrawer": "pf-v6-c-page__drawer",
  "pageMain": "pf-v6-c-page__main",
  "pageMainBody": "pf-v6-c-page__main-body",
  "pageMainBreadcrumb": "pf-v6-c-page__main-breadcrumb",
  "pageMainContainer": "pf-v6-c-page__main-container",
  "pageMainDrawer": "pf-v6-c-page__main-drawer",
  "pageMainGroup": "pf-v6-c-page__main-group",
  "pageMainSection": "pf-v6-c-page__main-section",
  "pageMainSubnav": "pf-v6-c-page__main-subnav",
  "pageMainTabs": "pf-v6-c-page__main-tabs",
  "pageMainWizard": "pf-v6-c-page__main-wizard",
  "pageSidebar": "pf-v6-c-page__sidebar",
  "pageSidebarBody": "pf-v6-c-page__sidebar-body",
  "pageSidebarHeader": "pf-v6-c-page__sidebar-header",
  "pageSidebarTitle": "pf-v6-c-page__sidebar-title",
  "pagination": "pf-v6-c-pagination",
  "paginationNav": "pf-v6-c-pagination__nav",
  "paginationNavControl": "pf-v6-c-pagination__nav-control",
  "paginationNavPageSelect": "pf-v6-c-pagination__nav-page-select",
  "paginationPageMenu": "pf-v6-c-pagination__page-menu",
  "paginationTotalItems": "pf-v6-c-pagination__total-items",
  "panel": "pf-v6-c-panel",
  "panelFooter": "pf-v6-c-panel__footer",
  "panelHeader": "pf-v6-c-panel__header",
  "panelMain": "pf-v6-c-panel__main",
  "panelMainBody": "pf-v6-c-panel__main-body",
  "pficon": "pf-v6-pficon",
  "popover": "pf-v6-c-popover",
  "popoverArrow": "pf-v6-c-popover__arrow",
  "popoverBody": "pf-v6-c-popover__body",
  "popoverClose": "pf-v6-c-popover__close",
  "popoverContent": "pf-v6-c-popover__content",
  "popoverFooter": "pf-v6-c-popover__footer",
  "popoverHeader": "pf-v6-c-popover__header",
  "popoverTitle": "pf-v6-c-popover__title",
  "popoverTitleIcon": "pf-v6-c-popover__title-icon",
  "popoverTitleText": "pf-v6-c-popover__title-text",
  "progress": "pf-v6-c-progress",
  "progressBar": "pf-v6-c-progress__bar",
  "progressDescription": "pf-v6-c-progress__description",
  "progressHelperText": "pf-v6-c-progress__helper-text",
  "progressIndicator": "pf-v6-c-progress__indicator",
  "progressMeasure": "pf-v6-c-progress__measure",
  "progressStatus": "pf-v6-c-progress__status",
  "progressStatusIcon": "pf-v6-c-progress__status-icon",
  "progressStepper": "pf-v6-c-progress-stepper",
  "progressStepperStep": "pf-v6-c-progress-stepper__step",
  "progressStepperStepConnector": "pf-v6-c-progress-stepper__step-connector",
  "progressStepperStepDescription": "pf-v6-c-progress-stepper__step-description",
  "progressStepperStepIcon": "pf-v6-c-progress-stepper__step-icon",
  "progressStepperStepMain": "pf-v6-c-progress-stepper__step-main",
  "progressStepperStepTitle": "pf-v6-c-progress-stepper__step-title",
  "radio": "pf-v6-c-radio",
  "radioBody": "pf-v6-c-radio__body",
  "radioDescription": "pf-v6-c-radio__description",
  "radioInput": "pf-v6-c-radio__input",
  "radioLabel": "pf-v6-c-radio__label",
  "scrollInnerWrapper": "pf-v6-c-scroll-inner-wrapper",
  "scrollOuterWrapper": "pf-v6-c-scroll-outer-wrapper",
  "sidebar": "pf-v6-c-sidebar",
  "sidebarContent": "pf-v6-c-sidebar__content",
  "sidebarMain": "pf-v6-c-sidebar__main",
  "sidebarPanel": "pf-v6-c-sidebar__panel",
  "simpleList": "pf-v6-c-simple-list",
  "simpleListItemLink": "pf-v6-c-simple-list__item-link",
  "simpleListSection": "pf-v6-c-simple-list__section",
  "simpleListTitle": "pf-v6-c-simple-list__title",
  "skeleton": "pf-v6-c-skeleton",
  "skipToContent": "pf-v6-c-skip-to-content",
  "slider": "pf-v6-c-slider",
  "sliderActions": "pf-v6-c-slider__actions",
  "sliderMain": "pf-v6-c-slider__main",
  "sliderRail": "pf-v6-c-slider__rail",
  "sliderRailTrack": "pf-v6-c-slider__rail-track",
  "sliderStep": "pf-v6-c-slider__step",
  "sliderStepLabel": "pf-v6-c-slider__step-label",
  "sliderStepTick": "pf-v6-c-slider__step-tick",
  "sliderSteps": "pf-v6-c-slider__steps",
  "sliderThumb": "pf-v6-c-slider__thumb",
  "sliderValue": "pf-v6-c-slider__value",
  "spinner": "pf-v6-c-spinner",
  "spinnerPath": "pf-v6-c-spinner__path",
  "switch": "pf-v6-c-switch",
  "switchInput": "pf-v6-c-switch__input",
  "switchLabel": "pf-v6-c-switch__label",
  "switchToggle": "pf-v6-c-switch__toggle",
  "switchToggleIcon": "pf-v6-c-switch__toggle-icon",
  "tabContent": "pf-v6-c-tab-content",
  "tabContentBody": "pf-v6-c-tab-content__body",
  "table": "pf-v6-c-table",
  "tableAction": "pf-v6-c-table__action",
  "tableButton": "pf-v6-c-table__button",
  "tableButtonContent": "pf-v6-c-table__button-content",
  "tableCaption": "pf-v6-c-table__caption",
  "tableCellEmpty": "pf-v6-c-table__cell-empty",
  "tableCheck": "pf-v6-c-table__check",
  "tableColumnHelp": "pf-v6-c-table__column-help",
  "tableColumnHelpAction": "pf-v6-c-table__column-help-action",
  "tableCompoundExpansionToggle": "pf-v6-c-table__compound-expansion-toggle",
  "tableControlRow": "pf-v6-c-table__control-row",
  "tableDraggable": "pf-v6-c-table__draggable",
  "tableExpandableRow": "pf-v6-c-table__expandable-row",
  "tableExpandableRowContent": "pf-v6-c-table__expandable-row-content",
  "tableFavorite": "pf-v6-c-table__favorite",
  "tableIcon": "pf-v6-c-table__icon",
  "tableIconInline": "pf-v6-c-table__icon-inline",
  "tableInlineEditAction": "pf-v6-c-table__inline-edit-action",
  "tableSort": "pf-v6-c-table__sort",
  "tableSortIndicator": "pf-v6-c-table__sort-indicator",
  "tableStickyCell": "pf-v6-c-table__sticky-cell",
  "tableSubhead": "pf-v6-c-table__subhead",
  "tableTbody": "pf-v6-c-table__tbody",
  "tableTd": "pf-v6-c-table__td",
  "tableText": "pf-v6-c-table__text",
  "tableTh": "pf-v6-c-table__th",
  "tableThead": "pf-v6-c-table__thead",
  "tableToggle": "pf-v6-c-table__toggle",
  "tableToggleIcon": "pf-v6-c-table__toggle-icon",
  "tableTr": "pf-v6-c-table__tr",
  "tableTreeViewDetailsToggle": "pf-v6-c-table__tree-view-details-toggle",
  "tableTreeViewIcon": "pf-v6-c-table__tree-view-icon",
  "tableTreeViewMain": "pf-v6-c-table__tree-view-main",
  "tableTreeViewText": "pf-v6-c-table__tree-view-text",
  "tableTreeViewTitleCell": "pf-v6-c-table__tree-view-title-cell",
  "tabs": "pf-v6-c-tabs",
  "tabsAdd": "pf-v6-c-tabs__add",
  "tabsItem": "pf-v6-c-tabs__item",
  "tabsItemAction": "pf-v6-c-tabs__item-action",
  "tabsItemActionIcon": "pf-v6-c-tabs__item-action-icon",
  "tabsItemText": "pf-v6-c-tabs__item-text",
  "tabsLink": "pf-v6-c-tabs__link",
  "tabsLinkToggleIcon": "pf-v6-c-tabs__link-toggle-icon",
  "tabsList": "pf-v6-c-tabs__list",
  "tabsScrollButton": "pf-v6-c-tabs__scroll-button",
  "tabsToggle": "pf-v6-c-tabs__toggle",
  "tabsToggleButton": "pf-v6-c-tabs__toggle-button",
  "tabsToggleIcon": "pf-v6-c-tabs__toggle-icon",
  "textInputGroup": "pf-v6-c-text-input-group",
  "textInputGroupGroup": "pf-v6-c-text-input-group__group",
  "textInputGroupIcon": "pf-v6-c-text-input-group__icon",
  "textInputGroupMain": "pf-v6-c-text-input-group__main",
  "textInputGroupText": "pf-v6-c-text-input-group__text",
  "textInputGroupTextInput": "pf-v6-c-text-input-group__text-input",
  "textInputGroupUtilities": "pf-v6-c-text-input-group__utilities",
  "tile": "pf-v6-c-tile",
  "tileBody": "pf-v6-c-tile__body",
  "tileHeader": "pf-v6-c-tile__header",
  "tileIcon": "pf-v6-c-tile__icon",
  "tileTitle": "pf-v6-c-tile__title",
  "timestamp": "pf-v6-c-timestamp",
  "timestampText": "pf-v6-c-timestamp__text",
  "title": "pf-v6-c-title",
  "toggleGroup": "pf-v6-c-toggle-group",
  "toggleGroupButton": "pf-v6-c-toggle-group__button",
  "toggleGroupIcon": "pf-v6-c-toggle-group__icon",
  "toggleGroupItem": "pf-v6-c-toggle-group__item",
  "toggleGroupText": "pf-v6-c-toggle-group__text",
  "toolbar": "pf-v6-c-toolbar",
  "toolbarContent": "pf-v6-c-toolbar__content",
  "toolbarContentSection": "pf-v6-c-toolbar__content-section",
  "toolbarExpandAllIcon": "pf-v6-c-toolbar__expand-all-icon",
  "toolbarExpandableContent": "pf-v6-c-toolbar__expandable-content",
  "toolbarGroup": "pf-v6-c-toolbar__group",
  "toolbarItem": "pf-v6-c-toolbar__item",
  "toolbarToggle": "pf-v6-c-toolbar__toggle",
  "tooltip": "pf-v6-c-tooltip",
  "tooltipArrow": "pf-v6-c-tooltip__arrow",
  "tooltipContent": "pf-v6-c-tooltip__content",
  "treeView": "pf-v6-c-tree-view",
  "treeViewAction": "pf-v6-c-tree-view__action",
  "treeViewContent": "pf-v6-c-tree-view__content",
  "treeViewList": "pf-v6-c-tree-view__list",
  "treeViewListItem": "pf-v6-c-tree-view__list-item",
  "treeViewNode": "pf-v6-c-tree-view__node",
  "treeViewNodeCheck": "pf-v6-c-tree-view__node-check",
  "treeViewNodeContainer": "pf-v6-c-tree-view__node-container",
  "treeViewNodeContent": "pf-v6-c-tree-view__node-content",
  "treeViewNodeCount": "pf-v6-c-tree-view__node-count",
  "treeViewNodeIcon": "pf-v6-c-tree-view__node-icon",
  "treeViewNodeText": "pf-v6-c-tree-view__node-text",
  "treeViewNodeTitle": "pf-v6-c-tree-view__node-title",
  "treeViewNodeToggle": "pf-v6-c-tree-view__node-toggle",
  "treeViewNodeToggleIcon": "pf-v6-c-tree-view__node-toggle-icon",
  "treeViewSearch": "pf-v6-c-tree-view__search",
  "truncate": "pf-v6-c-truncate",
  "truncateEnd": "pf-v6-c-truncate__end",
  "truncateStart": "pf-v6-c-truncate__start",
  "wizard": "pf-v6-c-wizard",
  "wizardClose": "pf-v6-c-wizard__close",
  "wizardDescription": "pf-v6-c-wizard__description",
  "wizardFooter": "pf-v6-c-wizard__footer",
  "wizardHeader": "pf-v6-c-wizard__header",
  "wizardInnerWrap": "pf-v6-c-wizard__inner-wrap",
  "wizardMain": "pf-v6-c-wizard__main",
  "wizardMainBody": "pf-v6-c-wizard__main-body",
  "wizardNav": "pf-v6-c-wizard__nav",
  "wizardNavItem": "pf-v6-c-wizard__nav-item",
  "wizardNavLink": "pf-v6-c-wizard__nav-link",
  "wizardNavLinkMain": "pf-v6-c-wizard__nav-link-main",
  "wizardNavLinkStatusIcon": "pf-v6-c-wizard__nav-link-status-icon",
  "wizardNavLinkToggle": "pf-v6-c-wizard__nav-link-toggle",
  "wizardNavLinkToggleIcon": "pf-v6-c-wizard__nav-link-toggle-icon",
  "wizardNavList": "pf-v6-c-wizard__nav-list",
  "wizardOuterWrap": "pf-v6-c-wizard__outer-wrap",
  "wizardTitle": "pf-v6-c-wizard__title",
  "wizardTitleText": "pf-v6-c-wizard__title-text",
  "wizardToggle": "pf-v6-c-wizard__toggle",
  "wizardToggleIcon": "pf-v6-c-wizard__toggle-icon",
  "wizardToggleList": "pf-v6-c-wizard__toggle-list",
  "wizardToggleListItem": "pf-v6-c-wizard__toggle-list-item",
  "wizardToggleNum": "pf-v6-c-wizard__toggle-num",
  "wizardToggleSeparator": "pf-v6-c-wizard__toggle-separator",
  "wizardToggleStatusIcon": "pf-v6-c-wizard__toggle-status-icon"
};