"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OverflowMenuContext = void 0;
const react_1 = require("react");
exports.OverflowMenuContext = (0, react_1.createContext)({
    isBelowBreakpoint: false
});
//# sourceMappingURL=OverflowMenuContext.js.map