import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon';
export declare const BlackTieIconConfig: {
  name: 'BlackTieIcon',
  height: 512,
  width: 448,
  svgPath: "M0 32v448h448V32H0zm316.5 325.2L224 445.9l-92.5-88.7 64.5-184-64.5-86.6h184.9L252 173.2l64.5 184z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
export declare const BlackTieIcon: ComponentClass<SVGIconProps>;
export default BlackTieIcon;