.pf-v6-c-card {
  --pf-v6-c-card--BackgroundColor: var(--pf-t--global--background--color--primary--default);
  --pf-v6-c-card--BorderColor: var(--pf-t--global--border--color--default);
  --pf-v6-c-card--BorderStyle: solid;
  --pf-v6-c-card--BorderWidth: var(--pf-t--global--border--width--box--default);
  --pf-v6-c-card--BorderRadius: var(--pf-t--global--border--radius--medium);
  --pf-v6-c-card--first-child--PaddingBlockStart: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card--child--PaddingInlineEnd: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card--child--PaddingBlockEnd: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card--child--PaddingInlineStart: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card--c-divider--child--PaddingBlockStart: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card__title--not--last-child--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-card__title-text--Color: var(--pf-t--global--text--color--regular);
  --pf-v6-c-card__title-text--FontFamily: var(--pf-t--global--font--family--heading);
  --pf-v6-c-card__title-text--FontSize: var(--pf-t--global--font--size--heading--xs);
  --pf-v6-c-card__title-text--FontWeight: var(--pf-t--global--font--weight--heading--default);
  --pf-v6-c-card__title-text--LineHeight: var(--pf-t--global--font--line-height--heading);
  --pf-v6-c-card__title-text--OverflowWrap: break-word;
  --pf-v6-c-card--c-button--disabled--Color: var(--pf-t--global--text--color--on-disabled);
  --pf-v6-c-card__body--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-card__footer--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-card__footer--Color: var(--pf-t--global--text--color--subtle);
  --pf-v6-c-card__actions--PaddingInlineStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-card__actions--Gap: var(--pf-t--global--spacer--gap--action-to-action--default);
  --pf-v6-c-card__actions--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--default) * -1);
  --pf-v6-c-card__actions--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--default) * -1);
  --pf-v6-c-card__header--m-wrap--RowGap: var(--pf-t--global--spacer--sm);
  --pf-v6-c-card__header--m-wrap--ColumnGap: var(--pf-t--global--spacer--md);
  --pf-v6-c-card__header-toggle--MarginBlockStart: calc(var(--pf-t--global--spacer--control--vertical--default) * -1);
  --pf-v6-c-card__header-toggle--MarginInlineEnd: var(--pf-t--global--spacer--gap--text-to-element--default);
  --pf-v6-c-card__header-toggle--MarginBlockEnd: calc(var(--pf-t--global--spacer--control--vertical--default) * -1);
  --pf-v6-c-card__header-toggle--MarginInlineStart: calc(var(--pf-t--global--spacer--action--horizontal--plain--default) * -1);
  --pf-v6-c-card__header-toggle-icon--TransitionTimingFunction: var(--pf-t--global--motion--timing-function--default);
  --pf-v6-c-card__header-toggle-icon--TransitionDuration: var(--pf-t--global--motion--duration--icon--default);
  --pf-v6-c-card--m-expanded__header-toggle-icon--Rotate: 90deg;
  --pf-v6-c-card--m-selectable--BorderWidth: var(--pf-v6-c-card--BorderWidth);
  --pf-v6-c-card--m-clickable--m-current--BorderColor: var(--pf-t--global--border--color--clicked);
  --pf-v6-c-card--m-clickable--m-current--BorderWidth: var(--pf-t--global--border--width--box--clicked);
  --pf-v6-c-card--m-selectable--m-selected--BorderColor: var(--pf-t--global--border--color--clicked);
  --pf-v6-c-card--m-selectable--m-selected--BorderWidth: var(--pf-t--global--border--width--box--clicked);
  --pf-v6-c-card--m-selectable--hover--BorderColor: var(--pf-t--global--border--color--hover);
  --pf-v6-c-card--m-selectable--hover--BorderWidth: var(--pf-t--global--border--width--box--hover);
  --pf-v6-c-card--m-selectable--focus--BorderColor: var(--pf-t--global--border--color--hover);
  --pf-v6-c-card--m-selectable--focus--BorderWidth: var(--pf-t--global--border--width--box--hover);
  --pf-v6-c-card--m-selectable--m-selected--focus--BorderColor: var(--pf-t--global--border--color--clicked);
  --pf-v6-c-card--m-selectable--m-selected--focus--BorderWidth: var(--pf-t--global--border--width--box--clicked);
  --pf-v6-c-card--m-selectable--m-disabled__title-text--Color: var(--pf-t--global--text--color--on-disabled);
  --pf-v6-c-card--m-selectable--m-disabled__body--Color: var(--pf-t--global--text--color--on-disabled);
  --pf-v6-c-card--m-selectable--m-disabled__footer--Color: var(--pf-t--global--text--color--on-disabled);
  --pf-v6-c-card--m-selectable--m-disabled--BackgroundColor: var(--pf-t--global--background--color--disabled--default);
  --pf-v6-c-card--m-selectable--m-disabled--BorderColor: transparent;
  --pf-v6-c-card--m-selectable--m-clickable--m-current--BorderColor: var(--pf-t--global--border--color--clicked);
  --pf-v6-c-card--m-selectable--m-clickable--m-current--BorderWidth: var(--pf-t--global--border--width--box--clicked);
  --pf-v6-c-card--m-compact__title-text--FontSize: var(--pf-t--global--font--size--heading--xs);
  --pf-v6-c-card--m-compact__body--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-card--m-compact__footer--FontSize: var(--pf-t--global--font--size--body--sm);
  --pf-v6-c-card--m-compact--first-child--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-card--m-compact--child--PaddingInlineEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-card--m-compact--child--PaddingBlockEnd: var(--pf-t--global--spacer--md);
  --pf-v6-c-card--m-compact--child--PaddingInlineStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-card--m-compact--c-divider--child--PaddingBlockStart: var(--pf-t--global--spacer--md);
  --pf-v6-c-card--m-compact__title--not--last-child--PaddingBlockEnd: var(--pf-t--global--spacer--sm);
  --pf-v6-c-card--m-display-lg__title-text--FontSize: var(--pf-t--global--font--size--heading--md);
  --pf-v6-c-card--m-display-lg__body--FontSize: var(--pf-t--global--font--size--body--lg);
  --pf-v6-c-card--m-display-lg__footer--FontSize: var(--pf-t--global--font--size--body--default);
  --pf-v6-c-card--m-display-lg--first-child--PaddingBlockStart: var(--pf-t--global--spacer--xl);
  --pf-v6-c-card--m-display-lg--child--PaddingInlineEnd: var(--pf-t--global--spacer--xl);
  --pf-v6-c-card--m-display-lg--child--PaddingBlockEnd: var(--pf-t--global--spacer--xl);
  --pf-v6-c-card--m-display-lg--child--PaddingInlineStart: var(--pf-t--global--spacer--xl);
  --pf-v6-c-card--m-display-lg--c-divider--child--PaddingBlockStart: var(--pf-t--global--spacer--xl);
  --pf-v6-c-card--m-display-lg__title--not--last-child--PaddingBlockEnd: var(--pf-t--global--spacer--lg);
  --pf-v6-c-card--m-secondary--BackgroundColor: var(--pf-t--global--background--color--secondary--default);
  --pf-v6-c-card--m-secondary--BorderColor: var(--pf-t--global--border--color--high-contrast);
  --pf-v6-c-card--m-secondary--BorderWidth: var(--pf-t--global--border--width--high-contrast--regular);
  --pf-v6-c-card--m-full-height--Height: 100%;
  --pf-v6-c-card--m-plain--BorderColor: transparent;
  --pf-v6-c-card--m-plain--BackgroundColor: transparent;
  --pf-v6-c-card__header--m-toggle-right--toggle--MarginInlineEnd: calc(var(--pf-t--global--spacer--action--horizontal--plain--default) * -1);
  --pf-v6-c-card__header--m-toggle-right--toggle--MarginInlineStart: var(--pf-t--global--spacer--gap--text-to-element--default);
}

.pf-v6-c-card {
  position: relative;
  display: flex;
  flex-direction: column;
  overflow: auto;
  background-color: var(--pf-v6-c-card--BackgroundColor);
  border: 0;
  border-radius: var(--pf-v6-c-card--BorderRadius);
}
.pf-v6-c-card::before {
  position: absolute;
  inset: 0;
  pointer-events: none;
  content: "";
  border: var(--pf-v6-c-card--BorderColor) var(--pf-v6-c-card--BorderStyle) var(--pf-v6-c-card--BorderWidth);
  border-radius: inherit;
}
.pf-v6-c-card.pf-m-selectable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check, .pf-v6-c-radio) {
  gap: 0;
}
.pf-v6-c-card.pf-m-selectable, .pf-v6-c-card.pf-m-clickable {
  isolation: isolate;
}
.pf-v6-c-card.pf-m-selectable::before, .pf-v6-c-card.pf-m-clickable::before {
  border: none;
}
.pf-v6-c-card.pf-m-current {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-clickable--m-current--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-clickable--m-current--BorderWidth);
  --pf-v6-c-card--m-selectable--hover--BorderColor: var(--pf-v6-c-card--m-clickable--m-current--BorderColor);
  --pf-v6-c-card--m-selectable--focus--BorderColor: var(--pf-v6-c-card--m-clickable--m-current--BorderColor);
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__label, .pf-v6-c-radio__label) {
  position: unset;
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__label, .pf-v6-c-radio__label)::before {
  position: absolute;
  inset: 0;
  cursor: pointer;
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:focus-visible) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label) {
  --pf-v6-c-card--BackgroundColor: revert;
  --pf-v6-c-card--BorderColor: revert;
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:checked) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label), .pf-v6-c-card.pf-m-selectable.pf-m-clickable.pf-m-selected {
  --pf-v6-c-card--BorderColor: revert;
  --pf-v6-c-card--m-selectable--BorderWidth: revert;
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable.pf-m-current {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--m-clickable--m-current--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-selectable--m-clickable--m-current--BorderWidth);
}
.pf-v6-c-card.pf-m-selectable.pf-m-clickable .pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:disabled) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label), .pf-v6-c-card.pf-m-selectable.pf-m-clickable.pf-m-disabled {
  --pf-v6-c-card--BackgroundColor: var(--pf-v6-c-card--m-selectable--m-disabled--BackgroundColor);
}
.pf-v6-c-card.pf-m-compact {
  --pf-v6-c-card__title-text--FontSize: var(--pf-v6-c-card--m-compact__title-text--FontSize);
  --pf-v6-c-card__body--FontSize: var(--pf-v6-c-card--m-compact__body--FontSize);
  --pf-v6-c-card__footer--FontSize: var(--pf-v6-c-card--m-compact__footer--FontSize);
  --pf-v6-c-card--first-child--PaddingBlockStart: var(--pf-v6-c-card--m-compact--first-child--PaddingBlockStart);
  --pf-v6-c-card--child--PaddingInlineEnd: var(--pf-v6-c-card--m-compact--child--PaddingInlineEnd);
  --pf-v6-c-card--child--PaddingBlockEnd: var(--pf-v6-c-card--m-compact--child--PaddingBlockEnd);
  --pf-v6-c-card--child--PaddingInlineStart: var(--pf-v6-c-card--m-compact--child--PaddingInlineStart);
  --pf-v6-c-card--c-divider--child--PaddingBlockStart: var(--pf-v6-c-card--m-compact--c-divider--child--PaddingBlockStart);
  --pf-v6-c-card__title--not--last-child--PaddingBlockEnd: var(--pf-v6-c-card--m-compact__title--not--last-child--PaddingBlockEnd);
}
.pf-v6-c-card.pf-m-display-lg {
  --pf-v6-c-card__title-text--FontSize: var(--pf-v6-c-card--m-display-lg__title-text--FontSize);
  --pf-v6-c-card__body--FontSize: var(--pf-v6-c-card--m-display-lg__body--FontSize);
  --pf-v6-c-card__footer--FontSize: var(--pf-v6-c-card--m-display-lg__footer--FontSize);
  --pf-v6-c-card--first-child--PaddingBlockStart: var(--pf-v6-c-card--m-display-lg--first-child--PaddingBlockStart);
  --pf-v6-c-card--child--PaddingInlineEnd: var(--pf-v6-c-card--m-display-lg--child--PaddingInlineEnd);
  --pf-v6-c-card--child--PaddingBlockEnd: var(--pf-v6-c-card--m-display-lg--child--PaddingBlockEnd);
  --pf-v6-c-card--child--PaddingInlineStart: var(--pf-v6-c-card--m-display-lg--child--PaddingInlineStart);
  --pf-v6-c-card--c-divider--child--PaddingBlockStart: var(--pf-v6-c-card--m-display-lg--c-divider--child--PaddingBlockStart);
  --pf-v6-c-card__title--not--last-child--PaddingBlockEnd: var(--pf-v6-c-card--m-display-lg__title--not--last-child--PaddingBlockEnd);
}
.pf-v6-c-card.pf-m-secondary {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-secondary--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-secondary--BorderWidth);
  --pf-v6-c-card--BackgroundColor: var(--pf-v6-c-card--m-secondary--BackgroundColor);
}
.pf-v6-c-card.pf-m-plain {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-plain--BorderColor);
  --pf-v6-c-card--BackgroundColor: var(--pf-v6-c-card--m-plain--BackgroundColor);
}
.pf-v6-c-card.pf-m-expanded .pf-v6-c-card__header-toggle-icon {
  transform: rotate(var(--pf-v6-c-card--m-expanded__header-toggle-icon--Rotate));
}
.pf-v6-c-card.pf-m-full-height {
  height: var(--pf-v6-c-card--m-full-height--Height);
}
.pf-v6-c-card > .pf-v6-c-divider + .pf-v6-c-card__header, .pf-v6-c-card > .pf-v6-c-divider + .pf-v6-c-card__title, .pf-v6-c-card > .pf-v6-c-divider + .pf-v6-c-card__body, .pf-v6-c-card > .pf-v6-c-divider + .pf-v6-c-card__footer {
  padding-block-start: var(--pf-v6-c-card--c-divider--child--PaddingBlockStart);
}

.pf-v6-c-card__header {
  display: flex;
  flex-direction: row;
  align-items: center;
}
.pf-v6-c-card__header .pf-v6-c-card__title {
  --pf-v6-c-card--first-child--PaddingBlockStart: 0;
  --pf-v6-c-card__title--not--last-child--PaddingBlockEnd: 0;
  padding: 0;
}
.pf-v6-c-card__header.pf-m-toggle-right {
  --pf-v6-c-card__header-toggle--MarginInlineEnd: var(--pf-v6-c-card__header--m-toggle-right--toggle--MarginInlineEnd);
  --pf-v6-c-card__header-toggle--MarginInlineStart: var(--pf-v6-c-card__header--m-toggle-right--toggle--MarginInlineStart);
}
.pf-v6-c-card__header.pf-m-toggle-right .pf-v6-c-card__header-toggle {
  order: 2;
}
.pf-v6-c-card__header.pf-m-wrap {
  --pf-v6-c-card__actions--PaddingInlineStart: 0;
  gap: var(--pf-v6-c-card__header--m-wrap--RowGap) var(--pf-v6-c-card__header--m-wrap--ColumnGap);
}
.pf-v6-c-card__header.pf-m-wrap,
.pf-v6-c-card__header.pf-m-wrap .pf-v6-c-card__actions {
  flex-wrap: wrap;
  row-gap: var(--pf-v6-c-card__header--m-wrap--RowGap);
}
.pf-v6-c-card__header.pf-m-wrap .pf-v6-c-card__actions {
  margin-inline-start: 0;
}
.pf-v6-c-card__header.pf-m-wrap .pf-v6-c-card__actions + * {
  margin-inline-end: auto;
}

.pf-v6-c-card__header-main {
  flex-grow: 1;
}

.pf-v6-c-card__header-toggle {
  align-self: flex-start;
  margin-block-start: var(--pf-v6-c-card__header-toggle--MarginBlockStart);
  margin-block-end: var(--pf-v6-c-card__header-toggle--MarginBlockEnd);
  margin-inline-start: var(--pf-v6-c-card__header-toggle--MarginInlineStart);
  margin-inline-end: var(--pf-v6-c-card__header-toggle--MarginInlineEnd);
}

.pf-v6-c-card__header-toggle-icon {
  display: inline-block;
  transition-timing-function: var(--pf-v6-c-card__header-toggle-icon--TransitionTimingFunction);
  transition-duration: var(--pf-v6-c-card__header-toggle-icon--TransitionDuration);
  transition-property: transform;
}
:where(.pf-v6-m-dir-rtl, [dir=rtl]) .pf-v6-c-card__header-toggle-icon {
  scale: -1 1;
}

.pf-v6-c-card__title-text {
  font-family: var(--pf-v6-c-card__title-text--FontFamily);
  font-size: var(--pf-v6-c-card__title-text--FontSize);
  font-weight: var(--pf-v6-c-card__title-text--FontWeight);
  line-height: var(--pf-v6-c-card__title-text--LineHeight);
  color: var(--pf-v6-c-card__title-text--Color);
  overflow-wrap: var(--pf-v6-c-card__title-text--OverflowWrap);
}

.pf-v6-c-card__actions {
  display: flex;
  gap: var(--pf-v6-c-card__actions--Gap);
  align-items: center;
  align-self: flex-start;
  order: 1;
  padding-inline-start: var(--pf-v6-c-card__actions--PaddingInlineStart);
  margin-block-start: var(--pf-v6-c-card__actions--MarginBlockStart);
  margin-block-end: var(--pf-v6-c-card__actions--MarginBlockEnd);
  margin-inline-start: auto;
}
.pf-v6-c-card__actions + .pf-v6-c-card__title,
.pf-v6-c-card__actions + .pf-v6-c-card__body,
.pf-v6-c-card__actions + .pf-v6-c-card__footer {
  padding: 0;
}
.pf-v6-c-card__actions.pf-m-no-offset {
  --pf-v6-c-card__actions--MarginBlockStart: 0;
  --pf-v6-c-card__actions--MarginBlockEnd: 0;
}

.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__label, .pf-v6-c-radio__label, .pf-v6-c-card__clickable-action) {
  position: absolute;
  inset: 0;
  justify-self: auto;
  cursor: pointer;
}
.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__label, .pf-v6-c-radio__label, .pf-v6-c-card__clickable-action)::before {
  position: absolute;
  inset: 0;
  z-index: -1;
  content: "";
  background-color: var(--pf-v6-c-card--BackgroundColor, transparent);
  border: var(--pf-v6-c-card--BorderWidth) solid var(--pf-v6-c-card--BorderColor, transparent);
  border-radius: var(--pf-v6-c-card--BorderRadius);
}
.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__label, .pf-v6-c-radio__label, .pf-v6-c-card__clickable-action):hover {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--hover--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-selectable--hover--BorderWidth);
}

.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:checked) ~ :is(.pf-v6-c-radio__label, .pf-v6-c-check__label),
.pf-v6-c-card.pf-m-selected {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--m-selected--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-selectable--m-selected--BorderWidth);
}

.pf-v6-c-card__selectable-actions .pf-v6-c-card__clickable-action:where(:focus-visible),
.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input, .pf-v6-c-card__clickable-action):where(:focus-visible) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label) {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--focus--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-selectable--focus--BorderWidth);
}

.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:focus-visible):where(:checked) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label) {
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--m-selected--focus--BorderColor);
  --pf-v6-c-card--BorderWidth: var(--pf-v6-c-card--m-selectable--m-selected--focus--BorderWidth);
}

.pf-v6-c-card__selectable-actions :is(.pf-v6-c-check__input, .pf-v6-c-radio__input):where(:disabled) ~ :is(.pf-v6-c-check__label, .pf-v6-c-radio__label),
.pf-v6-c-card.pf-m-disabled {
  --pf-v6-c-card__title-text--Color: var(--pf-v6-c-card--m-selectable--m-disabled__title-text--Color);
  --pf-v6-c-card__body--Color: var(--pf-v6-c-card--m-selectable--m-disabled__body--Color);
  --pf-v6-c-card__footer--Color: var(--pf-v6-c-card--m-selectable--m-disabled__footer--Color);
  --pf-v6-c-card--BackgroundColor: var(--pf-v6-c-card--m-selectable--m-disabled--BackgroundColor);
  --pf-v6-c-card--BorderColor: var(--pf-v6-c-card--m-selectable--m-disabled--BorderColor);
}

.pf-v6-c-card__clickable-action {
  background: none;
  border: 0;
  outline: 0;
}
.pf-v6-c-card__clickable-action:disabled, .pf-v6-c-card__clickable-action.pf-m-disabled {
  pointer-events: none;
}

.pf-v6-c-card__header,
.pf-v6-c-card__title,
.pf-v6-c-card__body,
.pf-v6-c-card__footer {
  padding-block-end: var(--pf-v6-c-card--child--PaddingBlockEnd);
  padding-inline-start: var(--pf-v6-c-card--child--PaddingInlineStart);
  padding-inline-end: var(--pf-v6-c-card--child--PaddingInlineEnd);
}
.pf-v6-c-card__header:first-child,
.pf-v6-c-card__title:first-child,
.pf-v6-c-card__body:first-child,
.pf-v6-c-card__footer:first-child {
  padding-block-start: var(--pf-v6-c-card--first-child--PaddingBlockStart);
}

.pf-v6-c-card__header:not(:last-child),
.pf-v6-c-card__title:not(:last-child) {
  padding-block-end: var(--pf-v6-c-card__title--not--last-child--PaddingBlockEnd);
}
.pf-v6-c-card__header .pf-v6-c-button.pf-m-inline:disabled,
.pf-v6-c-card__title .pf-v6-c-button.pf-m-inline:disabled {
  --pf-v6-c-button--disabled--Color: var(--pf-v6-c-card--c-button--disabled--Color);
}

.pf-v6-c-card__expandable-content {
  --pf-v6-c-card--first-child--PaddingBlockStart: 0;
}

.pf-v6-c-card__body:not(.pf-m-no-fill) {
  flex: 1 1 auto;
}

.pf-v6-c-card__body {
  font-size: var(--pf-v6-c-card__body--FontSize);
  color: var(--pf-v6-c-card__body--Color);
}

.pf-v6-c-card__footer {
  font-size: var(--pf-v6-c-card__footer--FontSize);
  color: var(--pf-v6-c-card__footer--Color);
}