/// <reference types="react" />
export interface FormHelperTextProps extends React.HTMLProps<HTMLDivElement> {
    /** Content rendered inside the helper text wrapper */
    children?: React.ReactNode;
    /** Additional classes added to the helper text wrapper  */
    className?: string;
}
export declare const FormHelperText: React.FunctionComponent<FormHelperTextProps>;
//# sourceMappingURL=FormHelperText.d.ts.map