import { createIcon } from '../createIcon';

export const GripLinesIconConfig = {
  name: 'GripLinesIcon',
  height: 512,
  width: 512,
  svgPath: "M496 288H16c-8.8 0-16 7.2-16 16v32c0 8.8 7.2 16 16 16h480c8.8 0 16-7.2 16-16v-32c0-8.8-7.2-16-16-16zm0-128H16c-8.8 0-16 7.2-16 16v32c0 8.8 7.2 16 16 16h480c8.8 0 16-7.2 16-16v-32c0-8.8-7.2-16-16-16z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};

export const GripLinesIcon = createIcon(GripLinesIconConfig);

export default GripLinesIcon;