"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
tslib_1.__exportStar(require("./Tab"), exports);
tslib_1.__exportStar(require("./TabAction"), exports);
tslib_1.__exportStar(require("./Tabs"), exports);
tslib_1.__exportStar(require("./TabContent"), exports);
tslib_1.__exportStar(require("./TabContentBody"), exports);
tslib_1.__exportStar(require("./TabsContext"), exports);
tslib_1.__exportStar(require("./TabTitleText"), exports);
tslib_1.__exportStar(require("./TabTitleIcon"), exports);
//# sourceMappingURL=index.js.map