"use strict"
exports.__esModule = true;
exports.FlipboardIconConfig = {
  name: 'FlipboardIcon',
  height: 512,
  width: 448,
  svgPath: "M0 32v448h448V32H0zm358.4 179.2h-89.6v89.6h-89.6v89.6H89.6V121.6h268.8v89.6z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.FlipboardIcon = require('../createIcon').createIcon(exports.FlipboardIconConfig);
exports["default"] = exports.FlipboardIcon;